@@ -46,7 +46,7 @@ fi
 #TODO: Check debug symbols are stripped
 
 #Ensure that program name not screwed up by XCode
-if [ x`grep ${INFO_PLIST} -Depict` != x"" ] ; then
+if [ x`grep '[-]Depict' ${INFO_PLIST}` != x"" ] ; then
 	echo "Program name incorrectly stored in package, is listed as _Depict, rather than $PROGRAM_NAME"
 	exit 1
 fi
@@ -54,7 +54,9 @@ fi
 #ensure that we have some .vfm files in here
 if [ x`find ./ -name \*.vfm` == x"" ] ; then
 	echo "No VFM files (mathgl fonts) found!"
-	exit 1 
+	echo " Have you checked that you installed the font files for mathgl? Do unusual chars (eg \alpeh) work in the plot (try, eg changing title of spectrum)"
+	sleep 5
+#	exit 1 
 fi
 
 #ensure that we have some .pdf files in here
