@@ -11,6 +11,9 @@
 #HOST_VAL=x86_64-w64-mingw32 #For mingw64 (windows 64 bit)
 #HOST_VAL=i686-w64-mingw32 #For mingw32 (Windows 32 bit)
 
+#Should we use Hg to track changes in the unpacked dependencies (where enabled)?
+USE_HG=1
+
 #Setup clone of hg repository, if required
 if [ ! -d code ] || [ ! -d code/3Depict ]  ; then
 	read -p "Code dir is missing -- shall we clone it?? (y/n):" answer
@@ -134,16 +137,20 @@ PATCHES_ICONV="iconv-fix-alias2.patch"
 #1) gettext-tools fails in various places, but we don't actually need it, so turn it off
 PATCHES_GETTEXT="gettext-fix-configure-versions gettext-disable-tools"   
 
-PATCHES_GLEW="glew-makefile.base glew-disable-dllentrypoint"
+PATCHES_GLEW="glew-disable-dllentrypoint glew-disable-tool-build.patch"
 
 PATCHES_MATHGL="mathgl-disable-things"
 
-PATCHES_QHULL="qhull-ptr.patch" # qhull-2009-configure_ac.patch"
+PATCHES_QHULL_2015="qhull-ptr.patch" # qhull-2009-configure_ac.patch"
+PATCHES_QHULL_2009="qhull_2009-ptr_t.patch qhull-2009-configure_ac.patch qhull_2009-libtool.patch"
 
 #Vigra's cmakelists assumes you can execute compiled binaries on the host
 # this obviously won't work for cross compilation
 PATCHES_LIBVIGRA="vigra-cpp-version.patch"
 
+#Libvd uses error.h which has a name conflict
+PATCHES_LIBVD="libvd_error_rename"
+
 PATCH_LIST="$PATCHES_WXWIDGETS_POST $PATCHES_GSL $PATCHES_ZLIB $PATCHES_LIBPNG $PATCHES_GETTEXT $PATCHES_FTGL $PATCHES_GLEW $PATCHES_MATHGL $PATCHES_FTGL_POSTCONF $PATCHES_ICONV $PATCHES_QHULL $PATCHES_LIBVIGRA"
 
 
@@ -160,6 +167,18 @@ function isBuilt()
 	fi
 }
 
+function createHgRepoAsNeeded
+{
+	if [ $USE_HG -ne 0 ] ; then
+
+		if [ ! -d .hg ] ; then
+			hg init .
+			hg add .
+			hg commit  -u me -m "Automatic initial commit"
+		fi
+	fi
+}
+
 function applyPatches()
 {
 	for i in $APPLY_PATCH_ARG
@@ -267,44 +286,44 @@ function grabDeps()
 
 	#---
 	#Download dsc package not in archive (pull from debian mentors)
-	FILES_LIBVD="libvd_1.1.0+svn7-1.dsc libvd_1.1.0+svn7-1.debian.tar.xz libvd_1.1.0+svn7.orig.tar.gz"
-	URL_LIBVD="https://mentors.debian.net/debian/pool/main/libv/libvd/"
-	SHA_LIBVD="70ad1c77d807f0eea259ae4b88a0eb1284401467 afac97ecfc678965a241f7132d14ebb8c09d0be1 d66f48b3b2d00d3543cb1d3de572ef9c9acd4875"
+#	FILES_LIBVD="libvd_1.1.0+svn7-1.dsc libvd_1.1.0+svn7-1.debian.tar.xz libvd_1.1.0+svn7.orig.tar.gz"
+#	URL_LIBVD="https://mentors.debian.net/debian/pool/main/libv/libvd/"
+#	SHA_LIBVD="70ad1c77d807f0eea259ae4b88a0eb1284401467 afac97ecfc678965a241f7132d14ebb8c09d0be1 d66f48b3b2d00d3543cb1d3de572ef9c9acd4875"
 
 
 	#Check SHA1sum hash to ensure integrity
 	#----
-	rm sha1_libvd.tmp
-	for i in $FILES_LIBVD
-	do
-		if [ ! -f $i ] ; then
-			if [ ! -f packages/$i  ] ; then
-				wget ${URL_LIBVD}${i} || { echo "Unable to download libvd DSC"; exit 1; }
-			else
-				mv packages/$i .
-			fi
-		fi
+#	rm sha1_libvd.tmp
+#	for i in $FILES_LIBVD
+#	do
+#		if [ ! -f $i ] ; then
+#			if [ ! -f packages/$i  ] ; then
+#				wget ${URL_LIBVD}${i} || { echo "Unable to download libvd DSC"; exit 1; }
+#			else
+#				mv packages/$i .
+#			fi
+#		fi
 
-		sha1sum $i | awk '{ print $1 }' >>sha1_libvd.tmp
-	done
+#		sha1sum $i | awk '{ print $1 }' >>sha1_libvd.tmp
+#	done
 
 	
-	SHA_DOWNLOADS=`cat sha1_libvd.tmp | tr '\n' ' '  | sed 's/ *$//'`
-	if [ x"${SHA_DOWNLOADS}" != x"${SHA_LIBVD}" ] ; then
-		echo "SHA1 sums were : |"${SHA_DOWNLOADS}"|"
-		echo " Should be: |"${SHA_LIBVD}"|"
-		exit 1
-	fi
-	rm sha1_libvd.tmp
+#	SHA_DOWNLOADS=`cat sha1_libvd.tmp | tr '\n' ' '  | sed 's/ *$//'`
+#	if [ x"${SHA_DOWNLOADS}" != x"${SHA_LIBVD}" ] ; then
+#		echo "SHA1 sums were : |"${SHA_DOWNLOADS}"|"
+#		echo " Should be: |"${SHA_LIBVD}"|"
+#		exit 1
+#	fi
+#	rm sha1_libvd.tmp
 	#----
 	
 	#extract
-	if [ ! -d libvd-1.1.0+svn7 ] ; then	
-		dpkg-source --no-check -x libvd*dsc || { echo "LIBVD Package extraction failed"; exit 1; }
-	fi
+#	if [ ! -d libvd-1.1.0+svn7 ] ; then	
+#		dpkg-source --no-check -x libvd*dsc || { echo "LIBVD Package extraction failed"; exit 1; }
+#	fi
 
 	#Move into package folder
-	mv libvd*{dsc,gz,xz} packages/
+#	mv libvd*{dsc,gz,xz} packages/
 	#---
 
 
@@ -460,6 +479,8 @@ function build_zlib()
 		echo "Zlib dir missing, or duplicated?"
 		exit 1
 	fi
+
+	createHgRepoAsNeeded
 	
 	make clean
 	rm -f configure.log
@@ -494,6 +515,9 @@ function build_glew()
 		return;
 	fi
 
+	echo "WARNING - GLEW BUILDS, BUT SOMETIMES DLL WONT LOAD UNDER WINDOWS - REASON NOT CLEAR..."
+	sleep 5
+
 	#Perform dynamic modification of patch
 	if [ x"`grep HOST_VAL patches/glew-makefile.base`" == x""  -o   x"`grep BASEDIR patches/glew-makefile.base`" == x"" ] ; then
 		echo "patches/glew-makefile did not contain replacement keywords"
@@ -505,8 +529,6 @@ function build_glew()
 	sed -i "s@HOST_VAL@$HOST_VAL@" patches/glew-makefile
 	sed -i "s@BASEDIR@$BASE@" patches/glew-makefile
 	#FIXME: I patched out the bin/ subdir, around line 155
-	echo "There is a patch missing to remove the tool build"
-	exit 1
 
 	pushd deps >/dev/null
 	pushd glew-* >/dev/null
@@ -518,7 +540,7 @@ function build_glew()
 	fi
 	
 
-	APPLY_PATCH_ARG="glew-makefile"
+	APPLY_PATCH_ARG=$PATCHES_GLEW
 	applyPatches
 
 	make clean
@@ -564,6 +586,8 @@ function build_libpng()
 		exit 1
 	fi
 
+	createHgRepoAsNeeded
+
 	make clean
 
 	./configure --host=$HOST_VAL --prefix=/ --enable-shared --disable-static || { echo "Libpng configure failed"; exit 1; } 
@@ -632,6 +656,8 @@ function build_libxml2()
 		exit 1
 	fi
 
+	createHgRepoAsNeeded
+	
 	#Libxml 2.8 and up doesn't need patching.
 	# note that --compare-versions returns 0 on truth, and 1 on false
 	dpkg --compare-versions  $LIBXMLVER lt 2.8
@@ -689,6 +715,8 @@ function build_libjpeg()
 		exit 1
 	fi
 
+	createHgRepoAsNeeded
+
 	make clean
 
 	autoconf
@@ -725,6 +753,9 @@ function build_libtiff()
 		echo "libtiff dir missing, or duplicated?"
 		exit 1
 	fi
+	
+	createHgRepoAsNeeded
+	
 	./configure --host=$HOST_VAL --enable-shared --disable-static --prefix=/ || { echo "Libtiff configure failed"; exit 1; } 
 
 	make -j $NUM_PROCS || { echo "libtiff build failed"; exit 1; } 
@@ -750,7 +781,8 @@ function build_qhull2012()
 	if [ $ISBUILT -eq 1 ] ; then
 		return;
 	fi
-	
+
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd qhull-* >/dev/null
 	
@@ -758,6 +790,8 @@ function build_qhull2012()
 		echo "qhull dir missing, or duplicated?"
 		exit 1
 	fi
+	
+	createHgRepoAsNeeded
 
 	make clean
 
@@ -798,6 +832,7 @@ function build_qhull2015()
 		return;
 	fi
 	
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd qhull-* >/dev/null
 	
@@ -806,11 +841,13 @@ function build_qhull2015()
 		exit 1
 	fi
 
+	createHgRepoAsNeeded
+
 	#delete the qhull directories that do NOT correspond to the version of qhull we want to build
 	rm -rf src/libqhull src/libqhullcpp src/libqhullstatic*
 
-	APPLY_PATCH_ARG="$PATCHES_QHULL"
-	applyPatches
+#	APPLY_PATCH_ARG="$PATCHES_QHULL"
+#	applyPatches
 	make clean
 
 	cp ../../patches/qhull2015-cmakefile-replacement CMakeLists.txt
@@ -861,6 +898,7 @@ function build_qhull2009()
 		return;
 	fi
 	
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd qhull-* >/dev/null
 	
@@ -869,6 +907,12 @@ function build_qhull2009()
 		exit 1
 	fi
 
+	
+	APPLY_PATCH_ARG="$PATCHES_QHULL_2009"
+	applyPatches
+
+	createHgRepoAsNeeded
+
 
 	#The as-distributed version of libtool no longer builds dlls with my gcc, it just fails silently. Rebuild
 	libtoolize --install
@@ -876,8 +920,8 @@ function build_qhull2009()
 	automake --add-missing
 
 	#FIXME: Need to change the ptrT type on 64 bit, in mem.h
-	echo "Need to change ptrT, mem.h..."
-	exit 1
+#	echo "Need to change ptrT, mem.h..."
+#	exit 1
 
 	
 	make distclean
@@ -910,15 +954,14 @@ function build_qhull2009()
 
 function build_libvd()
 {
-	echo "FIXME: You need to disable the soname generation in the libvd makefile, otherwise the dll wont load properly"
-	exit 1
-
 	NAME="libvd"
 	ISBUILT_ARG=${NAME}
 	isBuilt
 	if [ $ISBUILT -eq 1 ] ; then
 		return;
 	fi
+	
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd libvd*[0-9]* >/dev/null
 	
@@ -926,10 +969,23 @@ function build_libvd()
 		echo "${NAME} dir missing, or duplicated?"
 		exit 1
 	fi
+	
+	createHgRepoAsNeeded
+	
+	APPLY_PATCH_ARG=$PATCHES_LIBVD
+	applyPatches
+
+
+	#libvd's error.h clashes with system error.h
+	if [ -f error.h ] ; then
+		mv error.h libvdError.h
+	fi
 
 	pushd src/
 	#Make sure we do not pull any VS code in
 	rm -rf msvc
+	#remove code we do not use, and needs to be refactored to compile (throwing errors over library boundary)
+	rm iobmp.cpp ioavi.cpp editor.cpp displayhistogram.cpp iopgm.cpp clip.cpp
 
 
 	make clean
@@ -947,6 +1003,14 @@ function build_libvd()
 	# however I have not yet made a patch for this
 	LDFLAGS="-L/home/pcuser/mingw64/lib/ -lopengl32 -lglu32 -lglew32 -lstdc++" make || { echo "libvd compilation failed"; exit 1; }
 
+	mkdir -p libvd/display ; 
+	
+	for i in `find ./ -name \*.h | grep -v tools | grep -v test | grep -v doc | grep -v io/ | grep -v libvd | sed 's@^./@@' `; 
+	do 
+		cp $i libvd/$i; 
+	done
+
+	popd
 	popd
 
 	FIX_LA_FILE_ARG=libvd
@@ -966,6 +1030,7 @@ function build_qhull2015b()
 		return;
 	fi
 	
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd qhull-* >/dev/null
 	
@@ -973,6 +1038,8 @@ function build_qhull2015b()
 		echo "qhull dir missing, or duplicated?"
 		exit 1
 	fi
+	
+	createHgRepoAsNeeded
 
 	rm -f CMakeCache.txt
 	cmake -DCMAKE_INSTALL_PREFIX="$BASE" -DCMAKE_TOOLCHAIN_FILE=../../patches/cmake-toolchain$BITS_VAL 
@@ -995,6 +1062,7 @@ function build_expat()
 	if [ $ISBUILT -eq 1 ] ; then
 		return;
 	fi
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd expat-** >/dev/null
 	
@@ -1003,6 +1071,8 @@ function build_expat()
 		exit 1
 	fi
 
+	createHgRepoAsNeeded
+
 	./configure --host=$HOST_VAL --enable-shared --disable-static --prefix=/ || { echo "$NAME configure failed"; exit 1; } 
 
 	make -j $NUM_PROCS || { echo "$NAME build failed"; exit 1; } 
@@ -1031,6 +1101,7 @@ function build_gsl()
 		return;
 	fi
 	
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd gsl-* >/dev/null
 		
@@ -1039,6 +1110,8 @@ function build_gsl()
 		exit 1
 	fi
 
+	createHgRepoAsNeeded
+
 	make clean
 
 	mkdir -p doc
@@ -1075,6 +1148,7 @@ function build_wx()
 		return;
 	fi
 	
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd wx[Ww]idgets* >/dev/null
        	
@@ -1182,6 +1256,8 @@ function build_freetype()
 	if [ $ISBUILT -eq 1 ] ; then
 		return;
 	fi
+	
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd freetype-* >/dev/null
 		
@@ -1246,6 +1322,7 @@ function build_libiconv()
 		return;
 	fi
 
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd libiconv-* >/dev/null
 		
@@ -1256,6 +1333,8 @@ function build_libiconv()
 
 	APPLY_PATCH_ARG=$PATCHES_ICONV
 	applyPatches
+	
+	createHgRepoAsNeeded
 
 	make clean
 
@@ -1282,6 +1361,8 @@ function build_gettext()
 	if [ $ISBUILT -eq 1 ] ; then
 		return;
 	fi
+	
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd gettext-* >/dev/null
 		
@@ -1295,6 +1376,8 @@ function build_gettext()
 	APPLY_PATCH_ARG=$PATCHES_GETTEXT
 	applyPatches
 	automake
+	
+	createHgRepoAsNeeded
 
 	#The CFlags/cxxflags thing is due to a really old gettext bug
 	# (who is maintaining that these days? the fix is known for years!) 
@@ -1339,6 +1422,8 @@ function build_mathgl()
 	if [ $ISBUILT -eq 1 ] ; then
 		return;
 	fi
+	
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd mathgl-* >/dev/null
 	
@@ -1356,6 +1441,8 @@ function build_mathgl()
 		exit 1
 	fi
 
+	createHgRepoAsNeeded
+
 	rm -f CMakeCache.txt
 	LIBS=-lpng cmake -Denable-gsl="yes" -Denable-jpeg="no" -Denable-mpi="no" -Denable-ltdl="no" -Denable-python="no"  -DCMAKE_INSTALL_PREFIX="$BASE" -DCMAKE_TOOLCHAIN_FILE=../../patches/cmake-toolchain$BITS_VAL -DPNG_PNG_INCLUDE_DIR=${BASEDIR}/include/
 
@@ -1386,6 +1473,7 @@ function build_libvigra()
 	if [ $ISBUILT -eq 1 ] ; then
 		return;
 	fi
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd libvigraimpex-* >/dev/null
 	
@@ -1397,6 +1485,8 @@ function build_libvigra()
 
 	APPLY_PATCH_ARG=$PATCHES_LIBVIGRA
 	applyPatches
+	
+	createHgRepoAsNeeded
 
 	cmake -DCMAKE_INSTALL_PREFIX="$BASE" -DCMAKE_TOOLCHAIN_FILE=../../patches/cmake-toolchain$BITS_VAL -DPNG_PNG_INCLUDE_DIR=${BASE}/include/
 
@@ -1421,6 +1511,7 @@ function build_ftgl()
 	if [ $ISBUILT -eq 1 ] ; then
 		return;
 	fi
+	echo Building $NAME
 	pushd deps >/dev/null
 	pushd ftgl-* >/dev/null
 	
@@ -1450,6 +1541,7 @@ function build_ftgl()
 	sed -i 's/return gluNewTess ()/return 0;/' configure
 	sed -i 's/return glBegin(GL_POINTS)/return 0;/' configure
 
+	createHgRepoAsNeeded
 
 	FTFLAG=-I${BASE}/include/freetype2/
 
@@ -1574,7 +1666,13 @@ function build_3Depict()
 	autoreconf
 	automake --add-missing
 
-	CONF_FLAG="--host=$HOST_VAL --with-libqhull-link=-lqhull_r --enable-sweep-hull --enable-libvd"
+	CONF_FLAG="--host=$HOST_VAL "
+
+	ENABLE_LIBVD=1
+	if [ $ENABLE_LIBVD -ne 0 ] ; then
+		CONF_FLAG="$CONF_FLAG --enable-libvd"
+	fi
+
 	if [ $IS_RELEASE -ne 0 ] ; then
 		CONF_FLAG="$CONF_FLAG --disable-debug-checks --enable-openmp-parallel"
 	fi
@@ -1655,7 +1753,8 @@ function build_3Depict()
 	#change the install dir
 	sed -i "s@/usr/share/@${BASE}/code/3Depict/@" makeTranslations 
 
-	./makeTranslations install || { echo "Translation build failed."; exit 1; }
+	./makeTranslations || { echo "Translation build failed."; exit 1; }
+	./makeTranslations install || { echo "Translation install failed."; exit 1; }
 	popd
 
 	popd > /dev/null
@@ -1684,6 +1783,19 @@ function make_package()
 		fi
 	fi
 
+	if [ ! -f data/textures/tex-source/3Depict-icon-hires.png ] ; then
+	
+		pushd data/textures/tex-source/
+		if [ x"`which rsvg-convert`" == x"" ] ; then
+			echo "Hi res icon has not been made. Typically 640x530 or similar, should be generated from the 3Depict icon svg. Do this, then re-run, or install rsvg-convert for auto-generation"
+			exit 1;
+		else
+			rsvg-convert -w 640 3Depict-icon.svg 3Depict-icon-hires.png
+
+		fi
+		popd
+	fi
+
 	mkdir locale
 
 	#Copy locales (eg wxstd.mo)
@@ -1782,7 +1894,7 @@ function make_package()
 		popd > /dev/null
 	fi
 
-	#Check for differeent DLL types (eg 32/64)
+	#Check for different DLL types (eg 32/64)
 	DLL_FILE_OUT="";
 	for i in $FOUND_DLLS
 	do
@@ -1802,6 +1914,9 @@ function make_package()
 		exit 1
 	fi
 
+	
+
+
 	#Insert DLL names automatically
 	cp windows-installer.nsi tmp.nsi
 	echo $FOUND_DLLS | sed 's/ /\n/g' |  sed 's@^@  File \"src\\@' | sed 's/$/\"/' > tmp-insert
@@ -1830,7 +1945,7 @@ function make_package()
 		TARGET_FILE=3Depict-${VERSION}-${HOST_EXT}-debug.exe
 	fi
 	
-	mv Setup.exe  $TARGET_FILE
+	mv 3Depict-setup.exe  $TARGET_FILE || { echo " Failed copy at `pwd`"; exit 1; }
 	echo "File written to : `pwd`/$TARGET_FILE"
 	echo "-------------------"
 	
@@ -1871,8 +1986,10 @@ function run_wine()
 		fi
 	fi
 
+	echo "Removing old installation"
 	#Remove any old code
 	rm -rf "${WINEPREFIX}/drive_c/Program\ Files/3Depict/"
+	echo "Unpacking"
 	#unpack installer using wine 
 	wine ${BASE}/code/3Depict/${TARGET_FILE}
 	#run program
@@ -1942,7 +2059,7 @@ build_libpng
 build_libjpeg
 build_libxml2
 build_gsl
-#build_qhull2009 
+build_qhull2009 
 #build_qhull2015
 build_expat
 build_freetype  
@@ -1956,6 +2073,8 @@ build_mathgl
 build_wx
 build_libvd 
 
+echo "BUILDING 3DEPICT"
+sleep 1
 
 build_3Depict
 
