@@ -36,6 +36,13 @@
 #include "testing/testing.h"
 #include "testing/filtertesting.h"
 
+//GSL error handler
+#include "common/gsl_helper.h"
+
+using std::cerr;
+using std::endl;
+using std::string;
+
 enum
 {
 	ID_MAIN_WINDOW=wxID_ANY+1,
@@ -76,6 +83,18 @@ public:
 
 };
 
+//Wayland is a PITA - no opengl support in GTK3 or higher, so we have to disable wayland
+// See https://trac.wxwidgets.org/ticket/17702
+#ifdef __WXGTK3__
+struct ForceX11 {
+    ForceX11() {
+       setenv("GDK_BACKEND", "x11", 1);
+    }
+};
+
+static struct ForceX11 forcex11;
+#endif
+
 //Check version is in place because wxT is deprecated for wx 2.9
 //Command line parameter table
 static const wxCmdLineEntryDesc g_cmdLineDesc [] =
@@ -114,7 +133,7 @@ threeDepictApp::threeDepictApp()
 #ifndef DEBUG
 	wxSetAssertHandler(NULL);
 #else
-	cerr << "Running debug mode (" << PROGRAM_VERSION << ")" << endl;
+	cerr << "Running debug mode (" << PROGRAM_VERSION << ")" << __DATE__ << endl;
 #endif
 	redirectWxLogging();
 }
@@ -136,7 +155,7 @@ void threeDepictApp::redirectWxLogging()
         wxStandardPaths &paths = wxStandardPaths::Get();
 	wxString filePath = paths.GetDocumentsDir();
 	filePath+=("/.")+string(PROGRAM_NAME) + string("log.txt");
-	debugLogStream.open(filePath.c_str());
+	debugLogStream.open((const char*)filePath.c_str());
 
 	if(!debugLogStream)
 		wxLog::EnableLogging(false);	
@@ -372,15 +391,15 @@ bool threeDepictApp::OnCmdLineParsed(wxCmdLineParser& parser)
 				}
 
 				//Run a refresh over the filter tree as a test
-				FilterTree f;
-				visControl.state.treeState.cloneFilterTree(f);
-				if(f.hasHazardousContents())
+				FilterTree fTree;
+				visControl.state.treeState.cloneFilterTree(fTree);
+				if(fTree.hasHazardousContents())
 				{
-					f.stripHazardousContents();
+					fTree.stripHazardousContents();
 					std::cerr << "For security reasons, the tree was pruned prior to execution." << std::endl;
 				}
 				
-				if(!testFilterTree(f))
+				if(!testFilterTree(fTree))
 				{
 					std::cerr << "Failed loading :" << strFile << " , aborting" << std::endl;
 					return false;
@@ -459,6 +478,9 @@ bool threeDepictApp::OnInit()
 #if defined(DEBUG) && defined(__linux__)
 	//Virtualbox has a bug, where the video driver generates FPEs
 //   trapfpe(); //Under Linux, enable  segfault on invalid floating point operations
+
+    //Set the GSL handler to use ASSERT()
+    gsl_set_error_handler(gsl_catch_errors);
 #endif
 
 
