@@ -121,7 +121,7 @@ unsigned int polyFitData(const vector<float> &obsX, const vector<float> &obsY,
 unsigned int readOps(const char *file, 
 		THREEDAP_EXPERIMENT &data, 
 			unsigned int &badLine, unsigned int &progress, 
-			ATOMIC_BOOL &wantAbort, bool strictMode=false)
+			std::atomic<bool> &wantAbort, bool strictMode=false)
 {
 
 	COMPILE_ASSERT(THREEDEP_ARRAYSIZE(OPS_ENUM_ERRSTRINGS) == OPSREADER_ENUM_END);
@@ -634,7 +634,7 @@ void cylinderReconstruct(const THREEDAP_EXPERIMENT &experiment,
 }
 
 
-unsigned int reconstruct3DapData(const char *file, const THREEDAP_RECON_PARAMS &params,unsigned int &progress, ATOMIC_BOOL &wantAbort, std::vector<IonHit> &ionData)
+unsigned int reconstruct3DapData(const char *file, const THREEDAP_RECON_PARAMS &params,unsigned int &progress, std::atomic<bool> &wantAbort, std::vector<IonHit> &ionData)
 {
 	unsigned int errCode;
 	unsigned int badLine;
