@@ -70,7 +70,7 @@ struct THREEDAP_RECON_PARAMS
 //!Reconstruct an "OPS" formatted file (from a 3Dap) to an IonHit vector
 unsigned int reconstruct3DapData(const char *file, 
 	const THREEDAP_RECON_PARAMS &params, 
-	unsigned int &progress, ATOMIC_BOOL &wantAbort,
+	unsigned int &progress, std::atomic<bool> &wantAbort,
 	std::vector<IonHit> &ionData);
 
 #endif
