@@ -128,7 +128,7 @@ const char *TAPSIM_ERR_STRINGS[] = {"",
 #define USE_SEEKING_LIMITLOAD
 #if defined(USE_SEEKING_LIMITLOAD)
 unsigned int LimitLoadPosFile(unsigned int inputnumcols, unsigned int outputnumcols, const unsigned int index[], vector<IonHit> &posIons,const char *posFile, size_t limitCount,
-	       	unsigned int &progress, ATOMIC_BOOL &wantAbort,bool strongSampling)
+	       	unsigned int &progress, std::atomic<bool> &wantAbort,bool strongSampling)
 {
 
 	//Function is only defined for 4 columns here.
@@ -291,7 +291,7 @@ unsigned int LimitLoadPosFile(unsigned int inputnumcols, unsigned int outputnumc
 }
 #else
 unsigned int LimitLoadPosFile(unsigned int inputnumcols, unsigned int outputnumcols, const unsigned int index[], vector<IonHit> &posIons,const char *posFile, size_t limitCount,
-	       	unsigned int &progress, ATOMIC_BOOL &wantAbort,bool strongSampling)
+	       	unsigned int &progress, std::atomic<bool> &wantAbort,bool strongSampling)
 {
 	//Function is only defined for 4 columns here.
 	ASSERT(outputnumcols == 4);
@@ -451,7 +451,7 @@ unsigned int LimitLoadPosFile(unsigned int inputnumcols, unsigned int outputnumc
 
 unsigned int GenericLoadFloatFile(unsigned int inputnumcols, unsigned int outputnumcols, 
 		const unsigned int index[], vector<IonHit> &posIons,const char *posFile, 
-			unsigned int &progress, ATOMIC_BOOL &wantAbort)
+			unsigned int &progress, std::atomic<bool> &wantAbort)
 {
 	ASSERT(outputnumcols==4); //Due to ionHit.setHit
 	//buffersize must be a power of two and at least sizeof(float)*outputnumCols
@@ -611,7 +611,7 @@ unsigned int GenericLoadFloatFile(unsigned int inputnumcols, unsigned int output
 //TODO: Add progress
 unsigned int limitLoadTextFile(unsigned int maxCols, 
 			vector<vector<float> > &data,const char *textFile, const char *delim, const size_t limitCount,
-				unsigned int &progress, ATOMIC_BOOL &wantAbort,bool strongRandom)
+				unsigned int &progress, std::atomic<bool> &wantAbort,bool strongRandom)
 {
 	ASSERT(maxCols);
 	ASSERT(textFile);
@@ -864,7 +864,7 @@ unsigned int limitLoadTextFile(unsigned int maxCols,
 
 
 
-unsigned int LoadATOFile(const char *fileName, vector<IonHit> &ions, unsigned int &progress, ATOMIC_BOOL &wantAbort,unsigned int forceEndian)
+unsigned int LoadATOFile(const char *fileName, vector<IonHit> &ions, unsigned int &progress, std::atomic<bool> &wantAbort,unsigned int forceEndian)
 {
 	//open pos file
 	std::ifstream CFile(fileName,std::ios::binary);
@@ -898,8 +898,6 @@ unsigned int LoadATOFile(const char *fileName, vector<IonHit> &ions, unsigned in
 	// we assume that the endian-ness must be auto-detected somehow, as no sources
 	// agree on file endian-ness. If we cannot detect it, we assume little endian
 
-	//Known versions of file : 2, 5
-
 	//Header (8 bytes), record 14 entries, 4 bytes each
 
 	const size_t LAWATAP_ATO_HEADER_SIZE=8;
@@ -1125,7 +1123,7 @@ unsigned int LoadATOFile(const char *fileName, vector<IonHit> &ions, unsigned in
 }
 
 //Load a TAPSIM Binfile, which is the input geometry format for TAPSIM
-unsigned int loadTapsimBinFile(const char *fileName, unsigned int &progress, ATOMIC_BOOL &wantAbort, vector<IonHit> &posIons)
+unsigned int loadTapsimBinFile(const char *fileName, unsigned int &progress, std::atomic<bool> &wantAbort, vector<IonHit> &posIons)
 {
 	ifstream f(fileName,std::ios::binary); 
 
@@ -1345,7 +1343,7 @@ bool testATOFormat()
 	unsigned int dummyProgress;
 
 
-	ATOMIC_BOOL wantAbort;
+	std::atomic<bool> wantAbort;
 	wantAbort=false;
 	vector<IonHit> ions;
 	//Load using auto-detection of endinanness
