@@ -689,7 +689,6 @@ bool RangeFile::openGuessFormat(const char *rangeFilename)
 
 		if(!open(rangeFilename,ui))
 		{
-			assumedFileFormat=ui;
 			openOK=true;
 			break;
 		}
@@ -2764,10 +2763,10 @@ bool RangeFile::isRanged(string shortName, bool caseSensitive)
 			
 			bool next;
 			next=false;
-			for(unsigned int ui=str.size(); ui--; )
+			for(unsigned int uj=str.size(); uj--; )
 			{
-				if(tolower(str[ui]) != 
-					tolower(shortName[ui]))
+				if(tolower(str[uj]) != 
+					tolower(shortName[uj]))
 				{
 					next=true;
 					break;
