@@ -47,7 +47,32 @@ enum{
 	RANGE_ERR_DATA_NOMAPPED_IONNAME,
 	RANGE_ERR_NONUNIQUE_POLYATOMIC,
 	RANGE_ERR_FILESIZE,
-	RANGE_ERR_ENUM_END
+
+	RANGE_ERR_DASHHEADER,
+	RANGE_ERR_IONBLOCK_CONTENT,
+	RANGE_ERR_NUMIONS,
+	RANGE_ERR_NUMIONS_DUPLICATED,
+	RANGE_ERR_TOO_MANYIONS,
+	RANGE_ERR_ION_BLOCK_NOT_PRESENT,
+	RANGE_ERR_DUPLICATE_NUMRANGES,
+	RANGE_ERR_NUMRANGE_PARSE,
+	RANGE_ERR_RRNG_IONS_TOOSHORT,
+	RANGE_ERR_RRNG_COLON_SEPARATOR,
+	RANGE_ERR_BADCOLOUR,
+	RANGE_ERR_ION_NOT_MAPPED,
+	RANGE_ERR_BADSTART,
+	RANGE_ERR_BADEND,
+	RANGE_ERR_NAME_EMPTY,
+	RANGE_ERR_BAD_LINE_RANGEBLOCK,
+	RANGE_ERR_MISSING_IONBLOCK,
+	RANGE_ERR_NO_RANGES,
+	RANGE_ERR_NO_BASIC_IONS,
+	RANGE_ERR_MISMATCHED_NUMRANGES,
+	RANGE_ERR_RANGEBLOCK_FORMAT,
+	RANGE_ERR_BAD_MULTIPLICITY,
+	RANGE_ERR_VOLUME_PARSE,
+
+	RANGE_ERR_ENUM_END,
 };
 
 
@@ -65,27 +90,26 @@ enum{ RANGE_FORMAT_ORNL,
 class RangeFile
 {
 	private:
-		//These vectors will contain the number of ions
-		
-		//The first element is the shortname for the Ion
-		//the second is the full name
+		//!The names of each ion 
+		/*!The first element is the shortname for the ion
+		  and the second is the full name*/
 		std::vector<std::pair<std::string,std::string> > ionNames;
-		//This holds the colours for the ions
+		//This holds the colours for the ions, one per ion
 		std::vector<RGBf> colours;
 		
-		//This will contains the number of ranges
-		//
-		//This holds the min and max masses for the range
+		//!This holds the min and max masses for the range, one per range
 		std::vector<std::pair<float,float> > ranges;
 		//The ion ID number for each range 
-		//FIXME: Convert to proper uniqueID system
-		std::vector<size_t> ionIDs;
+		std::vector<unsigned int> ionIDs;
 
-		//Should we enforce range consistency?
+		//!volume information for range. Can either be empty (no information) or can contain zeros (no information, or no volume) 
+		std::vector<float> rangeVolumes;
+
+		//!Should we enforce range consistency?
 		bool enforceConsistency;
 
 		unsigned int errState;
-		//Warning messages, used when loading rangefiles
+		//!Warning messages, used when loading rangefiles
 		std::vector<std::string> warnMessages;
 
 
@@ -122,7 +146,7 @@ class RangeFile
 		// caller must supply and release file pointer
 		unsigned int openENV(FILE *fp);
 
-		//Strip charge state from ENV ion names
+		//!Strip charge state from ENV ion names
 		static std::string envDropChargeState(const std::string &strName);
 
 	public:
@@ -219,14 +243,18 @@ class RangeFile
 		 */	
 		bool rangeByID(std::vector<IonHit> &ionHits,
 					unsigned int range);
+
+
+		//!Range the given ions, allowing only ions in the specified range. Input data will be modified to return result
 		void rangeByRangeID(std::vector<IonHit> &ionHits,
 					unsigned int rangeID);
 		//!Get the short name or long name of a specified ionID
-		/*! Pass shortname=false to retireve the long name 
+		/*! Pass shortname=false to retrieve the long name 
 		 * ionID passed in must exist. No checking outside debug mode
 		 */
 		std::string getName(unsigned int ionID,bool shortName=true) const;
 
+		//!Obtain the short name for a given IonHit. If not ranged, an empty string will be returned
 		std::string getName(const IonHit &ion, bool shortName) const;
 
 		//!set the short name for a given ion	
@@ -243,7 +271,7 @@ class RangeFile
 
 		//!Write the rangefile to the specified output stream (default ORNL format)
 		unsigned int write(std::ostream &o,size_t format=RANGE_FORMAT_ORNL) const;
-		//!WRite the rangefile to a file (ORNL format)
+		//!Write the rangefile to a file (ORNL format)
 		unsigned int write(const char *datafile, size_t format=RANGE_FORMAT_ORNL) const;
 
 		//!Return the atomic number of the element from either the long or short version of the atomic name 
@@ -283,11 +311,11 @@ class RangeFile
 
 		bool setRangeEnd(unsigned int rangeID, float v);
 
-		//Erase given range
-		void eraseRange(size_t rangeId) ;
+		//!Erase given range - this will reorder rangeIDs, so any ids you had previously will not longer be valid
+		void eraseRange(unsigned int rangeId) ;
 
-		//erase given ions and associated rnagefes)
-		void eraseIon(size_t ionId);
+		//!erase given ions and associated ranges)
+		void eraseIon(unsigned int ionId);
 
 		//can we decompose all composed ranges in this file into
 		// other components that already exist within this range?
