@@ -56,8 +56,8 @@ unsigned int vtk_write_legacy(const std::string &filename, unsigned int format,
 
 	if(format != VTK_ASCII)
 	{
-		cerr << "Binary mode is not implemented"
-			<< endl;
+		std::cerr << "Binary mode is not implemented"
+			<< std::endl;
 
 		return VTK_ERR_NOT_IMPLEMENTED;
 	}
@@ -76,32 +76,32 @@ unsigned int vtk_write_legacy(const std::string &filename, unsigned int format,
 	size_t nx,ny,nz;
 	vox.getSize(nx,ny,nz);
 	f << "DATASET RECTILINEAR_GRID\n";
-	f << "DIMENSIONS " << nx << " " << ny << " " << nz << endl;
+	f << "DIMENSIONS " << nx << " " << ny << " " << nz << std::endl;
 
 
-	f << "X_COORDINATES " << nx << " float" << endl;
+	f << "X_COORDINATES " << nx << " float" << std::endl;
 	for(unsigned int ui=0;ui<nx;ui++)
 	{
 		f << vox.getPoint(ui,0,0)[0] << " ";
 	}
-	f << endl; 
+	f << std::endl; 
 	
-	f << "Y_COORDINATES " << ny << " float" << endl;
+	f << "Y_COORDINATES " << ny << " float" << std::endl;
 	for(unsigned int ui=0;ui<ny;ui++)
 	{
 		f << vox.getPoint(0,ui,0)[1] << " ";
 	}
-	f << endl; 
+	f << std::endl; 
 	
-	f << "Z_COORDINATES " << nz << " float" << endl;
+	f << "Z_COORDINATES " << nz << " float" << std::endl;
 	for(unsigned int ui=0;ui<nz;ui++)
 	{
 		f << vox.getPoint(0,0,ui)[2] << " ";
 	}
-	f << endl; 
+	f << std::endl; 
 	
 
-	f << "POINT_DATA " << vox.size() << endl;
+	f << "POINT_DATA " << vox.size() << std::endl;
 	f << "SCALARS masstocharge float\n"; 
 	f << "LOOKUP_TABLE default\n";
 
@@ -118,7 +118,7 @@ unsigned int vtk_read_legacy(const std::string &filename, unsigned int format,
 		Voxels<T> &vox)
 {
 	ASSERT(format == VTK_ASCII);
-	ifstream f;
+	std::ifstream f;
 	f.open(filename.c_str());
 
 	if(!f)
@@ -149,7 +149,7 @@ unsigned int vtk_read_legacy(const std::string &filename, unsigned int format,
 	if(!getline(f,s))
 		return VTK_ERR_FILE_OPEN_FAIL;
 	
-	vector<string> strs;
+	std::vector<std::string> strs;
 	splitStrsRef(s.c_str()," \t",strs);
 
 
@@ -172,7 +172,7 @@ unsigned int vtk_read_legacy(const std::string &filename, unsigned int format,
 
 	
 	//Read the x-y-z coordinates
-	vector<string> strCoords[3];
+	std::vector<std::string> strCoords[3];
 	for(unsigned int ui=0;ui<3;ui++)
 	{
 		if(!getline(f,s))
