@@ -25,8 +25,16 @@
 
 #include "common/voxels.h"
 #include "common/colourmap.h"
-#include "backend/APT/vtk.h"
+#include "APT/vtk.h"
+#include "stats/erfinv.h"
+#include "stats/confidence.h"
 
+//toolchain for mingw-w64 does not support std::mutex
+// the -posix variety, available from update-alternatives
+// apparently does however.
+#ifndef WIN32
+std::mutex mtxProgress;
+#endif
 
 #include <set>
 #include <deque>
@@ -42,13 +50,10 @@ using std::pair;
 using std::make_pair;
 using std::endl;
 using std::deque;
-
-
-
-std::mutex mtxProgress;
+using std::map;
 
 bool Filter::strongRandom= false;
-ATOMIC_BOOL *Filter::wantAbort= nullptr;
+std::atomic<bool> *Filter::wantAbort= nullptr;
 
 const char *STREAM_NAMES[] = { NTRANS("Ion"),
 				NTRANS("Plot"),
@@ -549,7 +554,9 @@ PlotStreamData::PlotStreamData() :  r(1.0f),g(0.0f),b(0.0f),a(1.0f),
 	index((unsigned int)-1)
 {
 	streamType=STREAM_TYPE_PLOT;
-	errDat.mode=PLOT_ERROR_NONE;
+	//Filter output's error method
+	errorMode=PlotStreamData::ERROR_MODE_NONE;
+	confidenceVal=0.95;
 
 	for(unsigned int ui=0;ui<2;ui++)
 	{
@@ -584,6 +591,165 @@ bool PlotStreamData::getPlotBoundActive(unsigned int axis, unsigned int offset)
 	return plotBoundsActive[axis][offset];
 }
 
+void PlotStreamData::computeErrors(float alpha, vector<pair<float,float > > &vals,
+			bool correctFamilyWise) const
+{
+	vals.resize(xyData.size());
+	if(errorMode == PlotStreamData::ERROR_MODE_MOVING_AVERAGE)
+	{
+		//This is a totally different way of error estimation
+	
+		//FIXME: Has contiguous assumption implicit
+		ASSERT(movingAverageNum > 1);
+		for(int ui=0;ui<(int)xyData.size();ui++)
+		{
+			float mean;
+			mean=0.0f;
+
+			//Compute the local mean
+			for(int uj=0;uj<(int)movingAverageNum;uj++)
+			{
+				//Use int, as there can be an underflow
+				int idx;
+				idx= std::max(ui+uj-(int)movingAverageNum/2,0);
+				idx=std::min(idx,(int)(xyData.size()-1));
+				ASSERT(idx<(int)xyData.size());
+				mean+=xyData[idx].second;
+			}
+
+			mean/=(float)movingAverageNum;
+
+			//Compute the local stddev
+			float stddev;
+			stddev=0;
+			for(int uj=0;uj<(int)movingAverageNum;uj++)
+			{
+				int idx;
+				idx= std::max(ui+uj-(int)movingAverageNum/2,0);
+				idx=std::min(idx,(int)(xyData.size()-1));
+				stddev+=(xyData[idx].second-mean)*(xyData[idx].second-mean);
+			}
+
+			stddev=sqrtf(stddev/(float)movingAverageNum);
+			vals[ui]=make_pair(stddev,stddev);
+		}
+
+		return;
+
+	}
+
+	ASSERT(alpha > 0.0f && alpha <1.0f);
+
+	//Perform a Sidak correction for familywise error
+	// per-line
+	if(correctFamilyWise)
+	{
+		//FIXME: Implement me
+		alpha  = 1.0-pow(1.0-alpha,1/xyData.size());
+		ASSERT(false);
+	}
+
+	//If using a numerical estimator for error, the number of trials to perform, per bin
+	const unsigned int TRIALS=1000;
+	gsl_rng *rng =gsl_rng_alloc(gsl_rng_mt19937);
+	auto t = std::chrono::system_clock::now();
+
+	time_t tt  =std::chrono::system_clock::to_time_t(t);
+	//FIXME: This should be user exposed
+	gsl_rng_set(rng, tt);                  // set seed
+	
+	switch(errorMode)
+	{
+		case ERROR_MODE_GAUSS:
+		{
+			ASSERT(yErrParams.size() == xyData.size());
+			float nStdDeviations;
+			// Its P=erf(n/sqrt(2)), so sqrt(2)*erfinv(P)=n
+			nStdDeviations=sqrt(2.0f)*erfinv(alpha);
+
+			//Gaussian variance is sqrt(variance), in limit as poisson -> gaussian
+			// https://www.roe.ac.uk/japwww/teaching/astrostats/astrostats2012_part2.pdf
+			ASSERT(yErrParams.size());
+			for(auto ui=0;ui<xyData.size();ui++)
+				vals[ui].second=vals[ui].first=nStdDeviations*sqrt(yErrParams[ui]);
+			break;
+		}
+		case ERROR_MODE_POISSON:
+		{
+			ASSERT(yErrParams.size() == xyData.size());
+			for(auto ui=0;ui<xyData.size();ui++)
+			{
+				float lBound,uBound;
+				poissonConfidenceLimit(yErrParams[ui],alpha,lBound,uBound);
+				vals[ui]=std::make_pair(yErrParams[ui]-lBound,uBound - yErrParams[ui]);
+			}
+
+			break;
+		}
+		case ERROR_MODE_GAUSS_RATIO:
+		{
+			ASSERT(yErrTwoParams.size() == xyData.size());
+			for(auto ui=0;ui<xyData.size();ui++)
+			{
+				float lBound,uBound;
+
+				//Use Gaussian ratio, assuming that the Poisson observed counts
+				// have same mean & variance, and a G is a good approx
+				if(!numericalEstimateGaussRatioConf(yErrTwoParams[ui].first,
+					yErrTwoParams[ui].second, (yErrTwoParams[ui].first),
+					(yErrTwoParams[ui].second),
+					alpha,TRIALS,rng,lBound,uBound))
+				{
+					lBound=std::numeric_limits<float>::quiet_NaN();
+					uBound=std::numeric_limits<float>::quiet_NaN();
+				}
+				else
+				{
+					//convert to delta
+					float ratio;
+					ratio = yErrTwoParams[ui].first/yErrTwoParams[ui].second;
+					lBound=ratio-lBound;
+					uBound=uBound - ratio;
+				}
+				vals[ui] = std::make_pair(lBound,uBound);
+
+			}
+			break;
+		}
+		case ERROR_MODE_POISSON_RATIO:
+		{
+			ASSERT(yErrTwoParams.size() == xyData.size());
+			//Create and seed the random number generator
+
+			for(auto ui=0;ui<xyData.size();ui++)
+			{
+				float lBound,uBound;
+				if(!numericalEstimatePoissRatioConf(yErrTwoParams[ui].first,
+					yErrTwoParams[ui].second,alpha,TRIALS,rng,lBound,uBound))
+				{
+					lBound=std::numeric_limits<float>::quiet_NaN();
+					uBound=std::numeric_limits<float>::quiet_NaN();
+				}
+				else
+				{
+					//convert to delta
+					float ratio;
+					ratio = yErrTwoParams[ui].first/yErrTwoParams[ui].second;
+					lBound=ratio-lBound;
+					uBound=uBound - ratio;
+				}
+
+				vals[ui] = std::make_pair(lBound,uBound);
+
+			}
+			break;
+		}
+		default:
+			ASSERT(false);
+	}
+	gsl_rng_free(rng);
+}
+
 
 bool PlotStreamData::save(const char *filename) const
 {
@@ -605,7 +771,7 @@ bool PlotStreamData::save(const char *filename) const
 		pendingEndl=true;
 	}
 
-	if(errDat.mode==PLOT_ERROR_NONE)
+	if(errorMode==PlotStreamData::ERROR_MODE_NONE)
 	{
 		if(pendingEndl)
 			f << endl;
@@ -614,6 +780,7 @@ bool PlotStreamData::save(const char *filename) const
 	}
 	else
 	{
+		ASSERT(false); // FIXME: Update to new error mode
 		if(pendingEndl)
 		{
 			f << "\t" << TRANS("Error") << endl;
@@ -645,7 +812,25 @@ void PlotStreamData::checkSelfConsistent() const
 	//Must have valid trace style
 	ASSERT(plotStyle<PLOT_TYPE_ENUM_END);
 	//Must have valid error bar style
-	ASSERT(errDat.mode<PLOT_ERROR_ENDOFENUM);
+	ASSERT(errorMode<PlotStreamData::ERROR_MODE_END);
+	//Must have valid confidence interval
+	ASSERT(confidenceVal < 1.0f && confidenceVal > 0.5f);
+	//Must have  yErrTwoParams or yErrParams if errorMode set to 
+	// parameter based error
+	switch(errorMode)
+	{
+		//1-parameter error estimators
+		case PlotStreamData::ERROR_MODE_GAUSS:
+		case PlotStreamData::ERROR_MODE_POISSON:
+			ASSERT(yErrParams.size() == xyData.size());
+			break;
+		//2-parameter error estimators
+		case PlotStreamData::ERROR_MODE_GAUSS_RATIO:
+		case PlotStreamData::ERROR_MODE_POISSON_RATIO:
+			ASSERT(yErrTwoParams.size() == xyData.size());
+			break;
+
+	}
 
 	ASSERT(plotMode <PLOT_MODE_ENUM_END);
 
@@ -832,6 +1017,7 @@ unsigned int IonStreamData::exportStreams(const std::vector<const FilterStreamDa
 				{
 					const IonStreamData *ionData;
 					ionData=((const IonStreamData *)selectedStream);
+					ionvec.reserve(ionvec.size() + ionData->data.size());
 					for(const auto & data : ionData->data)
 						ionvec.push_back(data);
 					break;
@@ -1059,9 +1245,9 @@ Filter::Filter() : cache(true), cacheOK(false)
 Filter::~Filter()
 {
     if(cacheOK)
-	    clearCache();
+	    this->clearCache();
 
-    clearDevices();
+    this->clearDevices();
 }
 
 void Filter::setPropFromRegion(unsigned int method, unsigned int regionID, float newPos)
@@ -1273,7 +1459,9 @@ ProgressData::ProgressData()
 
 bool ProgressData::operator==( const ProgressData &oth) const
 {
+#ifndef WIN32
 	std::lock_guard<std::mutex> g(mtxProgress);
+#endif
 	if(filterProgress!=oth.filterProgress ||
 		(totalProgress!=oth.totalProgress) ||
 		(totalNumFilters!=oth.totalNumFilters) ||
@@ -1289,8 +1477,9 @@ bool ProgressData::operator==( const ProgressData &oth) const
 
 ProgressData::ProgressData(const ProgressData &oth) 
 {
+#ifndef WIN32
 	std::lock_guard<std::mutex> g(mtxProgress);
-	
+#endif	
 	filterProgress=oth.filterProgress ;
 	totalProgress=oth.totalProgress ;
 	totalNumFilters=oth.totalNumFilters ;
@@ -1303,8 +1492,9 @@ ProgressData::ProgressData(const ProgressData &oth)
 
 const ProgressData &ProgressData::operator=(const ProgressData &oth)
 {
+#ifndef WIN32
 	std::lock_guard<std::mutex> g(mtxProgress);
-
+#endif
 	filterProgress=oth.filterProgress;
 	totalProgress=oth.totalProgress;
 	totalNumFilters=oth.totalNumFilters;
@@ -1312,6 +1502,7 @@ const ProgressData &ProgressData::operator=(const ProgressData &oth)
 	maxStep=oth.maxStep;
 	curFilter=oth.curFilter;
 	stepName=oth.stepName;
+	estimatedSteps=oth.estimatedSteps;
 
 	return *this;
 }
