@@ -218,7 +218,7 @@ class FilterStreamData
 		//Cross-checks fields to determine if (best guess)
 		///data structure has a sane combination of values
 		virtual void checkSelfConsistent() const {}
-		virtual const string getName() const =0; 
+		virtual const std::string getName() const =0; 
 #endif
 
 };
@@ -270,7 +270,7 @@ class FilterProperty
 
 	//Initialise choice property 
 	FilterProperty(size_t key, const std::string &name, 
-			std::vector<std::pair<unsigned int, string> > &data, unsigned int selected,
+			std::vector<std::pair<unsigned int, std::string> > &data, unsigned int selected,
 				const std::string &helpText);
 	//Intialise colour property	
 	FilterProperty(size_t key, const std::string &name, 
@@ -375,7 +375,7 @@ public:
 	void estimateIonParameters(const IonStreamData *inputFilter);
 
 #ifdef DEBUG
-		const string getName() const { return "Ion Stream";}; 
+		const std::string getName() const { return "Ion Stream";}; 
 #endif
 };
 
@@ -414,7 +414,7 @@ public:
 	float bBoxR,bBoxG,bBoxB,bBoxA;
 		
 #ifdef DEBUG
-	const string getName() const { return "Voxel Stream";}; 
+	const std::string getName() const { return "Voxel Stream";}; 
 #endif
 };
 
@@ -428,6 +428,18 @@ class PlotStreamData : public FilterStreamData
 		float plotBounds[2][2];
 
 	public:
+		//!Methods of computing error
+		enum
+		{
+			ERROR_MODE_NONE,
+			ERROR_MODE_GAUSS,
+			ERROR_MODE_POISSON,
+			ERROR_MODE_GAUSS_RATIO,
+			ERROR_MODE_POISSON_RATIO,
+			ERROR_MODE_MOVING_AVERAGE,
+			ERROR_MODE_END
+		};
+
 		PlotStreamData();
 		PlotStreamData(const Filter *f);
 		//Write out a text version of this plot into a file
@@ -458,10 +470,19 @@ class PlotStreamData : public FilterStreamData
 
 		//!XY data pairs for plotting curve
 		std::vector<std::pair<float,float> > xyData;
+		//!Method of estimating error from given error data
+		unsigned int errorMode;
+		//!Y-Error data (single-parameter mode). Must be same size as xyData if in use
+		std::vector<float> yErrParams;
+		//!Y-Error data (ratio mode).  Must be same size as xyDat aif in use
+		std::vector<std::pair<float,float> > yErrTwoParams;
 
+		//!Alpha (confidence) value for errors
+		float confidenceVal;
 
 		//!Rectangular marked regions
 		std::vector<std::pair<float,float> > regions;
+		//!The name associated with each region
 		std::vector<std::string> regionTitle;
 		//!Region colours
 		std::vector<float> regionR,regionB,regionG;
@@ -474,8 +495,10 @@ class PlotStreamData : public FilterStreamData
 		Filter *regionParent;
 		//!Parent filter index
 		unsigned int index;
-		//!Error bar mode
-		PLOT_ERROR errDat;
+
+		
+		//!
+		unsigned int movingAverageNum;
 
 		//Set sections of the plot that must be visible
 		// offset=0/1 -> lower/upper, axis=0/1 -> x/y axis, respectively
@@ -484,12 +507,17 @@ class PlotStreamData : public FilterStreamData
 		
 		float getPlotBound(unsigned int axis, unsigned int offset) const;
 		bool getPlotBoundActive(unsigned int axis, unsigned int offset) const;
-		
+	
+		//!Compute the errors associated with  the current error mode and the given confidence value.
+		// returned error bars are positive in each case, or NaN if bound not stably computable
+		void computeErrors(float alpha,
+				std::vector<std::pair<float,float > > &vals,
+				bool correctFamilyWise=false) const;
 #ifdef DEBUG
 		//Cross-checks fields to determine if (best guess)
 		///data structure has a sane combination of values
 		virtual void checkSelfConsistent() const; 
-		const string getName() const { return "Plot Stream";}; 
+		const std::string getName() const { return "Plot Stream";}; 
 #endif
 
 };
@@ -545,7 +573,7 @@ class Plot2DStreamData : public FilterStreamData
 
 #ifdef DEBUG
 		void checkSelfConsistent() const;
-		const string getName() const { return "2DPlot Stream";}; 
+		const std::string getName() const { return "2DPlot Stream";}; 
 #endif
 };
 
@@ -569,7 +597,7 @@ class DrawStreamData: public FilterStreamData
 		//Cross-checks fields to determine if (best guess)
 		///data structure has a sane combination of values
 		void checkSelfConsistent() const; 
-		const string getName() const { return "Draw Stream";}; 
+		const std::string getName() const { return "Draw Stream";}; 
 #endif
 };
 
@@ -601,7 +629,7 @@ class RangeStreamData :  public FilterStreamData
 
 #ifdef DEBUG
 		void checkSelfConsistent() const ; 
-		const string getName() const { return "Range Stream" ;}; 
+		const std::string getName() const { return "Range Stream" ;}; 
 #endif
 };
 
@@ -635,7 +663,7 @@ class Filter
 
 
 		//Convert an internal file string (/ separated) representing a path, to absolute as required. Relative paths should be indicated with a "./"
-		void convertFileStringToAbsolute(const string &basePath, std::string &s) const;
+		void convertFileStringToAbsolute(const std::string &basePath, std::string &s) const;
 
 		//Collate ions from filterstream data into an ionhit vector
 		static unsigned int collateIons(const std::vector<const FilterStreamData *> &dataIn,
@@ -903,7 +931,7 @@ class Filter
 		Filter() ;
 		virtual ~Filter();
 		//Abort pointer . This must be  nonzero during filter refreshes
-		static ATOMIC_BOOL *wantAbort;
+		static std::atomic<bool> *wantAbort;
 
 		//!Obtain the number of progress steps for the refresh (e.g. may have 3 stages of computation)
 		virtual unsigned int getNumSteps() const { return 1; }; 
@@ -959,7 +987,7 @@ class Filter
 		//!Read state from XML  stream, using xml format
 		/* Current supported formats are STATE_FORMAT_XML
 		 */
-		virtual bool readState(xmlNodePtr& n, const std::string &packDir="") = 0; 
+		virtual bool readState(const xmlNodePtr& n, const std::string &packDir="") = 0; 
 		
 		//!Get the bitmask encoded list of filterStreams that this filter blocks from propagation.
 		// i.e. if this filterstream is passed to refresh, it is not emitted.
