@@ -27,7 +27,7 @@ using std::pair;
 
 unsigned int *K3DTreeMk2::progress=0;
 //Pointer for aborting during build process
-ATOMIC_BOOL *K3DTreeMk2::abort=0;
+std::atomic<bool> *K3DTreeMk2::abort=0;
 
 class NodeWalk
 {
