@@ -85,7 +85,7 @@ class K3DTreeMk2
 		BoundCube treeBounds;
 		
 		static unsigned int *progress; //Progress counter
-		static ATOMIC_BOOL *abort; //set to true if build should abort. Must be initalised prior to build
+		static std::atomic<bool> *abort; //set to true if build should abort. Must be initalised prior to build
 
 	public:
 		//KD Tree constructor
@@ -95,7 +95,7 @@ class K3DTreeMk2
 		~K3DTreeMk2(){};
 
 		static void setProgressPtr(unsigned int *ptr){progress=ptr;}
-		static void setAbortFlag(ATOMIC_BOOL *ptr){abort=ptr;}
+		static void setAbortFlag(std::atomic<bool> *ptr){abort=ptr;}
 
 		//Reset the points
 		void resetPts(std::vector<Point3D> &pts, bool clear=true);
