@@ -104,7 +104,7 @@ class K3DTree
 		size_t curNodeCount; //Counter for build operations
 
 		static unsigned int *progress; //Progress counter
-		static const ATOMIC_BOOL *abort; //aborting flag
+		static const std::atomic<bool> *abort; //aborting flag
 	public:
 	
 		//KD Tree constructor
@@ -114,7 +114,7 @@ class K3DTree
 		~K3DTree();
 
 		static void setProgressPtr(unsigned int *ptr){progress=ptr;}
-		static void setAbortFlag(const ATOMIC_BOOL *ptr){abort=ptr;}
+		static void setAbortFlag(const std::atomic<bool> *ptr){abort=ptr;}
 	
 		/*! Builds a balanced KD tree from a list of points
 		 * This call is being passed by copy in order to prevent
