@@ -548,10 +548,10 @@ void generateTestGridEntries(vector<GRID_ENTRY> &gridEntries, unsigned int &nSel
 	nSelected=2;
 
 	gsl_rng *r=gsl_rng_alloc(gsl_rng_ranlxs2);
-	timeval tv;
-	gettimeofday(&tv,NULL);
-	long seed =tv.tv_usec+tv.tv_sec; 
-	gsl_rng_set(r, seed);                  // set seed
+	auto t = std::chrono::system_clock::now();
+
+	time_t tt  =std::chrono::system_clock::to_time_t(t);
+	gsl_rng_set(r, tt);                  // set seed
 
 	gridEntries.resize(NSAMPLE);
 
