@@ -26,308 +26,6 @@ using std::vector;
 using std::set;
 
 
-//! Returns the shortest distance between a line segment and a given point
-/* The inputs are the ends of the line segment and the point. Uses the formula that 
- * \f$ 
- * D = \abs{\vec{PE}}\f$
- * \f[ 
- * \mathrm{~if~} \vec{PA} \cdot \vec{AB} > 0 
- * \rightarrow \vec{PE} = \vec{A} 
- * \f]
- * \f[
- * \mathrm{~if~} \vec{AB} \cdot \vec{PB} > 0 ~\&~ \vec{PA} \cdot \vec{AB} < 0
- * \rightarrow \vec{PB} \cdot \frac{\vec{AB}}{\abs{\vec{AB}}} 
- * \f]
- * \f[
- * \mathrm{~if~} \vec{PB} \cdot \vec{AB} < 0 
- * \rightarrow \vec{B} 
- * \f]
- */
-float distanceToSegment(const Point3D &fA, const Point3D &fB, const Point3D &p)
-{
-
-	//If the vectors a pointing "together" then use  point-line formula
-	if(vectorPointDir(fA,fB,p,p) == POINTDIR_TOGETHER)
-	{
-		Point3D closestPt;
-		Point3D vAB= fB-fA;
-
-		//Use formula d^2 = |(B-A)(cross)(A-P)|^2/|B-A|^2
-		return sqrtf( (vAB.crossProd(fA-p)).sqrMag()/(vAB.sqrMag()));
-	}
-
-	return sqrtf( std::min(fB.sqrDist(p), fA.sqrDist(p)) );
-}
-
-
-//!Find the distance between a point, and a triangular facet -- may be positive or negative
-/* The inputs are the facet points (ABC) and the point P.
- * distance is shortest using standard plane version 
- * \f$ D = \vec{AB} \cdot \vec{n} \f$ 
- * iff dot products to each combination of \f$ \left( AP,BP,CP \right) \leq 0 \f$
- * otherwise closest point is on the boundary of the simplex.
- * tested by shortest distance to each line segment (E is shortest pt. AB is line segement)
- * \f$ \vec{E} = \frac{\vec{AB}}{|\vec{AB}|} 
- *  ( \vec{PB} \cdot \vec{AB})\f$
- */
-float distanceToFacet(const Point3D &fA, const Point3D &fB, 
-			const Point3D &fC, const Point3D &p, const Point3D &normal)
-{
-
-	//This will check the magnitude of the incoming normal
-	ASSERT( fabs(sqrtf(normal.sqrMag()) - 1.0f) < 2.0* std::numeric_limits<float>::epsilon());
-	unsigned int pointDir[3];
-	pointDir[0] = vectorPointDir(fA,fB,p,p);
-	pointDir[1] = vectorPointDir(fA,fC,p,p);
-	pointDir[2] = vectorPointDir(fB,fC,p,p);
-
-	//They can never be "APART" if the
-	//vectors point to the same pt
-	ASSERT(pointDir[0] != POINTDIR_APART);
-	ASSERT(pointDir[1] != POINTDIR_APART);
-	ASSERT(pointDir[2] != POINTDIR_APART);
-
-	//Check to see if any of them are "in common"
-	if(pointDir[0]  > 0 ||  pointDir[1] >0 || pointDir[2] > 0)
-	{
-		//if so, we have to check each edge for its closest point
-		//then pick the best
-		float bestDist[3];
-		bestDist[0] = distanceToSegment(fA,fB,p);
-		bestDist[1] = distanceToSegment(fA,fC,p);
-		bestDist[2] = distanceToSegment(fB,fC,p);
-	
-
-		return std::min(bestDist[0],std::min(bestDist[1],bestDist[2]));
-	}
-
-	float temp;
-
-	temp = fabs((p-fA).dotProd(normal));
-
-	//check that the other points were not better than this!
-	ASSERT(sqrtf(fA.sqrDist(p)) >= temp - std::numeric_limits<float>::epsilon());
-	ASSERT(sqrtf(fB.sqrDist(p)) >= temp - std::numeric_limits<float>::epsilon());
-	ASSERT(sqrtf(fC.sqrDist(p)) >= temp - std::numeric_limits<float>::epsilon());
-
-	//Point lies above/below facet, use plane formula
-	return temp; 
-}
-
-#ifdef HAVE_SWEEP_HULL
-
-//S-Hull version
-
-float getConvexVolume(const vector<Point3D> &pts, 
-			const vector<HULLTRI> &facets)
-{
-	//Find midpoint
-	Point3D midPt(0,0,0);
-
-	for(unsigned int ui=0;ui<pts.size();ui++)
-		midPt+=pts[ui];
-	midPt*=1.0f/(float)pts.size();
-
-	//Use double to limit accumulation error
-	double totalVol = 0;
-	//The convex hull consists of tetrahedra which are joined to the midpt.
-	//V_tet = \frac(1)(3!) \abs(a\cdot(b \cross c))
-	for(unsigned int ui=0;ui<facets.size();ui++)
-	{
-		Point3D edge[3];
-
-		//Skip bad facets FIXME: This appears to be an upstream problem
-		if(facets[ui].vertex[0] >= pts.size() ||
-				facets[ui].vertex[1] >=pts.size() ||
-				facets[ui].vertex[2] >=pts.size())
-			continue;
-
-		edge[0]  = pts[facets[ui].vertex[0]]-midPt;
-		edge[1]  = pts[facets[ui].vertex[1]]-midPt;
-		edge[2]  = pts[facets[ui].vertex[2]]-midPt;
-
-		totalVol+=fabs(edge[0].dotProd(edge[1].crossProd(edge[2])));
-	}
-
-	totalVol*=1.0f/6.0f;
-	return (float)totalVol;
-}
-
-unsigned int computeConvexHull(const vector<const FilterStreamData*> &data, unsigned int *progress,
-					std::vector<Point3D> &curHull,vector<HULLTRI> &facets)
-{
-
-	BoundCube bCube;
-
-
-	vector<Point3D> pointsOrig;
-	for(unsigned int ui=0;ui<data.size();ui++)
-	{
-		if(data[ui]->getStreamType() != STREAM_TYPE_IONS)
-			continue;
-
-		const IonStreamData *ionD;
-		ionD = (IonStreamData*)data[ui];
-
-		for(unsigned int ui=0;ui<ionD->data.size();ui++)
-		{
-			Point3D p;
-			p = ionD->data[ui].getPos();
-			pointsOrig.push_back(p); 
-		}
-	}
-
-	bCube.setBounds(pointsOrig);
-
-	//FIXME: Remove me
-	//---
-	//Due to a bug when points are in some particular (near-spherical) configurations
-	// the points have to be joggled a little
-	std::random_device rd;
-	std::mt19937 gen(rd());
-	std::uniform_real_distribution<> realV(-1,1);
-
-	vector<R3> pts;
-	pts.resize(pointsOrig.size());
-	for(unsigned int ui=0;ui<pts.size();ui++)
-	{
-		//Noise the points to 1/10,000th of the bbox size
-		pointsOrig[ui]+=Point3D(realV(gen),realV(gen),realV(gen))*bCube.getSize()*1.0/5e3;
-		pts[ui] = R3(pointsOrig[ui][0],pointsOrig[ui][1],pointsOrig[ui][2]);
-	}
-	//---
-
-	//Run the convex hull calculation
-	vector<Tri> hull; 
-	NewtonApple_hull_3D(pts,hull);
-
-
-	//Find all unique points
-	set<size_t> ptIdx;
-	for(unsigned int ui=0;ui<hull.size();ui++)
-	{
-		ptIdx.insert(hull[ui].a);
-		ptIdx.insert(hull[ui].b);
-		ptIdx.insert(hull[ui].c);
-	
-		HULLTRI h;
-		h.vertex[0] = hull[ui].a;
-		h.vertex[1] = hull[ui].b;
-		h.vertex[2] = hull[ui].c;
-		facets.push_back(h);
-	}
-
-	curHull.reserve(ptIdx.size()/3); //This is a guess, depends on ajacency of each vertex
-	for(std::set<size_t>::iterator it=ptIdx.begin(); it!=ptIdx.end();++it)	
-	{
-		curHull.push_back(
-			Point3D(pts[*it].r,pts[*it].c,pts[*it].z));
-	}
-
-	return 0;
-}
-
-unsigned int computeConvexHull(const vector<Point3D> &data, unsigned int *progress,
-				const bool &abortPtr,std::vector<Point3D> &curHull)
-{
-	//Copy the points into the format required by shull
-	vector<R3> pts;
-	pts.resize(data.size());
-	for(unsigned int ui=0;ui<data.size();ui++)
-		pts[ui]=R3(data[ui][0],data[ui][1],data[ui][2]);
-
-	//Run the convex hull calculation
-	vector<Tri> hull; 
-	NewtonApple_hull_3D(pts,hull);
-
-	//Find all unique points
-	set<size_t> ptIdx;
-	for(unsigned int ui=0;ui<hull.size();ui++)
-	{
-		ptIdx.insert(hull[ui].a);
-		ptIdx.insert(hull[ui].b);
-		ptIdx.insert(hull[ui].c);
-	}
-
-	curHull.reserve(ptIdx.size()/3); //This is a guess, depends on ajacency of each vertex
-	for(std::set<size_t>::iterator it=ptIdx.begin(); it!=ptIdx.end();++it)	
-	{
-		curHull.push_back(
-			Point3D(pts[*it].r,pts[*it].c,pts[*it].z));
-	}
-	return 0;
-}
-
-unsigned int do3DDelaunay(vector<Point3D> &pts,
-		vector<size_t> &ta, vector<size_t> &tb, vector<size_t> &tc)
-{
-	vector<R3> inPts;
-	inPts.resize(pts.size());
-#pragma omp parallel  shared(inPts)
-	{
-#pragma omp for
-	for(unsigned int ui=0; ui<pts.size(); ui++)
-		inPts[ui]= R3(pts[ui][0],pts[ui][1],pts[ui][2]);
-
-	vector<Tri> triVec;
-	if(NewtonApple_Delaunay( inPts, triVec) != 1)
-		return 1;
-
-	ta.resize(triVec.size());
-	tb.resize(triVec.size());
-	tc.resize(triVec.size());
-#pragma omp for
-	for(unsigned int ui=0;ui<triVec.size();ui++)
-	{
-		ta[ui]=triVec[ui].a;
-		tb[ui]=triVec[ui].b;
-		tc[ui]=triVec[ui].c;
-	}
-	}
-
-	return 0;
-}
-
-unsigned int do2DDelaunay(double *bufXY, unsigned int n, 
-		vector<size_t> &ta, vector<size_t> &tb, vector<size_t> &tc)
-{
-	vector<R3> inPts;
-	std::random_device rd;
-	std::mt19937 gen(rd());
-	std::uniform_real_distribution<> realV(-0.001,0.001);
-
-	inPts.resize(n);
-	for(unsigned int ui=0; ui<n; ui++)
-	{
-		inPts[ui].r=bufXY[2*ui];
-		inPts[ui].c=bufXY[2*ui+1];
-		inPts[ui].z=realV(gen);
-	}
-	vector<Tri> triVec;
-	if(NewtonApple_Delaunay( inPts, triVec) != 1)
-		return 1;
-
-	ta.resize(triVec.size());
-	tb.resize(triVec.size());
-	tc.resize(triVec.size());
-	for(unsigned int ui=0;ui<triVec.size();ui++)
-	{
-		ta[ui]=triVec[ui].a;
-		tb[ui]=triVec[ui].b;
-		tc[ui]=triVec[ui].c;
-	}
-
-	return 0;
-}
-
-unsigned int GetReducedHullPts(const vector<Point3D> &points, float reductionDim,  
-		unsigned int *progress, ATOMIC_BOOL &wantAbort, vector<Point3D> &pointResult)
-{
-	ASSERT(false); //IMPLEMENT ME
-}
-#else
-
-//QHULL edition
 
 //grab size when doing convex hull calculations
 const unsigned int HULL_GRAB_SIZE=4096;
@@ -920,7 +618,7 @@ void freeConvexHull()
 //it has been shrunk such that the closest distance from the hull to the original data
 //is reductionDim 
 unsigned int GetReducedHullPts(const vector<Point3D> &points, float reductionDim,  
-		unsigned int *progress, ATOMIC_BOOL &wantAbort, vector<Point3D> &pointResult)
+		unsigned int *progress, std::atomic<bool> &wantAbort, vector<Point3D> &pointResult)
 {
 	//TODO: This could be made to use a fixed amount of ram, by
 	//partitioning the input points, and then
@@ -1026,7 +724,7 @@ unsigned int GetReducedHullPts(const vector<Point3D> &points, float reductionDim
 		}
 
 		//Find the distance between hull centroid and a given facet
-		temp = distanceToFacet(vertexPt[0],vertexPt[1],vertexPt[2],hullCentroid,
+		temp = hullCentroid.distanceToFacet(vertexPt[0],vertexPt[1],vertexPt[2],
 					Point3D(curFac->normal[0],curFac->normal[1],curFac->normal[2]));
 
 		if(temp < minDist)
@@ -1113,7 +811,6 @@ reduced_loop_next:
 
 	return 0;
 }
-#endif
 
 
 #ifdef DEBUG
@@ -1192,14 +889,8 @@ bool testConvexHull()
 	dataStream.push_back(d);
 	unsigned int dummyProg;
 	vector<Point3D> hull;
-#ifdef HAVE_SWEEP_HULL
-	vector<HULLTRI> facets;
-	computeConvexHull(dataStream,&dummyProg,hull,facets);
-	TEST(hull.size() == 4,"Hull pt count (sweep-hull)");
-#else
 	computeConvexHull(dataStream,&dummyProg,hull,false,false);
 	TEST(hull.size() == 4,"Hull pt count (qhull)");
-#endif
 
 
 	double tVol,cVol;
@@ -1238,22 +929,11 @@ bool testConvexHull2()
 	dataStream.push_back(d);
 	unsigned int dummyProg;
 	vector<Point3D> hull;
-#ifdef HAVE_SWEEP_HULL
-	vector<HULLTRI> facets;
-	computeConvexHull(dataStream,&dummyProg,hull,facets);
-#else
 	computeConvexHull(dataStream,&dummyProg,hull,true,false);
 
-#endif
-
 	TEST(hull.size() == 8,"Hull pt count");
-#ifdef HAVE_SWEEP_HULL
-	float cVol = getConvexVolume(hull,facets);
-	TEST(EQ_TOLV(cVol,1.0f,1e-2) ,"Hull volume (cube, shull)");
-#else
 	TEST(EQ_TOL(qh totvol,1.0f),"Hull volume (cube, qhull)");
 	freeConvexHull();
-#endif
 
 	delete d;
 	return true;
@@ -1261,7 +941,7 @@ bool testConvexHull2()
 }
 bool testHull()
 {
-	cerr << "Hull tests " << endl;;
+	std::cerr << "Hull tests " << std::endl;;
 	//Delaunay is not implemented for sweep-hull
 	TEST(testDelaunay(),"delaunay test");
 	TEST(testConvexHull(), "convex hull test (tetrahedron)");
