@@ -25,7 +25,8 @@ using std::vector;
 
 //Background modes
 const char *BACKGROUND_MODE_STRING[FIT_MODE_ENUM_END] = {NTRANS("None"), 	
-					NTRANS("Flat TOF")};
+					NTRANS("Simple Flat TOF"),
+					NTRANS("Zech Estimate")};
 
 std::string getFitError(unsigned int errMsg) 
 {
@@ -66,7 +67,11 @@ void makeHistogram(const vector<float> &data, float start,
 unsigned int doFitBackground(const vector<const FilterStreamData*> &dataIn, 
 	BACKGROUND_PARAMS &backParams)
 {
-	ASSERT(backParams.mode == FIT_MODE_CONST_TOF);
+	//FIXME: Backparams shouldn't know about whether zech or simple
+	// is being used, as really there are two parts to this
+	// however, the filter layer is not properly separating this, and should.
+	ASSERT(backParams.mode == FIT_MODE_CONST_TOF_SIMPLE || 
+		backParams.mode == FIT_MODE_CONST_TOF_ZECH);
 	ASSERT(backParams.massStart < backParams.massEnd);
 
 	vector<const IonStreamData *> ionData;
@@ -297,7 +302,7 @@ bool testBackgroundFitCode()
 {
 	BACKGROUND_PARAMS bp;
 
-	bp.mode = FIT_MODE_CONST_TOF;
+	bp.mode = FIT_MODE_CONST_TOF_SIMPLE;
 	bp.binWidth = 0.1;
 
 	vector<float> massData;
