@@ -31,7 +31,10 @@
 enum
 {
 	FIT_MODE_NONE,
-	FIT_MODE_CONST_TOF,
+	FIT_MODE_CONST_TOF_SIMPLE, //Simple background subtraction
+	FIT_MODE_CONST_TOF_ZECH, // Method of Zech/Bityukov subtraction 
+				// Upper limits in experiments with background or measurement errors
+				// Zech. Nuclear Instruments and Methods in Physics Research, 1989
 	FIT_MODE_ENUM_END,
 };
 
