@@ -26,9 +26,16 @@
 #include <gsl/gsl_randist.h>
 #include <gsl/gsl_multifit.h>
 
+#if defined(__WIN64)
+//Needed for size check on win64
+extern "C"
+{
 #include <qhull/qhull_a.h>
+}
+#endif
 
 using std::vector;
+using std::set;
 
 #ifdef _OPENMP
 #include <omp.h>
@@ -88,7 +95,7 @@ const unsigned int MAX_NN_DISTS = 0x8000000; //96 MB samples at a time
 unsigned int generateNNHist( const vector<Point3D> &pointList, 
 			const K3DTree &tree,unsigned int nnMax, unsigned int numBins,
 		       	vector<vector<size_t> > &histogram, float *binWidth , unsigned int *progressPtr,
-			ATOMIC_BOOL &wantAbort)
+			std::atomic<bool> &wantAbort)
 {
 	if(pointList.size() <=nnMax)
 		return RDF_ERR_INSUFFICIENT_INPUT_POINTS;
@@ -279,7 +286,7 @@ unsigned int generateNNHist( const vector<Point3D> &pointList,
 
 unsigned int generate1DAxialDistHist(const vector<Point3D> &pointList, const K3DTreeMk2 &tree,
 		const Point3D &axisDir, unsigned int *histogram, float distMax, unsigned int numBins,
-		unsigned int *progressPtr, ATOMIC_BOOL &wantAbort)
+		unsigned int *progressPtr, std::atomic<bool> &wantAbort)
 {
 	//Check that the axis is normalised
 	ASSERT(EQ_TOL(axisDir.sqrMag(),1.0f));
@@ -373,7 +380,7 @@ unsigned int generate1DAxialDistHist(const vector<Point3D> &pointList, const K3D
 
 unsigned int generate1DAxialNNHist(const vector<Point3D> &pointList, const K3DTreeMk2 &tree,
 		const Point3D &axisDir, unsigned int *histogram, float &binWidth, unsigned int nnMax, unsigned int numBins,
-		unsigned int *progressPtr, ATOMIC_BOOL &wantAbort)
+		unsigned int *progressPtr, std::atomic<bool> &wantAbort)
 {
 #ifdef DEBUG
 	for(unsigned int ui=0;ui<numBins;ui++)
@@ -571,7 +578,7 @@ unsigned int generate1DAxialNNHist(const vector<Point3D> &pointList, const K3DTr
 unsigned int generateDistHist(const vector<Point3D> &pointList, const K3DTree &tree,
 			unsigned int *histogram, float distMax,
 			unsigned int numBins, unsigned int &warnBiasCount,
-			unsigned int *progressPtr,ATOMIC_BOOL &wantAbort)
+			unsigned int *progressPtr,std::atomic<bool> &wantAbort)
 {
 
 
@@ -627,7 +634,7 @@ unsigned int generateDistHist(const vector<Point3D> &pointList, const K3DTree &t
 		//Loop from this ion, up to its max	
 		//disable exact matching, by requiring d^2 > epsilon
 		deadDistSqr=std::numeric_limits<float>::epsilon();
-		sqrDist=0;
+
 		sourcePoint=pointList[ui];
 		while(deadDistSqr < maxSqrDist)
 		{
@@ -748,7 +755,7 @@ void generateKnnTheoreticalDist(const std::vector<float> &radii, float density,
 }
 
 unsigned int generate1DAxialDistHistSweep(const std::vector<Point3D> &pointList, K3DTreeMk2 &tree,
-		float distMax, unsigned int &prog, ATOMIC_BOOL &wantAbort,
+		float distMax, unsigned int &prog, std::atomic<bool> &wantAbort,
 		std::vector<std::vector<std::vector<unsigned int> > > &histogram, float thetaStart,
 		float thetaStop,float phiStart,float phiStop)
 {
@@ -942,7 +949,7 @@ void errorFitAxialDistArray(const std::vector<std::vector<std::vector<unsigned i
 
 bool qhullTest()
 {
-#if defined(__WIN64) && !defined(HAVE_SWEEP_HULL)
+#if defined(__WIN64) 
 	//If using a cross-compile (at least)
 	// qhull under win64 must use long long, or we get random crashes
 	// The definition is set in qhull/mem.h
