@@ -1163,8 +1163,10 @@ bool AnnotateFilter::writeState(std::ostream &f,unsigned int format, unsigned in
 	return true;
 }
 
-bool AnnotateFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool AnnotateFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
+	xmlNodePtr tmpNodeOrig=nodePtr;
+
 	using std::string;
 	string tmpStr;
 
@@ -1172,10 +1174,10 @@ bool AnnotateFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 
 	//Retrieve user string
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"userstring"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
@@ -1183,32 +1185,32 @@ bool AnnotateFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	//===
 
 	//Annotation mode
-	if(!XMLGetNextElemAttrib(nodePtr,annotationMode,"annotationmode","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,annotationMode,"annotationmode","value"))
 		return false;
 
 	if(annotationMode >=ANNOTATION_MODE_END)
 		return false;
 
 	//position
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"position","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"position","value"))
 		return false;
 
 	if(!position.parse(tmpStr))
 		return false;
 
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"target","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"target","value"))
 		return false;
 
 	if(!target.parse(tmpStr))
 		return false;
 	
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"upvec","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"upvec","value"))
 		return false;
 
 	if(!upVec.parse(tmpStr))
 		return false;
 	
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"acrossvec","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"acrossvec","value"))
 		return false;
 
 	if(!acrossVec.parse(tmpStr))
@@ -1219,53 +1221,53 @@ bool AnnotateFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 		return false;
 
 	xmlNodePtr tmpPtr;
-	tmpPtr=nodePtr;
+	tmpPtr=tmpNodeOrig;
 
-	if(XMLHelpFwdToElem(nodePtr,"anglepos"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"anglepos"))
 		return false;
 	
-	if(!nodePtr->xmlChildrenNode)
+	if(!tmpNodeOrig->xmlChildrenNode)
 		return false;
 	
-	nodePtr=nodePtr->xmlChildrenNode;
+	tmpNodeOrig=tmpNodeOrig->xmlChildrenNode;
 
 	for(unsigned int ui=0;ui<3;ui++)
 	{
-		if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"position","value"))
+		if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"position","value"))
 			return false;
 
 		if(!anglePos[ui].parse(tmpStr))
 			return false;
 	}
 
-	nodePtr=tmpPtr;
+	tmpNodeOrig=tmpPtr;
 
 	//If it fails, thats OK, just use the empty string.	
-	if(!XMLGetNextElemAttrib(nodePtr,annotateText,"annotatetext","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,annotateText,"annotatetext","value"))
 		annotateText="";
 
-	if(!XMLGetNextElemAttrib(nodePtr,textSize,"textsize","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,textSize,"textsize","value"))
 		return false;
 	
-	if(!XMLGetNextElemAttrib(nodePtr,annotateSize,"annotatesize","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,annotateSize,"annotatesize","value"))
 		return false;
 
 	if(annotateSize <0.0f)
 		return false;
 
 
-	if(!XMLGetNextElemAttrib(nodePtr,sphereMarkerSize,"sphereanglesize","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,sphereMarkerSize,"sphereanglesize","value"))
 		return false;
 	if(sphereMarkerSize<0.0f)
 		return false;
 
-	if(!XMLGetNextElemAttrib(nodePtr,lineSize,"linesize","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,lineSize,"linesize","value"))
 		return false;
 	if(lineSize<0.0f)
 		return false;
 
 	//TODO: we have a standardised parsexmlColour func, use it
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"colour","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"colour","value"))
 		return false;
 	
 	ColourRGBA tmpRgba;
@@ -1275,54 +1277,54 @@ bool AnnotateFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 
 	rgba=tmpRgba.toRGBAf();
 
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"active","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"active","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,active))
 		return false;
 
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"showangletext","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"showangletext","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,showAngleText))
 		return false;
 
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"reflexangle","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"reflexangle","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,reflexAngle))
 		return false;
 
 
-	if(!XMLGetNextElemAttrib(nodePtr,angleFormatPreDecimal,"angleformat","predecimal"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,angleFormatPreDecimal,"angleformat","predecimal"))
 		return false;
 
-	if(!XMLGetAttrib(nodePtr,angleFormatPostDecimal,"predecimal"))
+	if(!XMLGetAttrib(tmpNodeOrig,angleFormatPostDecimal,"predecimal"))
 		return false;
 
 	//This feature did not exist prior to 2741:2eb7770d3018
 	// (<0.0.21), and thus may not be present
 	xmlNodePtr tmpNode;
-	tmpNode=nodePtr;
+	tmpNode=tmpNodeOrig;
 
-	if(!XMLHelpFwdToElem(nodePtr,"ruler"))
+	if(!XMLHelpFwdToElem(tmpNodeOrig,"ruler"))
 	{	
-		if(!XMLGetAttrib(nodePtr,rulerMode,"mode"))
+		if(!XMLGetAttrib(tmpNodeOrig,rulerMode,"mode"))
 			return false;
 		if(rulerMode >=RULER_MODE_ENUM_END)
 			return false;
 
-		if(!XMLGetAttrib(nodePtr,linearMeasureSpacing,"spacing"))
+		if(!XMLGetAttrib(tmpNodeOrig,linearMeasureSpacing,"spacing"))
 			return false;
 		if(linearMeasureSpacing<=0 )
 			return false;
 
-		if(!XMLGetAttrib(nodePtr,linearMeasureTicks,"tickcount"))
+		if(!XMLGetAttrib(tmpNodeOrig,linearMeasureTicks,"tickcount"))
 			return false;
 		if(!linearMeasureTicks)
 			return false;
 
-		if(!XMLGetAttrib(nodePtr,fontSizeLinearMeasure,"fontsize"))
+		if(!XMLGetAttrib(tmpNodeOrig,fontSizeLinearMeasure,"fontsize"))
 			return false;
 		if(fontSizeLinearMeasure <=0)
 			return false;
