@@ -124,7 +124,7 @@ class AnnotateFilter : public Filter
 		//!Read state from XML  stream, using xml format
 		/* Current supported formats are STATE_FORMAT_XML
 		 */
-		bool readState(xmlNodePtr& n, const std::string &packDir="");
+		bool readState(const xmlNodePtr& n, const std::string &packDir="");
 
 		//!Get the bitmask encoded list of filterStreams that this filter blocks from propagation.
 		// i.e. if this filterstream is passed to refresh, it is not emitted.
