@@ -843,14 +843,15 @@ bool BoundingBoxFilter::writeState(std::ostream &f,unsigned int format, unsigned
 	return true;
 }
 
-bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool BoundingBoxFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
+	xmlNodePtr tmpNodeOrig=nodePtr;
 	//Retrieve user string
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"userstring"))
 		return false;
 
-	xmlChar *xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlChar *xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
@@ -860,10 +861,10 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 
 	//Retrieve visibility 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"visible"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"visible"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -876,10 +877,10 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 	
 	//Retrieve box style 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"boundstyle"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"boundstyle"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -893,10 +894,10 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 	
 	//Retrieve fixed tick num
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"fixedticks"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"fixedticks"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -909,10 +910,10 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 	
 	//Retrieve num ticks
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"ticknum"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"ticknum"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"x");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"x");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -922,7 +923,7 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 
 	xmlFree(xmlString);
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"y");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"y");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -932,7 +933,7 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 
 	xmlFree(xmlString);
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"z");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"z");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -945,10 +946,10 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 	
 	//Retrieve spacing
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"tickspacing"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"tickspacing"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"x");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"x");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -961,7 +962,7 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 
 	xmlFree(xmlString);
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"y");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"y");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -973,7 +974,7 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 
 	xmlFree(xmlString);
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"z");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"z");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -988,21 +989,21 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 
 	//Retrieve ticks enabled (3Depict > 0.0.18)
 	//===
-	xmlNodePtr tmpNode=nodePtr;
-	if(XMLHelpFwdToElem(nodePtr,"ticksenabled"))
+	xmlNodePtr tmpNode=tmpNodeOrig;
+	if(XMLHelpFwdToElem(tmpNodeOrig,"ticksenabled"))
 	{
 		//loading failed, use default (enabled)
 		for(unsigned int ui=0; ui<3; ui++)
 			enableTicks[ui] =true;
 
-		nodePtr=tmpNode;
+		tmpNodeOrig=tmpNode;
 	}
 	else
 	{
 		const char *XYZ[]={"x","y","z"};
 		for(unsigned int ui=0;ui<3;ui++)
 		{
-			xmlString=xmlGetProp(nodePtr,(const xmlChar *)XYZ[ui]);
+			xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)XYZ[ui]);
 			if(!xmlString)
 				return false;
 			tmpStr=(char *)xmlString;
@@ -1018,10 +1019,10 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 	
 	//Retrieve line width 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"linewidth"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"linewidth"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1037,10 +1038,10 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 	
 	//Retrieve font size 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"fontsize"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"fontsize"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1054,23 +1055,23 @@ bool BoundingBoxFilter::readState(xmlNodePtr &nodePtr, const std::string &stateF
 
 	//Retrieve colour
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"colour"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"colour"))
 		return false;
 
 	ColourRGBAf tmpCol;
-	if(!parseXMLColour(nodePtr,tmpCol))
+	if(!parseXMLColour(tmpNodeOrig,tmpCol))
 		return false;
 	lineColour=tmpCol;
 	//====
 
 	//Retrieve absolute coordinates (only for 3Depict > 0.0.18) 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"absolutecoords"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"absolutecoords"))
 		absoluteCoords=false;
 	else
 	{
 		std::string s;
-		if(XMLHelpGetProp(s,nodePtr,"value"))
+		if(XMLHelpGetProp(s,tmpNodeOrig,"value"))
 			return false;
 		if(!boolStrDec(s,absoluteCoords))
 			return false;
