@@ -297,6 +297,12 @@ Filter *ClusterAnalysisFilter::cloneUncached() const
 	p->linkDist=linkDist;
 	p->dErosion=dErosion;
 
+	p->enableCoreClassify=enableCoreClassify;
+	p->enableBulkLink=enableBulkLink;
+	p->enableErosion=enableErosion;
+
+	p->coreKNN = coreKNN;
+
 	p->wantCropSize=wantCropSize;
 	p->nMin=nMin;
 	p->nMax=nMax;
@@ -1595,16 +1601,18 @@ size_t ClusterAnalysisFilter::numBytesForCache(size_t nObjects) const
 	return (size_t)nObjects*IONDATA_SIZE;
 }
 
-bool ClusterAnalysisFilter::readState(xmlNodePtr &nodePtr, const std::string &packDir)
+bool ClusterAnalysisFilter::readState(const xmlNodePtr &nodePtr, const std::string &packDir)
 {
+	xmlNodePtr tmpNode=nodePtr;
+
 	using std::string;
 
 	//Retrieve user string
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNode,"userstring"))
 		return false;
 
-	xmlChar *xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlChar *xmlString=xmlGetProp(tmpNode,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
@@ -1613,7 +1621,7 @@ bool ClusterAnalysisFilter::readState(xmlNodePtr &nodePtr, const std::string &pa
 
 	//Retrieve algorithm
 	//====== 
-	if(!XMLGetNextElemAttrib(nodePtr,algorithm,"algorithm","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,algorithm,"algorithm","value"))
 		return false;
 	if(algorithm >=CLUSTER_ALGORITHM_ENUM_END)
 		return false;
@@ -1625,40 +1633,40 @@ bool ClusterAnalysisFilter::readState(xmlNodePtr &nodePtr, const std::string &pa
 	{
 		case CLUSTER_LINK_ERODE:
 		{
-			if(!XMLGetNextElemAttrib(nodePtr,coreDist,"coredist","value"))
+			if(!XMLGetNextElemAttrib(tmpNode,coreDist,"coredist","value"))
 				return false;
 			if(coreDist<0)
 				return false;
-			if(!XMLGetNextElemAttrib(nodePtr,coreKNN,"coringknn","value"))
+			if(!XMLGetNextElemAttrib(tmpNode,coreKNN,"coringknn","value"))
 				return false;
 			if(!coreKNN)
 				return false;
-			if(!XMLHelpGetProp(enableCoreClassify,nodePtr,"enabled"))
+			if(XMLHelpGetProp(enableCoreClassify,tmpNode,"enabled"))
 			{
 				//FIXME : Deprecate this check - previously the enabled setting was specfied by
-				// setting a value of zero for the link distance
-				enableCoreClassify=!(bulkLink == 0);
+				// setting a value of zero for the core distance
+				enableCoreClassify=!(coreDist== 0);
 			}
 
-			if(!XMLGetNextElemAttrib(nodePtr,linkDist,"linkdist","value"))
+			if(!XMLGetNextElemAttrib(tmpNode,linkDist,"linkdist","value"))
 				return false;
 			if(linkDist<=0)
 				return false;
-			if(!XMLGetNextElemAttrib(nodePtr,bulkLink,"bulklink","value"))
+			if(!XMLGetNextElemAttrib(tmpNode,bulkLink,"bulklink","value"))
 				return false;
 			if(bulkLink<0)
 				return false;
-			if(!XMLHelpGetProp(enableBulkLink,nodePtr,"enabled"))
+			if(!XMLHelpGetProp(enableBulkLink,tmpNode,"enabled"))
 			{
 				//FIXME : Deprecate this check - previously the enabled setting was specfied by
 				// setting a value of zero for the link distance
 				enableBulkLink=!(bulkLink == 0);
 			}
-			if(!XMLGetNextElemAttrib(nodePtr,dErosion,"derosion","value"))
+			if(!XMLGetNextElemAttrib(tmpNode,dErosion,"derosion","value"))
 				return false;
 			if(dErosion<0)
 				return false;
-			if(!XMLHelpGetProp(enableErosion,nodePtr,"enabled"))
+			if(!XMLHelpGetProp(enableErosion,tmpNode,"enabled"))
 			{
 				//FIXME : Deprecate this check - previously the enabled setting was specfied by
 				// setting a value of zero for the link distance
@@ -1677,39 +1685,39 @@ bool ClusterAnalysisFilter::readState(xmlNodePtr &nodePtr, const std::string &pa
 	//Retrieve cropping info
 	//===
 	xmlNodePtr tmpPtr;
-	tmpPtr=nodePtr;
+	tmpPtr=tmpNode;
 
-	if(!XMLGetNextElemAttrib(nodePtr,wantCropSize,"wantcropsize","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,wantCropSize,"wantcropsize","value"))
 		return false;
-	nodePtr=tmpPtr;
+	tmpNode=tmpPtr;
 
-	if(!XMLGetNextElemAttrib(nodePtr,nMin,"nmin","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,nMin,"nmin","value"))
 		return false;
-	nodePtr=tmpPtr;
-	if(!XMLGetNextElemAttrib(nodePtr,nMax,"nmax","value"))
+	tmpNode=tmpPtr;
+	if(!XMLGetNextElemAttrib(tmpNode,nMax,"nmax","value"))
 		return false;
-	nodePtr=tmpPtr;
+	tmpNode=tmpPtr;
 
-	if(!XMLGetNextElemAttrib(nodePtr,wantClusterSizeDist,"wantclustersizedist","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,wantClusterSizeDist,"wantclustersizedist","value"))
 		return false;
-	nodePtr=tmpPtr;
-	if(!XMLGetNextElemAttrib(nodePtr,logClusterSize,"wantclustersizedist","logarithmic"))
+	tmpNode=tmpPtr;
+	if(!XMLGetNextElemAttrib(tmpNode,logClusterSize,"wantclustersizedist","logarithmic"))
 		return false;
 	
-	tmpPtr=nodePtr;
-	if(!XMLGetNextElemAttrib(nodePtr,wantClusterComposition,"wantclustercomposition","value"))
+	tmpPtr=tmpNode;
+	if(!XMLGetNextElemAttrib(tmpNode,wantClusterComposition,"wantclustercomposition","value"))
 		return false;
-	nodePtr=tmpPtr;
-	if(!XMLGetNextElemAttrib(nodePtr,normaliseComposition,"wantclustercomposition","normalise"))
+	tmpNode=tmpPtr;
+	if(!XMLGetNextElemAttrib(tmpNode,normaliseComposition,"wantclustercomposition","normalise"))
 		return false;
 	
 	
-	nodePtr=tmpPtr;
-	if(!XMLGetNextElemAttrib(nodePtr,wantClusterMorphology,"wantclustermorphology","value"))
+	tmpNode=tmpPtr;
+	if(!XMLGetNextElemAttrib(tmpNode,wantClusterMorphology,"wantclustermorphology","value"))
 		return false;
 	
-	nodePtr=tmpPtr;
-	if(!XMLGetNextElemAttrib(nodePtr,wantClusterID,"wantclusterid","value"))
+	tmpNode=tmpPtr;
+	if(!XMLGetNextElemAttrib(tmpNode,wantClusterID,"wantclusterid","value"))
 	{
 		//COMPAT_BREAK: compat fix, 0.0.16.
 		wantClusterID=false;
@@ -1726,16 +1734,16 @@ bool ClusterAnalysisFilter::readState(xmlNodePtr &nodePtr, const std::string &pa
 	ionBulkEnabled.clear();
 
 	//Retrieve enabled selections
-	if(XMLHelpFwdToElem(nodePtr,"enabledions"))
+	if(XMLHelpFwdToElem(tmpNode,"enabledions"))
 		return false;
 
 	//Jump to ion sequence (<core>/<bulk> level)
-	nodePtr=nodePtr->xmlChildrenNode;
+	tmpNode=tmpNode->xmlChildrenNode;
 
-	if(XMLHelpFwdToElem(nodePtr,"core"))
+	if(XMLHelpFwdToElem(tmpNode,"core"))
 		return false;
 	//Jump to <ion> level
-	tmpPtr=nodePtr->xmlChildrenNode;
+	tmpPtr=tmpNode->xmlChildrenNode;
 	
 	while(!XMLHelpFwdToElem(tmpPtr,"ion"))
 	{
@@ -1752,9 +1760,9 @@ bool ClusterAnalysisFilter::readState(xmlNodePtr &nodePtr, const std::string &pa
 		ionNames.push_back(tmpName);
 	}
 
-	if(XMLHelpFwdToElem(nodePtr,"bulk"))
+	if(XMLHelpFwdToElem(tmpNode,"bulk"))
 		return false;
-	tmpPtr=nodePtr->xmlChildrenNode;
+	tmpPtr=tmpNode->xmlChildrenNode;
 
 	while(!XMLHelpFwdToElem(tmpPtr,"ion"))
 	{
