@@ -164,7 +164,7 @@ class ClusterAnalysisFilter : public Filter
 						unsigned int depth=0) const;
 		//!Read the state of the filter from XML file. If this
 		//fails, filter will be in an undefined state.
-		bool readState(xmlNodePtr &node, const std::string &packDir);
+		bool readState(const xmlNodePtr &node, const std::string &packDir);
 		
 
 		//Obtain the number of steps that need to be taken
