@@ -989,15 +989,17 @@ bool DataLoadFilter::setProperty(  unsigned int key,
 	return true;
 }
 
-bool DataLoadFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool DataLoadFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
+	xmlNodePtr tmpNode=nodePtr;
+
 	//Retrieve user string
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNode,"userstring"))
 		return false;
 
 	xmlChar *xmlString;
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
@@ -1005,16 +1007,16 @@ bool DataLoadFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	//===
 
 	//Retrieve file name	
-	if(XMLHelpFwdToElem(nodePtr,"file"))
+	if(XMLHelpFwdToElem(tmpNode,"file"))
 		return false;
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"name");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"name");
 	if(!xmlString)
 		return false;
 	ionFilename=(char *)xmlString;
 	xmlFree(xmlString);
 
 	//retrieve file type (text,pos etc), if needed; default to pos.
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"type");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"type");
 	if(xmlString)
 	{
 		int type;
@@ -1036,15 +1038,15 @@ bool DataLoadFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	ionFilename=convertFileStringToNative(ionFilename);
 
 	//Retrieve number of columns	
-	if(!XMLGetNextElemAttrib(nodePtr,numColumns,"columns","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,numColumns,"columns","value"))
 		return false;
 	if(numColumns >= MAX_NUM_FILE_COLS)
 		return false;
 	
 	//Retrieve index	
-	if(XMLHelpFwdToElem(nodePtr,"xyzm"))
+	if(XMLHelpFwdToElem(tmpNode,"xyzm"))
 		return false;
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"values");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"values");
 	if(!xmlString)
 		return false;
 	std::vector<string> v;
@@ -1062,7 +1064,7 @@ bool DataLoadFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	//Retrieve enabled/disabled
 	//--
 	unsigned int tmpVal;
-	if(!XMLGetNextElemAttrib(nodePtr,tmpVal,"enabled","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,tmpVal,"enabled","value"))
 		return false;
 	enabled=tmpVal;
 	//--
@@ -1070,12 +1072,12 @@ bool DataLoadFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	//Retrieve monitor mode 
 	//--
 	xmlNodePtr nodeTmp;
-	nodeTmp=nodePtr;
-	if(XMLGetNextElemAttrib(nodePtr,tmpVal,"monitor","value"))
+	nodeTmp=tmpNode;
+	if(XMLGetNextElemAttrib(tmpNode,tmpVal,"monitor","value"))
 		wantMonitor=tmpVal;
 	else
 	{
-		nodePtr=nodeTmp;
+		tmpNode=nodeTmp;
 		wantMonitor=false;
 	}
 	//--
@@ -1083,16 +1085,16 @@ bool DataLoadFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	//Retrieve value type string (eg mass-to-charge, 
 	// or whatever the data type is)
 	//--
-	nodeTmp=nodePtr;
-	if(XMLHelpFwdToElem(nodePtr,"valuetype"))
+	nodeTmp=tmpNode;
+	if(XMLHelpFwdToElem(tmpNode,"valuetype"))
 	{
-		nodePtr=nodeTmp;
+		tmpNode=nodeTmp;
 		valueLabel=TRANS(DEFAULT_LABEL);
 	}
 	else
 	{
 		xmlChar *xmlString;
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+		xmlString=xmlGetProp(tmpNode,(const xmlChar *)"value");
 		if(!xmlString)
 			return false;
 		valueLabel=(char *)xmlString;
@@ -1110,11 +1112,11 @@ bool DataLoadFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	// so some statefiles will exist without this. In the case it is not
 	// found, we need to make it up
 	{
-	nodeTmp=nodePtr;
+	nodeTmp=tmpNode;
 	bool needSampleState=false;
-	if(!XMLGetNextElemAttrib(nodePtr,doSample,"dosample","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,doSample,"dosample","value"))
 	{
-		nodePtr=nodeTmp;
+		tmpNode=nodeTmp;
 		needSampleState=true;
 	}
 	//---
@@ -1123,7 +1125,7 @@ bool DataLoadFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	//--
 	//TODO: Forbid zero values - don't do it now, as we previously used this
 	// for disabling sampling, so some users' XML files will still have this
-	if(!XMLGetNextElemAttrib(nodePtr,maxIons,"maxions","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,maxIons,"maxions","value"))
 		return false;
 
 	if(needSampleState) 
@@ -1141,16 +1143,16 @@ bool DataLoadFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	}
 	//Retrieve colour
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"colour"))
+	if(XMLHelpFwdToElem(tmpNode,"colour"))
 		return false;
 
-	if(!parseXMLColour(nodePtr,rgbaf))
+	if(!parseXMLColour(tmpNode,rgbaf))
 		return false;	
 	//====
 
 	//Retrieve drawing size value
 	//--
-	if(!XMLGetNextElemAttrib(nodePtr,ionSize,"ionsize","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,ionSize,"ionsize","value"))
 		return false;
 	//check positive or zero
 	if(ionSize <=0)
