@@ -165,7 +165,7 @@ class DataLoadFilter:public Filter
 				const std::vector<std::string> &valueOverrides,unsigned int depth=0) const;
 		//!Read the state of the filter from XML file. If this
 		//fails, filter will be in an undefined state.
-		bool readState(xmlNodePtr &node, const std::string &packDir);
+		bool readState(const xmlNodePtr &node, const std::string &packDir);
 		
 		//!Get the block mask for this filter (bitmaks of streams blocked from propagation during ::refresh)
 		virtual unsigned int getRefreshBlockMask() const; 
