@@ -684,31 +684,33 @@ bool ExternalProgramFilter::writeState(std::ostream &f,unsigned int format, unsi
 	return true;
 }
 
-bool ExternalProgramFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool ExternalProgramFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
+	xmlNodePtr tmpNode=nodePtr;
+
 	//Retrieve user string
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNode,"userstring"))
 		return false;
 
-	xmlChar *xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlChar *xmlString=xmlGetProp(tmpNode,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
 	xmlFree(xmlString);
 
 	//Retrieve command
-	if(XMLHelpFwdToElem(nodePtr,"commandline"))
+	if(XMLHelpFwdToElem(tmpNode,"commandline"))
 		return false;
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"name");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"name");
 	if(!xmlString)
 		return false;
 	commandLine=(char *)xmlString;
 	xmlFree(xmlString);
 	
 	//Retrieve working dir
-	if(XMLHelpFwdToElem(nodePtr,"workingdir"))
+	if(XMLHelpFwdToElem(tmpNode,"workingdir"))
 		return false;
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"name");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"name");
 	if(!xmlString)
 		return false;
 	workingDir=(char *)xmlString;
@@ -717,14 +719,14 @@ bool ExternalProgramFilter::readState(xmlNodePtr &nodePtr, const std::string &st
 
 	//get should cache
 	string tmpStr;
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"alwayscache","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,tmpStr,"alwayscache","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,alwaysCache))
 		return false;
 
 	//check readable 
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"cleaninput","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,tmpStr,"cleaninput","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,cleanInput))
