@@ -82,7 +82,7 @@ class ExternalProgramFilter : public Filter
 						unsigned int depth=0) const;
 		//!Read the state of the filter from XML file. If this
 		//fails, filter will be in an undefined state.
-		bool readState(xmlNodePtr &node, const std::string &packDir);
+		bool readState(const xmlNodePtr &node, const std::string &packDir);
 
 		unsigned int getNumSteps() const; 
 		
