@@ -72,6 +72,7 @@ using std::ostream;
 using std::vector;
 using std::endl;
 using std::string;
+using std::pair;
 
 void writeVectorsXML(ostream &f,const char *containerName,
 		const vector<Point3D> &vectorParams, unsigned int depth)
@@ -392,7 +393,7 @@ std::string VoxelAppearanceProperties::getRepresentTypeString(int type) {
 	return  std::string(TRANS(REPRESENTATION_TYPE_STRING[type]));
 }
 
-VoxelAppearanceProperties::VoxelAppearanceProperties(Filter *p)
+VoxelAppearanceProperties::VoxelAppearanceProperties(Filter *p, bool showCKeys)
 {
 	COMPILE_ASSERT(THREEDEP_ARRAYSIZE(REPRESENTATION_TYPE_STRING) == VOXEL_REPRESENT_END);
 	parent=p;
@@ -422,6 +423,8 @@ VoxelAppearanceProperties::VoxelAppearanceProperties(Filter *p)
 
 	boundColour=ColourRGBAf(0,0,1);
 	nColours=256;	
+
+	showColourKeys=showCKeys;
 }
 
 void VoxelAppearanceProperties::operator=(const VoxelAppearanceProperties &oth)
@@ -525,10 +528,13 @@ void VoxelAppearanceProperties::getProperties(FilterPropGroup &propertyList, siz
 			curGroup++;
 
 			//-- Isosurface appearance --
-			FilterProperty pColour(keyOffset+KEY_VOXAPPEAR_COLOUR, TRANS("Colour"),
-				 rgba,TRANS("Colour of isosurface")); 
-			propertyList.addProperty(pColour,curGroup);
-			p.name=TRANS("Colour");
+			if(showColourKeys)
+			{
+				FilterProperty pColour(keyOffset+KEY_VOXAPPEAR_COLOUR, TRANS("Colour"),
+					 rgba,TRANS("Colour of isosurface")); 
+				propertyList.addProperty(pColour,curGroup);
+				p.name=TRANS("Colour");
+			}
 
 			FilterProperty pTransparency(keyOffset+KEY_VOXAPPEAR_TRANSPARENCY, TRANS("Transparency"),
 				 (float)(1.0-rgba.a()),TRANS("How \"see through\" each facet is (0 - opaque, 1 - invisible)"));
@@ -1153,8 +1159,8 @@ void VoxelAppearanceProperties::writeState(ostream &f, unsigned int format, unsi
 
 }
 
-//FIXME: This modifes the calling filter through the parent pointer
-// although this class is const, it still performs modfiications through its
+//FIXME: This modifies the calling filter through the parent pointer
+// although this class is const, it still performs modifications through its
 // member pointers - this is bad design and should be fixed
 unsigned int VoxelAppearanceProperties::refresh(Voxels<float> &voxelData, 
 				vector<const FilterStreamData *> &getOut, 
@@ -1563,25 +1569,26 @@ void VoxelAppearanceProperties::getTexturedSlice(const Voxels<float> &v,
 
 
 }
-unsigned int VoxelAppearanceProperties::readState(xmlNodePtr &nodePtr)
+unsigned int VoxelAppearanceProperties::readState(const xmlNodePtr &nodePtr)
 {
+	xmlNodePtr tmpNode=nodePtr;
 	//Retrieve representation
-	if(!XMLGetNextElemAttrib(nodePtr,representation,"representation","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,representation,"representation","value"))
 		return false;
 	
 	//Option did not exist Under 0.0.21 or earlier
 	xmlNodePtr tmpPtr;
-	tmpPtr =nodePtr;
-	if(!XMLGetNextElemAttrib(nodePtr,showBoundBox,"bound","show"))
+	tmpPtr =tmpNode;
+	if(!XMLGetNextElemAttrib(tmpNode,showBoundBox,"bound","show"))
 	{
 		showBoundBox=false;
-		nodePtr=tmpPtr;	
+		tmpNode=tmpPtr;	
 	}
 	else
 	{
 		//Parse colour attrib
 		ColourRGBAf tmpRgba;
-		if(!parseXMLColour(nodePtr,tmpRgba))
+		if(!parseXMLColour(tmpNode,tmpRgba))
 			return false;
 
 		boundColour=tmpRgba;
@@ -1598,21 +1605,21 @@ unsigned int VoxelAppearanceProperties::readState(xmlNodePtr &nodePtr)
 
 	//-------	
 	//Retrieve representation
-	if(!XMLGetNextElemAttrib(nodePtr,isoLevel,"isovalue","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,isoLevel,"isovalue","value"))
 		return false;
 
 	//Retrieve colour
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"colour"))
+	if(XMLHelpFwdToElem(tmpNode,"colour"))
 		return false;
 	ColourRGBAf tmpRgba;
-	if(!parseXMLColour(nodePtr,tmpRgba))
+	if(!parseXMLColour(tmpNode,tmpRgba))
 		return false;
 	rgba=tmpRgba;
 
 	//====
 
-	tmpPtr=nodePtr;
+	tmpPtr=tmpNode;
 	if(!XMLHelpFwdToElem(tmpPtr,"colourmap"))
 	{
 
@@ -1663,10 +1670,10 @@ unsigned int VoxelAppearanceProperties::readState(xmlNodePtr &nodePtr)
 	}
 
 	//try to retrieve slice, where possible
-	if(!XMLHelpFwdToElem(nodePtr,"axialslice"))
+	if(!XMLHelpFwdToElem(tmpNode,"axialslice"))
 	{
 		xmlNodePtr sliceNodes;
-		sliceNodes=nodePtr->xmlChildrenNode;
+		sliceNodes=tmpNode->xmlChildrenNode;
 
 		if(!sliceNodes)
 			return false;
