@@ -799,14 +799,15 @@ bool IonClipFilter::writeState(std::ostream &f,unsigned int format, unsigned int
 	return true;
 }
 
-bool IonClipFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool IonClipFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
+	xmlNodePtr tmpNode =nodePtr;
 	//Retrieve user string
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNode,"userstring"))
 		return false;
 
-	xmlChar *xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlChar *xmlString=xmlGetProp(tmpNode,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
@@ -816,7 +817,7 @@ bool IonClipFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	std::string tmpStr;	
 	//Retrieve primitive type 
 	//====
-	if(!XMLGetNextElemAttrib(nodePtr,primitiveType,"primitivetype","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,primitiveType,"primitivetype","value"))
 		return false;
 	if(primitiveType >= PRIMITIVE_END)
 	       return false;	
@@ -825,7 +826,7 @@ bool IonClipFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	//Retrieve clip inversion
 	//====
 	//
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"invertedclip","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,tmpStr,"invertedclip","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,invertedClip))
@@ -834,7 +835,7 @@ bool IonClipFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	
 	//Retrieve primitive visibility 
 	//====
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"showprimitive","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,tmpStr,"showprimitive","value"))
 		return false;
 	if(!boolStrDec(tmpStr,showPrimitive))
 		return false;
@@ -842,7 +843,7 @@ bool IonClipFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	
 	//Retrieve axis lock mode 
 	//====
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"lockaxismag","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,tmpStr,"lockaxismag","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,lockAxisMag))
@@ -851,19 +852,19 @@ bool IonClipFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	
 	//Retrieve vector parameters
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"vectorparams"))
+	if(XMLHelpFwdToElem(tmpNode,"vectorparams"))
 		return false;
 
-	if(!readVectorsXML(nodePtr,vectorParams))
+	if(!readVectorsXML(tmpNode,vectorParams))
 		return false;
 	//===	
 
 	//Retrieve scalar parameters
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"scalarparams"))
+	if(XMLHelpFwdToElem(tmpNode,"scalarparams"))
 		return false;
 
-	if(!readScalarsXML(nodePtr,scalarParams))
+	if(!readScalarsXML(tmpNode,scalarParams))
 		return false;
 	//===	
 
