@@ -676,24 +676,25 @@ bool IonDownsampleFilter::writeState(std::ostream &f,unsigned int format, unsign
 	return true;
 }
 
-bool IonDownsampleFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool IonDownsampleFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
 	using std::string;
 	string tmpStr;
+	xmlNodePtr tmpNode=nodePtr;
 
 	xmlChar *xmlString;
 	//Retrieve user string
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNode,"userstring"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
 	xmlFree(xmlString);
 
 	//Retrieve number out (yes/no) mode
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"fixednumout","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,tmpStr,"fixednumout","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,fixedNumOut))
@@ -702,7 +703,7 @@ bool IonDownsampleFilter::readState(xmlNodePtr &nodePtr, const std::string &stat
 		
 	//Retrieve Fraction
 	//===
-	if(!XMLGetNextElemAttrib(nodePtr,fraction,"fraction","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,fraction,"fraction","value"))
 		return false;
 	//disallow negative or values gt 1.
 	if(fraction < 0.0f || fraction > 1.0f)
@@ -711,12 +712,12 @@ bool IonDownsampleFilter::readState(xmlNodePtr &nodePtr, const std::string &stat
 
 	//Retreive maxafterfilter
 	//---
-	if(!XMLGetNextElemAttrib(nodePtr,maxAfterFilter,"maxafterfilter","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,maxAfterFilter,"maxafterfilter","value"))
 		return false;
 	//---
 	
 	//Retrieve "perspecies" attrib
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"perspecies","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,tmpStr,"perspecies","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,perSpecies))
@@ -724,18 +725,18 @@ bool IonDownsampleFilter::readState(xmlNodePtr &nodePtr, const std::string &stat
 
 	//Retrieve the ion per-species fractions
 	//--
-	if(XMLHelpFwdToElem(nodePtr,"fractions"))
+	if(XMLHelpFwdToElem(tmpNode,"fractions"))
 		return false;
 
 	//Populate the ion fraction vector
-	if(!readScalarsXML(nodePtr,ionFractions))
+	if(!readScalarsXML(tmpNode,ionFractions))
 		return false;
 
 	//Retrieve the ion per-species fractions
-	if(XMLHelpFwdToElem(nodePtr,"limits"))
+	if(XMLHelpFwdToElem(tmpNode,"limits"))
 		return false;
 
-	if(!readScalarsXML(nodePtr,ionLimits))
+	if(!readScalarsXML(tmpNode,ionLimits))
 		return false;
 
 	//--
