@@ -834,13 +834,6 @@ unsigned int IonInfoFilter::convexHullEstimateVol(const vector<const FilterStrea
 	const bool WANT_QHULL_VOL=true;
 
 	vector<Point3D> hullPts;
-#if HAVE_SWEEP_HULL
-	vector<HULLTRI> facets;
-	if(computeConvexHull(data,&dummyProgress,hullPts,facets))
-		return ERR_BAD_QHULL;
-
-	volume = getConvexVolume(hullPts,facets);
-#else
 	if(computeConvexHull(data,&dummyProgress,
 			hullPts,WANT_QHULL_VOL,NO_FREE_QHULL))
 		return ERR_BAD_QHULL;
@@ -849,7 +842,6 @@ unsigned int IonInfoFilter::convexHullEstimateVol(const vector<const FilterStrea
 
 	//Free the convex hull mem
 	freeConvexHull();
-#endif
 	
 	return 0;
 }
@@ -903,38 +895,40 @@ bool IonInfoFilter::writePackageState(std::ostream &f, unsigned int format,
 	result=writeState(f,format,depth);
 	const_cast<IonInfoFilter*>(this)->remapFilename=tmpFilename;
 
-	return true;
+	return result;
 }
 
 void IonInfoFilter::getStateOverrides(std::vector<string> &externalAttribs) const 
 {
 	externalAttribs.push_back(remapFilename);
 }
-bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool IonInfoFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
+	xmlNodePtr tmpNodeOrig=nodePtr;
+
 	using std::string;
 	string tmpStr;
 
 	xmlChar *xmlString;
 	//Retrieve user string
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"userstring"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
 	xmlFree(xmlString);
 
 	//--
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"wantioncounts","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"wantioncounts","value"))
 		return false;
 	if(!boolStrDec(tmpStr,wantIonCounts))
 		return false;
 	//--=
 	
 	//--
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"wantnormalise","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"wantnormalise","value"))
 		return false;
 	if(!boolStrDec(tmpStr,wantNormalise))
 		return false;
@@ -942,7 +936,7 @@ bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 
 
 	//--
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"wantvolume","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"wantvolume","value"))
 		return false;
 	if(!boolStrDec(tmpStr,wantVolume))
 		return false;
@@ -950,11 +944,11 @@ bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	//--
 	//TODO: COMPAT : did not exist prior to 0.0.22
 	// internal revision : 592af3968ddf
-	xmlNodePtr tmpNode=nodePtr;
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"wantionremap","value"))
+	xmlNodePtr tmpNode=tmpNodeOrig;
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"wantionremap","value"))
 	{
 		wantIonRemap=false;
-		nodePtr=tmpNode;
+		tmpNodeOrig=tmpNode;
 	}
 	else
 	{
@@ -965,7 +959,7 @@ bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 
 	//--
 	unsigned int tmpInt;
-	if(!XMLGetNextElemAttrib(nodePtr,tmpInt,"volumealgorithm","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpInt,"volumealgorithm","value"))
 		return false;
 
 	if(tmpInt >=VOLUME_MODE_END)
@@ -975,7 +969,7 @@ bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 
 	//--
 	float tmpFloat;
-	if(!XMLGetNextElemAttrib(nodePtr,tmpFloat,"cubesidelen","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpFloat,"cubesidelen","value"))
 		return false;
 
 	if(tmpFloat <= 0.0f)
@@ -986,30 +980,30 @@ bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	//Retrieve background fitting mode, if we have it
 	// TODO: COMPAT : Only available 3Depict >= 0.0.18
 	// internal rev > 3e41b89299f4
-	if(!XMLHelpFwdToElem(nodePtr,"background"))
+	if(!XMLHelpFwdToElem(tmpNodeOrig,"background"))
 	{
-		if(XMLHelpGetProp(fitMode,nodePtr,"mode"))
+		if(XMLHelpGetProp(fitMode,tmpNodeOrig,"mode"))
 			return false;
 
-		if(!nodePtr->xmlChildrenNode)
+		if(!tmpNodeOrig->xmlChildrenNode)
 			return false;
 			
-		xmlNodePtr tmpNode=nodePtr;
-		nodePtr=nodePtr->xmlChildrenNode;
+		xmlNodePtr tmpNode=tmpNodeOrig;
+		tmpNodeOrig=tmpNodeOrig->xmlChildrenNode;
 		
-		if(!XMLGetNextElemAttrib(nodePtr,massBackStart,"fitwindow","start"))
+		if(!XMLGetNextElemAttrib(tmpNodeOrig,massBackStart,"fitwindow","start"))
 			return false;
 
-		if(XMLHelpGetProp(massBackEnd,nodePtr,"end"))
+		if(XMLHelpGetProp(massBackEnd,tmpNodeOrig,"end"))
 			return false;
 		
-		nodePtr=tmpNode;
+		tmpNodeOrig=tmpNode;
 	}
 
 	//TODO: COMPAT : did not exist prior to 0.0.22
 	// internal revision > 592af3968ddf
 	//--
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"remapfilename","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"remapfilename","value"))
 		remapFilename="";
 	else
 	{
@@ -1042,7 +1036,7 @@ unsigned int IonInfoFilter::getRefreshUseMask() const
 
 bool IonInfoFilter::needsUnrangedData() const
 { 
-	return fitMode == FIT_MODE_CONST_TOF;
+	return fitMode == FIT_MODE_CONST_TOF_SIMPLE;
 }
 #ifdef DEBUG
 
@@ -1207,7 +1201,6 @@ bool volumeSphereTest()
 	TEST(consoleStrings.size(), "console strings existence test");
 
 
-#if !defined(HAVE_SWEEP_HULL)
 	float volMeasure,volReal;
 	volMeasure=f->getLastVolume();
 	//Bounding box for sphere is diameter^3.
@@ -1230,9 +1223,6 @@ bool volumeSphereTest()
 	TEST(fabs(volMeasure -volReal) < 0.05*volReal, "volume test, convex est. of sphere");
 	
 	TEST(consoleStrings.size(), "console strings existence test");
-#else
-	MESSAGE("Skipping spherical volume test when using SHULL- upstream has been notified of the problem...");
-#endif
 	delete d;
 	delete f;
 	return true;
