@@ -19,6 +19,7 @@
 #include "../plot.h"
 
 #include "filterCommon.h"
+#include "wx/wxcommon.h"
 #include "geometryHelpers.h"
 #include "../APT/ionMapFile.h"
 
@@ -38,6 +39,21 @@ enum
 	PRIMITIVE_END, //Not actually a primitive, just end of enum
 };
 
+//!Possible error-estimation modes
+enum
+{
+	NUM_ERR_ESTIMATE_NONE,
+	NUM_ERR_ESTIMATE_MOVING_AVERAGE,
+	NUM_ERR_ESTIMATE_GAUSS,
+	NUM_ERR_ESTIMATE_POISSON,
+	NUM_ERR_ESTIMATE_END, //End-of-enum marker, not a moode
+};
+
+const char *NUM_ERR_ESTIMATOR_METHOD[] = {NTRANS("None"),
+				NTRANS("Moving average"),
+				NTRANS("Gaussian-based"),
+				NTRANS("Poisson-based")
+	};
 
 //!Error codes
 enum
@@ -65,10 +81,11 @@ ProfileFilter::ProfileFilter() : primitiveType(PRIMITIVE_CYLINDER_AXIAL),
 	nBins(1000), binWidth(0.5f), minEvents(MINEVENTS_DEFAULT), rgba(0,0,1), plotStyle(0)
 {
 	COMPILE_ASSERT(THREEDEP_ARRAYSIZE(PRIMITIVE_NAME) == PRIMITIVE_END);
+	COMPILE_ASSERT(THREEDEP_ARRAYSIZE(NUM_ERR_ESTIMATOR_METHOD) == NUM_ERR_ESTIMATE_END);
 
 	wantDensity=false;	
-	errMode.mode=PLOT_ERROR_NONE;
-	errMode.movingAverageNum=4;
+	errMode=NUM_ERR_ESTIMATE_NONE;
+	movingAverageNum=4;
 	
 	vectorParams.emplace_back(Point3D(0.0,0.0,0.0));
 	vectorParams.emplace_back(Point3D(0,20.0,0.0));
@@ -77,6 +94,40 @@ ProfileFilter::ProfileFilter() : primitiveType(PRIMITIVE_CYLINDER_AXIAL),
 	haveRangeParent=false;
 }
 
+unsigned int ProfileFilter::remapNumErrorMode() const
+{
+	if(errMode == NUM_ERR_ESTIMATE_NONE )
+		return PlotStreamData::ERROR_MODE_NONE;
+	
+	if(errMode == NUM_ERR_ESTIMATE_MOVING_AVERAGE)
+		return PlotStreamData::ERROR_MODE_MOVING_AVERAGE;
+	
+	if(normalise)
+	{
+		switch(errMode)
+		{
+			case NUM_ERR_ESTIMATE_GAUSS:
+				return PlotStreamData::ERROR_MODE_GAUSS_RATIO;
+			case NUM_ERR_ESTIMATE_POISSON:
+				return PlotStreamData::ERROR_MODE_POISSON_RATIO;
+			default:
+				ASSERT(false);
+		}
+	}
+	else
+	{
+		switch(errMode)
+		{
+			case NUM_ERR_ESTIMATE_GAUSS:
+				return PlotStreamData::ERROR_MODE_GAUSS;
+			case NUM_ERR_ESTIMATE_POISSON:
+				return PlotStreamData::ERROR_MODE_POISSON;
+			default:
+				ASSERT(false);
+		}
+	}
+}
+
 //Puts an ion in its appropriate range position, given ionID mapping,
 //range data (if any), mass to charge and the output table
 void ProfileFilter::binIon(unsigned int targetBin, const RangeStreamData* rng, 
@@ -117,6 +168,18 @@ void ProfileFilter::binIon(unsigned int targetBin, const RangeStreamData* rng,
 	}
 }
 
+unsigned int ProfileFilter::plotErrModeID(const std::string &s)
+{
+	for(auto ui=0;ui<NUM_ERR_ESTIMATE_END; ui++)
+	{
+		if(s == TRANS(NUM_ERR_ESTIMATOR_METHOD[ui]))
+			return ui;
+	}
+
+	ASSERT(false);
+	return 0;
+}
+
 
 Filter *ProfileFilter::cloneUncached() const
 {
@@ -131,7 +194,8 @@ Filter *ProfileFilter::cloneUncached() const
 	std::copy(scalarParams.begin(),scalarParams.end(),p->scalarParams.begin());
 
 	p->wantDensity=wantDensity;
-	p->normalise=normalise;	
+	p->normalise=normalise;
+	p->minEvents=minEvents;	
 	p->wantIonRemap=wantIonRemap;
 	p->remapFilename=remapFilename;
 
@@ -143,6 +207,8 @@ Filter *ProfileFilter::cloneUncached() const
 	p->nBins = nBins;
 	p->plotStyle=plotStyle;
 	p->errMode=errMode;
+	p->movingAverageNum = movingAverageNum;
+		
 	//We are copying whether to cache or not,
 	//not the cache itself
 	p->cache=cache;
@@ -510,6 +576,37 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 	normalisationFactor.resize(ionFrequencies[0].size());
 	normalisationCount.resize(ionFrequencies[0].size());
 	bool needNormalise=false;
+	
+	//Perform ion remapping
+	// note: this needs to be done before normalisation
+	IonMapTable remapTable;
+	vector<string> remappedNames;
+	if(wantIonRemap && rngData)
+	{
+		//We need to pass the ionFrequencies and their identities to remap
+		if(remapTable.read(remapFilename.c_str()))
+			return ERR_REMAPFILE_OPEN;
+
+		vector<string> inputNames;
+		inputNames.resize(ionFrequencies.size());
+
+		for(auto idx=0;idx<ionFrequencies.size();idx++)
+		{
+			unsigned int thisIonID;
+			thisIonID = inverseIDMapping.find(idx)->second;
+			inputNames[idx] = rngData->rangeFile->getName(thisIonID);
+		}
+
+		vector<vector<unsigned int> > remappedCounts;
+
+		//Remap the counts using the table
+		remapTable.remapCounts(inputNames,ionFrequencies,
+				remappedNames,remappedCounts,false);
+
+		//swap the original counts with the remapped values
+		ionFrequencies.swap(remappedCounts);
+
+	}
 
 	//Perform the appropriate normalisation
 	if(!rngData && normalise)
@@ -587,34 +684,6 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 	}
 
 
-	IonMapTable remapTable;
-	vector<string> remappedNames;
-	if(wantIonRemap && rngData)
-	{
-		//We need to pass the ionFrequencies and their identities to remap
-		if(remapTable.read(remapFilename.c_str()))
-			return ERR_REMAPFILE_OPEN;
-
-		vector<string> inputNames;
-		inputNames.resize(ionFrequencies.size());
-
-		for(auto idx=0;idx<ionFrequencies.size();idx++)
-		{
-			unsigned int thisIonID;
-			thisIonID = inverseIDMapping.find(idx)->second;
-			inputNames[idx] = rngData->rangeFile->getName(thisIonID);
-		}
-
-		vector<vector<unsigned int> > remappedCounts;
-
-		//Remap the counts using the table
-		remapTable.remapCounts(inputNames,ionFrequencies,
-				remappedNames,remappedCounts,false);
-
-		//swap the original counts with the remapped values
-		ionFrequencies.swap(remappedCounts);
-
-	}
 	//Create the plots
 	PlotStreamData *plotData[ionFrequencies.size()];
 	for(unsigned int ui=0;ui<ionFrequencies.size();ui++)
@@ -624,7 +693,11 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 		plotData[ui]->index=ui;
 		plotData[ui]->parent=this;
 		plotData[ui]->xLabel= TRANS("Distance");
-		plotData[ui]->errDat=errMode;
+		plotData[ui]->errorMode= remapNumErrorMode();
+
+		if(errMode == NUM_ERR_ESTIMATE_MOVING_AVERAGE)
+			plotData[ui]->movingAverageNum =movingAverageNum;
+
 		if(normalise)
 		{
 			//If we have composition, normalise against 
@@ -738,11 +811,41 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 				plotData[ui]->xyData.push_back(
 					std::make_pair(xPos,
 					normFactor*(float)ionFrequencies[ui][uj]));
+
+				switch(errMode)
+				{
+					case NUM_ERR_ESTIMATE_NONE:
+					case NUM_ERR_ESTIMATE_MOVING_AVERAGE:
+						break;
+					case NUM_ERR_ESTIMATE_GAUSS:
+						plotData[ui]->yErrTwoParams.push_back(make_pair((float)ionFrequencies[ui][uj],1.0/normFactor));
+
+						break;
+					case NUM_ERR_ESTIMATE_POISSON:
+						plotData[ui]->yErrTwoParams.push_back(make_pair((float)ionFrequencies[ui][uj],1.0/normFactor));
+						break;
+					default:
+						ASSERT(false);
+				}
 			}
 			else
 			{	
 				plotData[ui]->xyData.push_back(
 					std::make_pair(xPos,ionFrequencies[ui][uj]) );
+				switch(errMode)
+				{
+					case NUM_ERR_ESTIMATE_NONE:
+					case NUM_ERR_ESTIMATE_MOVING_AVERAGE:
+						break;
+					case NUM_ERR_ESTIMATE_GAUSS:
+						plotData[ui]->yErrParams.push_back((float)ionFrequencies[ui][uj]);
+						break;
+					case NUM_ERR_ESTIMATE_POISSON:
+						plotData[ui]->yErrParams.push_back((float)ionFrequencies[ui][uj]);
+						break;
+					default:
+						ASSERT(false);
+				}
 			}
 		}
 
@@ -1017,12 +1120,12 @@ bool ProfileFilter::setProperty( unsigned int key,
 		case PROFILE_KEY_ERRMODE:
 		{
 			unsigned int tmpMode;
-			tmpMode=plotErrmodeID(value);
+			tmpMode=plotErrModeID(value);
 
-			if(tmpMode >= PLOT_ERROR_ENDOFENUM)
+			if(tmpMode >= NUM_ERR_ESTIMATE_END)
 				return false;
 
-			errMode.mode= tmpMode;
+			errMode= tmpMode;
 			needUpdate=true;
 
 			break;
@@ -1036,7 +1139,7 @@ bool ProfileFilter::setProperty( unsigned int key,
 			if(tmpNum<=1)
 				return false;
 
-			errMode.movingAverageNum=tmpNum;
+			movingAverageNum=tmpNum;
 			needUpdate=true;
 			break;
 		}
@@ -1204,12 +1307,13 @@ void ProfileFilter::getProperties(FilterPropGroup &propertyList) const
 	curGroup++;
 	
 	choices.clear();
-	tmpStr=plotErrmodeString(PLOT_ERROR_NONE);
-	choices.emplace_back((unsigned int) PLOT_ERROR_NONE,tmpStr);
-	tmpStr=plotErrmodeString(PLOT_ERROR_MOVING_AVERAGE);
-	choices.emplace_back((unsigned int) PLOT_ERROR_MOVING_AVERAGE,tmpStr);
+	for(auto ui=0;ui<NUM_ERR_ESTIMATE_END; ui++)
+	{
+		tmpStr=TRANS(NUM_ERR_ESTIMATOR_METHOD[ui]);
+		choices.emplace_back(ui,tmpStr);
+	}
 
-	tmpStr= choiceString(choices,errMode.mode);
+	tmpStr= choiceString(choices,errMode);
 	p.name=TRANS("Err. Estimator");
 	p.data=tmpStr;
 	p.type=PROPERTY_TYPE_CHOICE;
@@ -1217,9 +1321,9 @@ void ProfileFilter::getProperties(FilterPropGroup &propertyList) const
 	p.key=PROFILE_KEY_ERRMODE;
 	propertyList.addProperty(p,curGroup);
 
-	if(errMode.mode == PLOT_ERROR_MOVING_AVERAGE)
+	if(errMode == PLOT_ERROR_MOVING_AVERAGE)
 	{
-		stream_cast(tmpStr,errMode.movingAverageNum);
+		stream_cast(tmpStr,movingAverageNum);
 		p.name=TRANS("Avg. Window");
 		p.data=tmpStr;
 		p.type=PROPERTY_TYPE_INTEGER;
@@ -1349,6 +1453,9 @@ bool ProfileFilter::writeState(std::ostream &f,unsigned int format, unsigned int
 				<< "\" a=\"" << rgba.a() << "\"/>" <<endl;
 
 			f << tabs(depth+1) << "<plottype value=\"" << plotStyle << "\"/>" << endl;
+			f << tabs(depth+1) << "<errestimator type=\"" << errMode << "\" averagewindow=\"" << movingAverageNum << "\"/>" << endl; 
+
+			f << tabs(depth+1) << "<remap enabled=\"" << (int)wantIonRemap << "\" file=\"" << remapFilename << "\"/>" << endl;
 			f << tabs(depth) << "</" << trueName()  << ">" << endl;
 			break;
 		}
@@ -1370,14 +1477,16 @@ void ProfileFilter::setUserString(const std::string &str)
 	}	
 }
 
-bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool ProfileFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
+	xmlNodePtr tmpNodeOrig=nodePtr;
+
 	//Retrieve user string
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"userstring"))
 		return false;
 
-	xmlChar *xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlChar *xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
@@ -1387,11 +1496,11 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	std::string tmpStr;	
 	//Retrieve primitive type 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"primitivetype"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"primitivetype"))
 		return false;
 
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1400,16 +1509,6 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	if(stream_cast(primitiveType,tmpStr))
 		return false;
 
-	//FIXME: DEPRECATE 3Depict versions <=0.0.17 had only two primitives,
-	// cylinder and sphere. 
-/*	if(versionCheckGreater(Filter::stateWriterVersion,("0.0.17")))
-	{
-		//remap the primitive type as needed
-		if(primitiveType == PRIMITIVE_CYLINDER_RADIAL)
-			primitiveType=PRIMITIVE_SPHERE;
-
-	}
-*/
 	if(primitiveType >= PRIMITIVE_END)
 	       return false;	
 	xmlFree(xmlString);
@@ -1417,10 +1516,10 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	
 	//Retrieve primitive visibility 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"showprimitive"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"showprimitive"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1433,10 +1532,10 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	
 	//Retrieve axis lock mode 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"lockaxismag"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"lockaxismag"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1449,18 +1548,18 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	
 	//Retrieve vector parameters
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"vectorparams"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"vectorparams"))
 		return false;
-	xmlNodePtr tmpNode=nodePtr;
+	xmlNodePtr tmpNode=tmpNodeOrig;
 
-	nodePtr=nodePtr->xmlChildrenNode;
+	tmpNodeOrig=tmpNodeOrig->xmlChildrenNode;
 
 	vectorParams.clear();
-	while(!XMLHelpFwdToElem(nodePtr,"point3d"))
+	while(!XMLHelpFwdToElem(tmpNodeOrig,"point3d"))
 	{
 		float x,y,z;
 		//--Get X value--
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"x");
+		xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"x");
 		if(!xmlString)
 			return false;
 		tmpStr=(char *)xmlString;
@@ -1471,7 +1570,7 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 			return false;
 
 		//--Get Z value--
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"y");
+		xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"y");
 		if(!xmlString)
 			return false;
 		tmpStr=(char *)xmlString;
@@ -1482,7 +1581,7 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 			return false;
 
 		//--Get Y value--
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"z");
+		xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"z");
 		if(!xmlString)
 			return false;
 		tmpStr=(char *)xmlString;
@@ -1496,21 +1595,21 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	}
 	//===	
 
-	nodePtr=tmpNode;
+	tmpNodeOrig=tmpNode;
 	//Retrieve scalar parameters
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"scalarparams"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"scalarparams"))
 		return false;
 	
-	tmpNode=nodePtr;
-	nodePtr=nodePtr->xmlChildrenNode;
+	tmpNode=tmpNodeOrig;
+	tmpNodeOrig=tmpNodeOrig->xmlChildrenNode;
 
 	scalarParams.clear();
-	while(!XMLHelpFwdToElem(nodePtr,"scalar"))
+	while(!XMLHelpFwdToElem(tmpNodeOrig,"scalar"))
 	{
 		float v;
 		//Get value
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+		xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 		if(!xmlString)
 			return false;
 		tmpStr=(char *)xmlString;
@@ -1541,14 +1640,14 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 			return false;
 	}
 
-	nodePtr=tmpNode;
+	tmpNodeOrig=tmpNode;
 
 	//Retrieve normalisation on/off 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"normalise"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"normalise"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1558,14 +1657,20 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 		return false;
 
 	xmlFree(xmlString);
+	
+	if(XMLHelpGetProp(minEvents,tmpNodeOrig,"minevents"))
+	{
+		//FIXME: Deprecate me.
+		minEvents=MINEVENTS_DEFAULT;
+	}
 	//====
 
 	//Retrieve fixed bins on/off 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"fixedbins"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"fixedbins"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1579,27 +1684,22 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 
 	//Retrieve num bins
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"nbins"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"nbins"))
 		return false;
 
 	
-	if(XMLHelpGetProp(nBins,nodePtr,"value"))
+	if(XMLHelpGetProp(nBins,tmpNodeOrig,"value"))
 		return false;
 
 
-	if(XMLHelpGetProp(minEvents,nodePtr,"minevents"))
-	{
-		//FIXME: Deprecate me.
-		minEvents=MINEVENTS_DEFAULT;
-	}
 	//====
 
 	//Retrieve bin width
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"binwidth"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"binwidth"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1612,18 +1712,18 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 
 	//Retrieve colour
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"colour"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"colour"))
 		return false;
-	if(!parseXMLColour(nodePtr,rgba))
+	if(!parseXMLColour(tmpNodeOrig,rgba))
 		return false;
 	//====
 	
 	//Retrieve plot type 
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"plottype"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"plottype"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1637,9 +1737,39 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	xmlFree(xmlString);
 	//====
 
+	//Retrieve error estimator (if present)
+	// Not present for 3Depict < 0.0.23
+
+	tmpNode=tmpNodeOrig;	
+	if(!XMLHelpFwdToElem(tmpNode,"errestimator"))
+	{
+		if(XMLHelpGetProp(errMode,tmpNode,"type"))
+			return false;
+		
+		if(XMLHelpGetProp(movingAverageNum,tmpNode,"type"))
+			return false;
+	}
+
+	//Retreive remap file status
+	tmpNode=tmpNodeOrig;
+
+	if(!XMLHelpFwdToElem(tmpNode,"remap"))
+	{
+		if(XMLHelpGetProp(wantIonRemap,tmpNode,"enabled"))
+			return false;
+
+		if(XMLHelpGetProp(remapFilename,tmpNode,"file"))
+			return false;
+	}
+
 	return true;
 }
 
+void ProfileFilter::getStateOverrides(std::vector<string> &externalAttribs) const
+{
+	externalAttribs.push_back(remapFilename);
+}
+
 unsigned int ProfileFilter::getRefreshBlockMask() const
 {
 	//Absolutely anything can go through this filter.
@@ -1710,6 +1840,7 @@ unsigned int ProfileFilter::getPrimitiveId(const std::string &primitiveName)
 
 bool testDensityCylinder();
 bool testCompositionCylinder();
+bool testCompositionRemap();
 void synthComposition(const vector<pair<float,float> > &compositionData,
 			vector<IonHit> &h);
 IonStreamData *synthLinearProfile(const Point3D &start, const Point3D &end,
@@ -1722,6 +1853,8 @@ bool ProfileFilter::runUnitTests()
 
 	if(!testCompositionCylinder())
 		return false;
+	if(!testCompositionRemap())
+		return false;
 
 	return true;
 }
@@ -1771,12 +1904,12 @@ bool testCompositionCylinder()
 	bool needUp; std::string s;
 	stream_cast(s,Point3D((startPt+endPt)*0.5f));
 	TEST(f->setProperty(PROFILE_KEY_ORIGIN,s,needUp),"set origin");
-	TEST(f->setProperty(PROFILE_KEY_MINEVENTS,"0",needUp),"set origin");
+	TEST(f->setProperty(PROFILE_KEY_MINEVENTS,"0",needUp),"set min events");
 	
 	stream_cast(s,Point3D((endPt-startPt)*0.5f));
 	TEST(f->setProperty(PROFILE_KEY_NORMAL,s,needUp),"set direction");
 	TEST(f->setProperty(PROFILE_KEY_SHOWPRIMITIVE,"1",needUp),"Set cylinder visibility");
-	TEST(f->setProperty(PROFILE_KEY_NORMALISE,"1",needUp),"Disable normalisation");
+	TEST(f->setProperty(PROFILE_KEY_NORMALISE,"1",needUp),"Enable normalisation");
 	TEST(f->setProperty(PROFILE_KEY_RADIUS,"5",needUp),"Set radius");
 	
 	//Inform the filter about the range stream
@@ -1838,6 +1971,120 @@ bool testCompositionCylinder()
 	return true;
 }
 
+bool testCompositionRemap()
+{
+	const unsigned int NUM_PTS=100;
+	//Create a cylinder of data, forming a linear profile
+	Point3D startPt(-1.0f,-1.0f,-1.0f),endPt(1.0f,1.0f,1.0f);
+
+	//Synthesise some data.
+	auto d= synthLinearProfile(startPt,endPt,
+			0.5f, NUM_PTS);
+
+	//Generate two compositions for the test dataset
+	{
+	vector<std::pair<float,float>  > vecCompositions;
+	vecCompositions.emplace_back(2.0f,0.5f);
+	vecCompositions.emplace_back(3.0f,0.5f);
+	synthComposition(vecCompositions,d->data);
+	}
+
+	//Build a faux rangestream
+	RangeStreamData *rngStream;
+	rngStream = new RangeStreamData;
+	rngStream->rangeFile = new RangeFile;
+	
+	RGBf rgb; rgb.red=rgb.green=rgb.blue=1.0f;
+
+	unsigned int aIon,bIon;
+	std::string tmpStr;
+	tmpStr="A";
+	aIon=rngStream->rangeFile->addIon(tmpStr,tmpStr,rgb);
+	tmpStr="B";
+	bIon=rngStream->rangeFile->addIon(tmpStr,tmpStr,rgb);
+	rngStream->rangeFile->addRange(1.5,2.5,aIon);
+	rngStream->rangeFile->addRange(2.5,3.5,bIon);
+	rngStream->enabledIons.resize(2,true);
+	rngStream->enabledRanges.resize(2,true);
+
+	//Create a synthetic remap file
+	string fRemap=stlStr(wxFileName::CreateTempFileName("remap-tmp"));
+	
+	std::ofstream out(fRemap.c_str());
+	if(!out)
+	{
+		WARN(false,"Unable to test remap in profile , no write permission");
+		return true;
+	}
+	else
+	{
+		out << "<ionmap><entry name=\"A\"><ion name=\"C\" count=\"1\"/><ion name=\"D\" count=\"2\"/></entry></ionmap>";
+		out.close();
+	}
+
+	//Construct the composition filter
+	ProfileFilter *f = new ProfileFilter;
+
+	//Build some points to pass to the filter
+	vector<const FilterStreamData*> streamIn,streamOut;
+	
+	bool needUp; std::string s;
+	stream_cast(s,Point3D((startPt+endPt)*0.5f));
+	TEST(f->setProperty(PROFILE_KEY_ORIGIN,s,needUp),"set origin");
+	TEST(f->setProperty(PROFILE_KEY_MINEVENTS,"0",needUp),"Set min Events");
+	TEST(f->setProperty(PROFILE_KEY_WANTREMAP,"1",needUp),"Enable remap");
+	TEST(f->setProperty(PROFILE_KEY_REMAPFILE,fRemap,needUp),"Set remap file");
+	
+	stream_cast(s,Point3D((endPt-startPt)*0.5f));
+	TEST(f->setProperty(PROFILE_KEY_NORMAL,s,needUp),"set direction");
+	TEST(f->setProperty(PROFILE_KEY_SHOWPRIMITIVE,"1",needUp),"Set cylinder visibility");
+	TEST(f->setProperty(PROFILE_KEY_NORMALISE,"1",needUp),"Enable normalisation");
+	TEST(f->setProperty(PROFILE_KEY_RADIUS,"5",needUp),"Set radius");
+
+	//Inform the filter about the range stream
+	streamIn.push_back(rngStream);
+	f->initFilter(streamIn,streamOut);
+	
+	streamIn.push_back(d);
+	f->setCaching(false);
+
+
+	ProgressData p;
+	TEST(!f->refresh(streamIn,streamOut,p),"Refresh error code");
+	
+	delete d;
+
+	//3* plot, 1*rng, 1*draw. NOte that only A is generated, and decomposed to C,D
+	// A,B,C is emitted
+	TEST(streamOut.size() == 5, "output stream count");
+	
+	for(unsigned int ui=0;ui<streamOut.size();ui++)
+	{
+		if(streamOut[ui]->getStreamType() == STREAM_TYPE_PLOT)
+		{
+			//Weak test to check that composition lies in the right range
+			const PlotStreamData* plotData = (const PlotStreamData *)streamOut[ui];
+			for(auto &v : plotData->xyData)
+			{
+				TEST(v.second <= 1.0f && 
+					v.second >=0.0f,"normalised data range test"); 
+			}
+
+		}
+	}
+
+
+
+	delete rngStream->rangeFile;
+	for(unsigned int ui=0;ui<streamOut.size();ui++)
+		delete streamOut[ui];
+
+
+	delete f;
+
+	return true;
+}
+
 bool testDensityCylinder()
 {
 	IonStreamData *d;
