@@ -1102,15 +1102,16 @@ bool RangeFileFilter::writeState(std::ostream &f,unsigned int format, unsigned i
 	return true;
 }
 
-bool RangeFileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool RangeFileFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
-	
+	xmlNodePtr tmpNodeOrig=nodePtr;
+
 	//Retrieve user string
 	//==
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"userstring"))
 		return false;
 
-	xmlChar *xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlChar *xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
@@ -1120,9 +1121,9 @@ bool RangeFileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFil
 	//Retrieve file name	
 	//==
 	//Retrieve file name	
-	if(XMLHelpFwdToElem(nodePtr,"file"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"file"))
 		return false;
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"name");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"name");
 	if(!xmlString)
 		return false;
 	rngName=(char *)xmlString;
@@ -1141,7 +1142,7 @@ bool RangeFileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFil
 
 	//TODO: Deprecate me. Did not exist prior to 0.0.17/
 	// internal 3e88134daeea
-	xmlNodePtr tmpNode=nodePtr;
+	xmlNodePtr tmpNode=tmpNodeOrig;
 	if(!XMLHelpFwdToElem(tmpNode,"legend"))
 	{
 		if(XMLHelpGetProp(showLegend,tmpNode,"enabled"))
@@ -1155,7 +1156,7 @@ bool RangeFileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFil
 	std::string tmpStr;
 	//Retrieve range status 
 	//==
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"dropunranged","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"dropunranged","value"))
 		return false;
 
 	if(!boolStrDec(tmpStr,dropUnranged))
@@ -1166,21 +1167,21 @@ bool RangeFileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFil
 
 	//Retrieve enabled ions	
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"enabledions"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"enabledions"))
 		return false;
-	tmpNode=nodePtr;
+	tmpNode=tmpNodeOrig;
 
-	nodePtr=nodePtr->xmlChildrenNode;
+	tmpNodeOrig=tmpNodeOrig->xmlChildrenNode;
 
 	unsigned int ionID;
 	bool enabled;
 	//By default, turn ions off, but use state file to turn them on
 	map<unsigned int ,char> tmpEnabledIons;
 	map<unsigned int ,RGBf> tmpCol;
-	while(!XMLHelpFwdToElem(nodePtr,"ion"))
+	while(!XMLHelpFwdToElem(tmpNodeOrig,"ion"))
 	{
 		//Get ID value
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"id");
+		xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"id");
 		if(!xmlString)
 			return false;
 		tmpStr=(char *)xmlString;
@@ -1193,7 +1194,7 @@ bool RangeFileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFil
 		if(ionID>= rng.getNumIons()) 
 			return false;
 		
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"enabled");
+		xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"enabled");
 		if(!xmlString)
 			return false;
 		tmpStr=(char *)xmlString;
@@ -1204,7 +1205,7 @@ bool RangeFileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFil
 		xmlFree(xmlString);
 		
 		
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"colour");
+		xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"colour");
 		if(!xmlString)
 			return false;
 
@@ -1223,22 +1224,22 @@ bool RangeFileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFil
 	//===
 
 
-	nodePtr=tmpNode;
+	tmpNodeOrig=tmpNode;
 	//Retrieve enabled ranges
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"enabledranges"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"enabledranges"))
 		return false;
-	tmpNode=nodePtr;
+	tmpNode=tmpNodeOrig;
 
-	nodePtr=nodePtr->xmlChildrenNode;
+	tmpNodeOrig=tmpNodeOrig->xmlChildrenNode;
 
 	//By default, turn ranges off (cause there are lots of them), and use state to turn them on
 	map<unsigned int, char> tmpEnabledRanges;
 	unsigned int rngID;
-	while(!XMLHelpFwdToElem(nodePtr,"range"))
+	while(!XMLHelpFwdToElem(tmpNodeOrig,"range"))
 	{
 		//Get ID value
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"id");
+		xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"id");
 		if(!xmlString)
 			return false;
 		tmpStr=(char *)xmlString;
@@ -1251,7 +1252,7 @@ bool RangeFileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFil
 		if(rngID>= rng.getNumRanges()) 
 			return false;
 		
-		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"enabled");
+		xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"enabled");
 		if(!xmlString)
 			return false;
 		tmpStr=(char *)xmlString;
