@@ -18,6 +18,7 @@
 #ifndef SPATIALANALYSIS_H
 #define SPATIALANALYSIS_H
 #include "../filter.h"
+#include "filterCommon.h"
 #include "../../common/translation.h"
 
 //!Spatial analysis filter
@@ -153,7 +154,34 @@ class SpatialAnalysisFilter : public Filter
 		size_t algorithmRDF(ProgressData &progress, size_t totalDataSize, 
 			const std::vector<const FilterStreamData *>  &dataIn, 
 			std::vector<const FilterStreamData * > &getOut,const RangeFile *rngF);
+		//---------
 
+		//Linear decomposition specific
+		//---------
+		//Maximal number of eigen/singular values/vectors  to retain
+		unsigned int maxSingularvalues;
+		//Size of voxel to use
+		float voxelLength;
+		//Spectral bin width
+		float spectralBinWidth;
+		//Auto determine bins?
+		bool autoSpectraMinMax;
+		//Mass start/end
+		float spectraStartMass, spectraEndMass;
+
+		//Do we want to show the components in their scaled form?
+		bool scaleBasisVectors;
+		//Do we want to show the residual plot?
+		bool showResidualPlot;
+
+		//Which of the output singular values do we wisht to dispaly
+		unsigned int singularValueVoxelDisplayIdx;
+
+		VoxelAppearanceProperties voxAppearance;
+
+		vector<Voxels<float> > voxelCache;
+		
+		//---------
 
 		//Local density function - places a sphere around each point to compute per-point density
 		size_t algorithmDensity(ProgressData &progress, size_t totalDataSize, 
@@ -207,6 +235,11 @@ class SpatialAnalysisFilter : public Filter
 		vector<bool> expandEnabledToParentRange(const vector<bool> &vb, 
 							const RangeFile *rngF) const;
 
+		//!Linearly decompose the input data into linear basis components. Generates spectra for each factor
+		// and voxels that represent the loading factors for each component
+		size_t algorithmLinearDecomposition(ProgressData &progress, size_t totalDataSize, 
+			const vector<const FilterStreamData *>  &dataIn, 
+			vector<const FilterStreamData * > &getOut);
 	public:
 		SpatialAnalysisFilter(); 
 		//!Duplicate filter contents, excluding cache.
@@ -246,11 +279,11 @@ class SpatialAnalysisFilter : public Filter
 		virtual bool writePackageState(std::ostream &f, unsigned int format,
 				const std::vector<std::string> &valueOverrides,unsigned int depth=0) const;
 		//Obtain the state file override 
-		void getStateOverrides(std::vector<string> &externalAttribs) const; 
+		void getStateOverrides(std::vector<std::string> &externalAttribs) const; 
 
 		//!Read the state of the filter from XML file. If this
 		//fails, filter will be in an undefined state.
-		bool readState(xmlNodePtr &node, const std::string &packDir);
+		bool readState(const xmlNodePtr &node, const std::string &packDir);
 		
 		//!Get the stream types that will be dropped during ::refresh	
 		unsigned int getRefreshBlockMask() const;
