@@ -17,6 +17,7 @@
 */
 #include "spectrumPlot.h"
 #include "algorithms/mass.h"
+#include "../stats/confidence.h"
 
 #include "../plot.h"
 
@@ -56,7 +57,7 @@ enum
 };
 
 //Limit user to two :million: bins
-const unsigned int SPECTRUM_MAX_BINS=2000000;
+const unsigned int SPECTRUM_MAX_BINS=1000000;
 
 const unsigned int SPECTRUM_AUTO_MAX_BINS=45000;
 
@@ -254,6 +255,10 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 			nBins = 10;
 			binWidth = (maxPlot-minPlot)/nBins;
 		}
+
+		//Notify the user if we reach the maximum number of spectrum bins, as the output wil be truncated
+		if(nBins == SPECTRUM_MAX_BINS)
+			appendConsoleMessage(TRANS("WARNING : maximum number of bins reached. Spectrum may be truncated"));
 	}
 
 
@@ -460,6 +465,7 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 		}
 		else 
 		{
+			float intensityPerBin = backParams.intensity;
 			if (!showOnlyCorrected)
 			{
 				vector<float> backgroundHist;
@@ -477,36 +483,92 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 				plotBack->xyData.reserve(d->xyData.size());
 
 
-				float intensityPerBin = backParams.intensity;
-				for(size_t ui=0;ui<d->xyData.size(); ui++)
 
+				switch(fitMode)
 				{
-					//negative sqrt cannot does not work. Equation only valid for positive masses
-					if(d->xyData[ui].first <=0)
-						continue;
-		
-					plotBack->xyData.emplace_back( d->xyData[ui].first,
-							intensityPerBin/(2.0*sqrtf(d->xyData[ui].first)));
+					case FIT_MODE_CONST_TOF_SIMPLE:
+					{
+						for(size_t ui=0;ui<d->xyData.size(); ui++)
+
+						{
+							//negative sqrt cannot does not work. Equation only valid for positive masses
+							if(d->xyData[ui].first <=0)
+								continue;
+				
+							plotBack->xyData.emplace_back( d->xyData[ui].first,
+									intensityPerBin/(2.0*sqrtf(d->xyData[ui].first)));
+					
+						}
+						break;
+					}
+					case FIT_MODE_CONST_TOF_ZECH:
+					{
+						for(size_t ui=0;ui<d->xyData.size(); ui++)
+
+						{
+							//negative sqrt cannot does not work. Equation only valid for positive masses
+							if(d->xyData[ui].first <=0)
+								continue;
 			
+							float thisIntensity;	
+							thisIntensity=intensityPerBin/(2.0*sqrtf(d->xyData[ui].first));
+
+							float correctedInt;
+							zechConfidenceLimits(thisIntensity,d->xyData[ui].second,0.5,correctedInt);
+
+							plotBack->xyData.emplace_back(d->xyData[ui].first,d->xyData[ui].second-correctedInt);
+						}
+
+						break;
+					}
+					default:
+						ASSERT(false);
 				}
 
 			}
 			else
 			{
-				//Correct the mass spectrum that we display
-				for(size_t ui=0;ui<d->xyData.size(); ui++)
+				switch(fitMode)
 				{
-					//negative sqrt cannot does not work. Equation only valid for positive masses
-					if(d->xyData[ui].first <=0)
+					case FIT_MODE_CONST_TOF_SIMPLE:
 					{
-						d->xyData[ui].second =0;
-						continue;
-					}
-	
-					d->xyData[ui].second-=backParams.intensity/sqrtf(d->xyData[ui].first);
+						//Correct the mass spectrum that we display
+						for(size_t ui=0;ui<d->xyData.size(); ui++)
+						{
+							//negative sqrt cannot does not work. Equation only valid for positive masses
+							if(d->xyData[ui].first <=0)
+							{
+								d->xyData[ui].second =0;
+								continue;
+							}
 
+							d->xyData[ui].second-=backParams.intensity/sqrtf(d->xyData[ui].first);
+
+					
+						}
+						break;
+					}
+					case FIT_MODE_CONST_TOF_ZECH:
+					{
+						for(size_t ui=0;ui<d->xyData.size(); ui++)
+
+						{
+							//negative sqrt cannot does not work. Equation only valid for positive masses
+							if(d->xyData[ui].first <=0)
+								continue;
 			
-				}
+							float thisIntensity;	
+							thisIntensity=intensityPerBin/(2.0*sqrtf(d->xyData[ui].first));
+
+							float correctedInt;
+							zechConfidenceLimits(thisIntensity,d->xyData[ui].second,0.5,correctedInt);
+							d->xyData[ui].second=correctedInt;
+						}
+
+						break;
+					}
+					default:
+						ASSERT(false);
 				//prevent negative values in log mode
 				if(logarithmic)
 				{
@@ -515,9 +577,9 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 				}
 				
 			}
+			}
 		}
 	}
-
 	if(normaliseMode != NORMALISE_NONE)
 	{
 		float scaleFact;
@@ -548,7 +610,8 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 				case FIT_MODE_NONE:
 					//Do nothing
 					break;
-				case FIT_MODE_CONST_TOF:
+				case FIT_MODE_CONST_TOF_SIMPLE:
+				case FIT_MODE_CONST_TOF_ZECH:
 					for(unsigned int ui=0;ui<plotBack->xyData.size();ui++)
 						plotBack->xyData[ui].second/=scaleFact;
 					break;
@@ -719,7 +782,8 @@ void SpectrumPlotFilter::getProperties(FilterPropGroup &propertyList) const
 	{
 		case FIT_MODE_NONE:
 			break;
-		case FIT_MODE_CONST_TOF:
+		case FIT_MODE_CONST_TOF_SIMPLE:
+		case FIT_MODE_CONST_TOF_ZECH:
 		{
 			//Add start/end TOF 
 			FilterProperty pFitStart(KEY_SPECTRUM_BACKMODE_FLAT_START, TRANS("Fit Start"),
@@ -729,8 +793,8 @@ void SpectrumPlotFilter::getProperties(FilterPropGroup &propertyList) const
 			FilterProperty pFitEnd(KEY_SPECTRUM_BACKMODE_FLAT_END, TRANS("Fit End"),
 				 massBackEnd,TRANS("End mass value for fitting background"));
 			propertyList.addProperty(pFitEnd,curGroup);
-		}
 			break;
+		}
 		default:
 			ASSERT(false);
 	}
@@ -936,7 +1000,7 @@ bool SpectrumPlotFilter::setProperty( unsigned int key,
 		}
 		case KEY_SPECTRUM_BACKMODE:
 		{
-			unsigned int newMode;
+			unsigned int newMode=FIT_MODE_ENUM_END;
 			for(size_t ui=0;ui<FIT_MODE_ENUM_END; ui++)
 			{
 				if(string(BACKGROUND_MODE_STRING[ui]) == string(value))
@@ -1121,17 +1185,19 @@ bool SpectrumPlotFilter::writeState(std::ostream &f,unsigned int format, unsigne
 	return true;
 }
 
-bool SpectrumPlotFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool SpectrumPlotFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
+	xmlNodePtr tmpNodeOrig=nodePtr;
+	
 	using std::string;
 	string tmpStr;
 
 	//Retrieve user string
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"userstring"))
 		return false;
 
-	xmlChar *xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlChar *xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 
@@ -1142,10 +1208,10 @@ bool SpectrumPlotFilter::readState(xmlNodePtr &nodePtr, const std::string &state
 	//Retrieve Extrema 
 	//===
 	float tmpMin,tmpMax;
-	if(XMLHelpFwdToElem(nodePtr,"extrema"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"extrema"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"min");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"min");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1155,7 +1221,7 @@ bool SpectrumPlotFilter::readState(xmlNodePtr &nodePtr, const std::string &state
 	if(stream_cast(tmpMin,tmpStr))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"max");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"max");
 	if(!xmlString)
 		return false;
 	tmpStr=(char *)xmlString;
@@ -1172,7 +1238,7 @@ bool SpectrumPlotFilter::readState(xmlNodePtr &nodePtr, const std::string &state
 	minPlot=tmpMin;
 	maxPlot=tmpMax;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"auto");
+	xmlString=xmlGetProp(tmpNodeOrig,(const xmlChar *)"auto");
 	if(!xmlString)
 		return false;
 	
@@ -1189,7 +1255,7 @@ bool SpectrumPlotFilter::readState(xmlNodePtr &nodePtr, const std::string &state
 	//Retrieve bin width 
 	//====
 	//
-	if(!XMLGetNextElemAttrib(nodePtr,binWidth,"binwidth","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,binWidth,"binwidth","value"))
 		return false;
 	if(binWidth  <= 0.0)
 		return false;
@@ -1199,17 +1265,17 @@ bool SpectrumPlotFilter::readState(xmlNodePtr &nodePtr, const std::string &state
 	//====
 	//Retrieve colour
 	//====
-	if(XMLHelpFwdToElem(nodePtr,"colour"))
+	if(XMLHelpFwdToElem(tmpNodeOrig,"colour"))
 		return false;
 	ColourRGBAf tmpRgba;
-	if(!parseXMLColour(nodePtr,tmpRgba))
+	if(!parseXMLColour(tmpNodeOrig,tmpRgba))
 		return false;
 	rgba=tmpRgba;
 	//====
 	
 	//Retrieve logarithmic mode
 	//====
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"logarithmic","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,tmpStr,"logarithmic","value"))
 		return false;
 	if(!boolStrDec(tmpStr,logarithmic))
 		return false;
@@ -1217,7 +1283,7 @@ bool SpectrumPlotFilter::readState(xmlNodePtr &nodePtr, const std::string &state
 
 	//Retrieve plot type 
 	//====
-	if(!XMLGetNextElemAttrib(nodePtr,plotStyle,"plottype","value"))
+	if(!XMLGetNextElemAttrib(tmpNodeOrig,plotStyle,"plottype","value"))
 		return false;
 	if(plotStyle >= PLOT_LINE_NONE)
 	       return false;	
@@ -1226,45 +1292,45 @@ bool SpectrumPlotFilter::readState(xmlNodePtr &nodePtr, const std::string &state
 	//Retrieve background fitting mode, if we have it
 	// Only available 3Depict >= 0.0.18
 	// internal rev > 5e7b66e5ce3d
-	xmlNodePtr  tmpNode=nodePtr;
-	if(!XMLHelpFwdToElem(nodePtr,"background"))
+	xmlNodePtr  tmpNode=tmpNodeOrig;
+	if(!XMLHelpFwdToElem(tmpNodeOrig,"background"))
 	{
-		if(XMLHelpGetProp(fitMode,nodePtr,"mode"))
+		if(XMLHelpGetProp(fitMode,tmpNodeOrig,"mode"))
 			return false;
 
-		if(!nodePtr->xmlChildrenNode)
+		if(!tmpNodeOrig->xmlChildrenNode)
 			return false;
 			
-		tmpNode=nodePtr;
-		nodePtr=nodePtr->xmlChildrenNode;
+		tmpNode=tmpNodeOrig;
+		tmpNodeOrig=tmpNodeOrig->xmlChildrenNode;
 		
-		if(!XMLGetNextElemAttrib(nodePtr,massBackStart,"fitwindow","start"))
+		if(!XMLGetNextElemAttrib(tmpNodeOrig,massBackStart,"fitwindow","start"))
 			return false;
 
-		if(XMLHelpGetProp(massBackEnd,nodePtr,"end"))
+		if(XMLHelpGetProp(massBackEnd,tmpNodeOrig,"end"))
 			return false;
 		
-		if(!XMLGetNextElemAttrib(nodePtr,showOnlyCorrected,"showonlycorrected","value"))
+		if(!XMLGetNextElemAttrib(tmpNodeOrig,showOnlyCorrected,"showonlycorrected","value"))
 			return false;
-		nodePtr=tmpNode;
+		tmpNodeOrig=tmpNode;
 	}
 	else
 	{
-		nodePtr=tmpNode;
+		tmpNodeOrig=tmpNode;
 	}
 	
 	// Only available 3Depict >= 0.0.18
 	// internal rev > 73289623683a tip
-	if(!XMLHelpFwdToElem(nodePtr,"normalise"))
+	if(!XMLHelpFwdToElem(tmpNodeOrig,"normalise"))
 	{
-		if(XMLHelpGetProp(normaliseMode,nodePtr,"mode"))
+		if(XMLHelpGetProp(normaliseMode,tmpNodeOrig,"mode"))
 			return false;
 
 		float tmpLow,tmpHigh;		
-		if(XMLHelpGetProp(tmpLow,nodePtr,"lowbound"))
+		if(XMLHelpGetProp(tmpLow,tmpNodeOrig,"lowbound"))
 			return false;
 	
-		if(XMLHelpGetProp(tmpHigh,nodePtr,"highbound"))
+		if(XMLHelpGetProp(tmpHigh,tmpNodeOrig,"highbound"))
 			return false;
 
 		if(tmpLow >=tmpHigh)
@@ -1301,7 +1367,7 @@ unsigned int SpectrumPlotFilter::getRefreshUseMask() const
 
 bool SpectrumPlotFilter::needsUnrangedData() const
 {
-	return fitMode == FIT_MODE_CONST_TOF;
+	return (fitMode == FIT_MODE_CONST_TOF_SIMPLE || fitMode == FIT_MODE_CONST_TOF_ZECH);
 }
 
 #ifdef DEBUG
