@@ -84,7 +84,7 @@ class TransformFilter : public Filter
 						unsigned int depth=0) const;
 		//!Read the state of the filter from XML file. If this
 		//fails, filter will be in an undefined state.
-		bool readState(xmlNodePtr &node, const std::string &packDir);
+		bool readState(const xmlNodePtr &node, const std::string &packDir);
 		
 		//!Get the stream types that will be dropped during ::refresh	
 		unsigned int getRefreshBlockMask() const;
