@@ -106,6 +106,11 @@ const char *VOXELISE_FILTER_TYPE_STRING[]={
 	NTRANS("Lapl. of Gauss. (edges)"),
 	};
 
+using std::string;
+using std::stack;
+using std::pair;
+using std::vector;
+
 
 //This is not a member of voxels.h, as the voxels do not have any concept of the IonHit
 int countPoints(Voxels<float> &v, const std::vector<IonHit> &points, 
@@ -345,38 +350,50 @@ unsigned int VoxeliseFilter::refresh(const std::vector<const FilterStreamData *>
 	Voxels<bool> voxelMask;
 	if(!voxelCache.size())
 	{
+		if(*Filter::wantAbort)
+			return VOXELISE_ABORT_ERR;
+
 		Point3D minP,maxP;
 
 		bc.setInverseLimits();
-		
-		//FIXME: this is technically wrong in some edge cases. 
-		// We disallow pair-wise points, even though if taken in conjunction
-		// they might form a valid bounding box	with other points not in the same
-		// data stream
+	
+		//Compute the overall bounding box
 		for (size_t i = 0; i < dataIn.size(); i++) 
 		{
 			//Check for ion stream types. Block others from propagation.
 			if (dataIn[i]->getStreamType() != STREAM_TYPE_IONS) continue;
 
 			const IonStreamData *is = (const IonStreamData *)dataIn[i];
-			//Don't work on empty or single object streams (bounding box needs to be defined)
-			if (is->getNumBasicObjects() < 2) continue;
+
+			//Don't work on empty object streams 
+			if (!is->getNumBasicObjects()) 
+				continue;
 		
 			BoundCube bcTmp;
 			IonHit::getBoundCube(is->data,bcTmp);
 
 			//Bounds could be invalid if, for example, we had coplanar axis aligned points
-			if (!bcTmp.isValid()) continue;
+			if (!bcTmp.isValid())
+			{
+				bcTmp.expand(is->data);
+				continue;
+			}
 
 			bc.expand(bcTmp);
 		}
 		//No bounding box? Tough cookies
 		if (!bc.isValid() || bc.isFlat()) return VOXELISE_BOUNDS_INVALID_ERR;
 
+		if(*Filter::wantAbort)
+			return VOXELISE_ABORT_ERR;
+
 		bc.getBounds(minP,maxP);	
 		//Disallow empty bounding boxes (ie, produce no output)
 		if(minP == maxP)
 			return 0;
+		
+		if(*Filter::wantAbort)
+			return VOXELISE_ABORT_ERR;
 
 		if (fixedWidth) 
 			calculateNumBinsFromWidths(binWidth, nBins);
@@ -389,6 +406,9 @@ unsigned int VoxeliseFilter::refresh(const std::vector<const FilterStreamData *>
 		voxelData.init(nBins[0], nBins[1], nBins[2], bc);
 		voxelData.fill(0);
 		
+		if(*Filter::wantAbort)
+			return VOXELISE_ABORT_ERR;
+		
 		//If we are normalising using count data, then initialise the denominator with zeros	
 		if (normaliseType == VOXELISE_NORMALISETYPE_COUNT2INVOXEL ||
 			normaliseType == VOXELISE_NORMALISETYPE_ALLATOMSINVOXEL) {
@@ -521,13 +541,20 @@ unsigned int VoxeliseFilter::refresh(const std::vector<const FilterStreamData *>
 			//Compute threshold mask if needed
 			if(thresholdMaskEnable) 	
 				voxelData.thresholdToBoolMask(threshMaskValue,true,voxelMask);
+			if(*Filter::wantAbort)
+				return VOXELISE_ABORT_ERR;
 
 			//Compute normalisations if needed
 			if (normaliseType == VOXELISE_NORMALISETYPE_VOLUME)
 				voxelData.calculateDensity();
+			if(*Filter::wantAbort)
+				return VOXELISE_ABORT_ERR;
 		}	
 		progress.filterProgress=100;
 
+		if(*Filter::wantAbort)
+			return VOXELISE_ABORT_ERR;
+		
 		vsDenom.clear();
 		
 		//Perform threshold operations as needed
@@ -543,6 +570,9 @@ unsigned int VoxeliseFilter::refresh(const std::vector<const FilterStreamData *>
 			voxelData.applyMask(voxelMask,replaceValue);
 		}
 
+		if(*Filter::wantAbort)
+			return VOXELISE_ABORT_ERR;
+		
 		//Perform voxel filtering
 		switch(filterMode)
 		{
@@ -551,19 +581,24 @@ unsigned int VoxeliseFilter::refresh(const std::vector<const FilterStreamData *>
 			case VOXELISE_FILTERTYPE_GAUSS:
 			{	
 				progress.stepName=TRANS("Gauss Smooth");
-				voxelData.isotropicGaussianSmooth(gaussDev,filterKernelSize);
+				if(!voxelData.isotropicGaussianSmooth(gaussDev,filterKernelSize))
+					return VOXELISE_CONVOLVE_ERR;
 				break;
 			}
 			case VOXELISE_FILTERTYPE_LAPLACE:
 			{
 				progress.stepName=TRANS("Calc. Laplace");
-				voxelData.laplaceOfGaussian(gaussDev,filterKernelSize);
+				if(!voxelData.laplaceOfGaussian(gaussDev,filterKernelSize))
+					return VOXELISE_CONVOLVE_ERR;
 				break;
 			}
 			default:
 				ASSERT(false);
 		}
 	
+		if(*Filter::wantAbort)
+			return VOXELISE_ABORT_ERR;
+		
 		voxelCache=voxelData;
 	}
 	else
@@ -1126,8 +1161,10 @@ bool VoxeliseFilter::writeState(std::ostream &f,unsigned int format, unsigned in
 	return true;
 }
 
-bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
+bool VoxeliseFilter::readState(const xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
+	xmlNodePtr tmpNode=nodePtr;
+
 	using std::string;
 	string tmpStr;
 	xmlChar *xmlString;
@@ -1135,10 +1172,10 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 
 	//Retrieve user string
 	//===
-	if(XMLHelpFwdToElem(nodePtr,"userstring"))
+	if(XMLHelpFwdToElem(tmpNode,"userstring"))
 		return false;
 
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"value");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"value");
 	if(!xmlString)
 		return false;
 	userString=(char *)xmlString;
@@ -1146,15 +1183,15 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	//===
 
 	//Retrieve fixedWidth mode
-	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"fixedwidth","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,tmpStr,"fixedwidth","value"))
 		return false;
 	if(!boolStrDec(tmpStr,fixedWidth))
 		return false;
 	
 	//Retrieve nBins	
-	if(XMLHelpFwdToElem(nodePtr,"nbins"))
+	if(XMLHelpFwdToElem(tmpNode,"nbins"))
 		return false;
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"values");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"values");
 	if(!xmlString)
 		return false;
 	std::vector<string> v1;
@@ -1170,9 +1207,9 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	xmlFree(xmlString);
 	
 	//Retrieve bin width 
-	if(XMLHelpFwdToElem(nodePtr,"binwidth"))
+	if(XMLHelpFwdToElem(tmpNode,"binwidth"))
 		return false;
-	xmlString=xmlGetProp(nodePtr,(const xmlChar *)"values");
+	xmlString=xmlGetProp(tmpNode,(const xmlChar *)"values");
 	if(!xmlString)
 		return false;
 	std::vector<string> v2;
@@ -1191,7 +1228,7 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	// statefiles will not have this data. Do not abort if we can't find it.
 	{
 		xmlNodePtr tmpPtr;
-		tmpPtr =nodePtr;
+		tmpPtr =tmpNode;
 
 		if(!XMLHelpFwdToElem(tmpPtr, "filter"))
 		{
@@ -1206,7 +1243,7 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 
 
 	//Retrieve normaliseType
-	if(!XMLGetNextElemAttrib(nodePtr,normaliseType,"normalisetype","value"))
+	if(!XMLGetNextElemAttrib(tmpNode,normaliseType,"normalisetype","value"))
 		return false;
 	if(normaliseType >= VOXELISE_NORMALISETYPE_MAX)
 		return false;
@@ -1214,7 +1251,7 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	//FIXME: COMPAT_BREAK : This feature did not exist < 0.0.22. Disabled by default
 	{
 		xmlNodePtr tmpPtr;
-		tmpPtr=nodePtr;
+		tmpPtr=tmpNode;
 		if(!XMLHelpFwdToElem(tmpPtr,"countmask"))
 		{
 			if(!XMLGetAttrib(tmpPtr,thresholdMaskEnable,"enable"))
@@ -1231,30 +1268,30 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	//-------	
 	//
 	
-	if(!XMLHelpFwdToElem(nodePtr,"enabledions"))
+	if(!XMLHelpFwdToElem(tmpNode,"enabledions"))
 	{
 
-		nodeStack.push(nodePtr);
-		if(!nodePtr->xmlChildrenNode)
+		nodeStack.push(tmpNode);
+		if(!tmpNode->xmlChildrenNode)
 			return false;
-		nodePtr=nodePtr->xmlChildrenNode;
+		tmpNode=tmpNode->xmlChildrenNode;
 		
 		//enabled ions for numerator
-		if(XMLHelpFwdToElem(nodePtr,"numerator"))
+		if(XMLHelpFwdToElem(tmpNode,"numerator"))
 			return false;
 
-		nodeStack.push(nodePtr);
+		nodeStack.push(tmpNode);
 
-		if(!nodePtr->xmlChildrenNode)
+		if(!tmpNode->xmlChildrenNode)
 			return false;
 
-		nodePtr=nodePtr->xmlChildrenNode;
+		tmpNode=tmpNode->xmlChildrenNode;
 
-		while(nodePtr)
+		while(tmpNode)
 		{
 			char c;
 			//Retrieve enabled state 
-			if(!XMLGetNextElemAttrib(nodePtr,c,"enabled","value"))
+			if(!XMLGetNextElemAttrib(tmpNode,c,"enabled","value"))
 				break;
 
 			if(c == '1')
@@ -1263,28 +1300,28 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 				enabledIons[0].push_back(false);
 
 
-			nodePtr=nodePtr->next;
+			tmpNode=tmpNode->next;
 		}
 
-		nodePtr=nodeStack.top();
+		tmpNode=nodeStack.top();
 		nodeStack.pop();
 
 		//enabled ions for denominator
-		if(XMLHelpFwdToElem(nodePtr,"denominator"))
+		if(XMLHelpFwdToElem(tmpNode,"denominator"))
 			return false;
 
 
-		if(!nodePtr->xmlChildrenNode)
+		if(!tmpNode->xmlChildrenNode)
 			return false;
 
-		nodeStack.push(nodePtr);
-		nodePtr=nodePtr->xmlChildrenNode;
+		nodeStack.push(tmpNode);
+		tmpNode=tmpNode->xmlChildrenNode;
 
-		while(nodePtr)
+		while(tmpNode)
 		{
 			char c;
 			//Retrieve enabled state (denom) 
-			if(!XMLGetNextElemAttrib(nodePtr,c,"enabled","value"))
+			if(!XMLGetNextElemAttrib(tmpNode,c,"enabled","value"))
 				break;
 
 			if(c == '1')
@@ -1293,12 +1330,12 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 				enabledIons[1].push_back(false);
 				
 
-			nodePtr=nodePtr->next;
+			tmpNode=tmpNode->next;
 		}
 
 
 		nodeStack.pop();
-		nodePtr=nodeStack.top();
+		tmpNode=nodeStack.top();
 		nodeStack.pop();
 
 		//Check that the enabled ions size makes at least some sense...
@@ -1308,7 +1345,7 @@ bool VoxeliseFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 	}
 
 	//-------
-	if(!voxAppearance.readState(nodePtr))
+	if(!voxAppearance.readState(tmpNode))
 		return false;
 
 	return true;
