@@ -25,6 +25,11 @@
 #include "common/stringFuncs.h"
 
 using std::string;
+using std::map;
+using std::list;
+using std::set;
+using std::stack;
+using std::make_pair;
 
 enum
 {
@@ -624,7 +629,7 @@ void FilterTree::getFilterRefreshStarts(vector<tree<Filter *>::iterator > &propS
 unsigned int FilterTree::refreshFilterTree(list<FILTER_OUTPUT_DATA > &outData, 
 		std::vector<SelectionDevice *> &devices,
 		vector<ConsoleMessage > &consoleMessages,
-	       	ProgressData &curProg, ATOMIC_BOOL &abortRefresh) 
+	       	ProgressData &curProg, std::atomic<bool> &abortRefresh) 
 {
 
 	//initially, we should not want to abort refreshing 
@@ -676,7 +681,7 @@ unsigned int FilterTree::refreshFilterTree(list<FILTER_OUTPUT_DATA > &outData,
 	getFilterRefreshStarts(baseTreeNodes);
 	curProg.totalNumFilters=countChildFilters(filters,baseTreeNodes)+baseTreeNodes.size();
 
-	//The number of sub-steps in each prgoress entry
+	//The number of sub-steps in each progress entry
 	vector<unsigned int> nStepsProgress;
 
 	//Looping over the filters, find the number of steps each filter will take, if we can.
@@ -1140,7 +1145,10 @@ unsigned int FilterTree::loadXML(const xmlNodePtr &treeParent, std::ostream &err
 			if(isValidFilterName(tmpStr))
 			{
 				newFilt=makeFilter(tmpStr);
-				if (!newFilt->readState(nodePtr->xmlChildrenNode,stateFileDir))
+
+				xmlNodePtr tmpNodePtr=nodePtr->xmlChildrenNode;
+
+				if (!newFilt->readState(tmpNodePtr,stateFileDir))
 				{
 					needCleanup=true;
 					break;
@@ -1148,7 +1156,7 @@ unsigned int FilterTree::loadXML(const xmlNodePtr &treeParent, std::ostream &err
 			}
 			else
 			{
-				errStream << TRANS("WARNING: Skipping node ") << (const char *)nodePtr->name << TRANS(" as it was not recognised") << endl;
+				errStream << TRANS("WARNING: Skipping node ") << (const char *)nodePtr->name << TRANS(" as it was not recognised") << std::endl;
 				nodeUnderstood=false;
 			}
 		}
@@ -1186,7 +1194,7 @@ unsigned int FilterTree::loadXML(const xmlNodePtr &treeParent, std::ostream &err
 	//OK, we hit an error, we need to delete any pointers on the
 	//cleanup list
 	if(nodePtr)
-		errStream << TRANS("Error processing node: ") << (const char *)nodePtr->name << endl;
+		errStream << TRANS("Error processing node: ") << (const char *)nodePtr->name << std::endl;
 
 	clear();	
 
@@ -1200,7 +1208,7 @@ bool FilterTree::saveXML(std::ofstream &f,std::map<string,string> &fileMapping,
 {
 	set<string> existingFiles;
 
-	f << tabs(minTabDepth+1) << "<filtertree>" << endl;
+	f << tabs(minTabDepth+1) << "<filtertree>" << std::endl;
 	//Depth-first search, enumerate all filters in depth-first fashion
 	unsigned int depthLast=0;
 	unsigned int child=0;
@@ -1214,7 +1222,7 @@ bool FilterTree::saveXML(std::ofstream &f,std::map<string,string> &fileMapping,
 			while(depthLast++ < depth)
 			{
 				f << tabs(minTabDepth+depthLast+1);
-				f  << "<children>" << endl; 
+				f  << "<children>" << std::endl; 
 				child++;
 			}
 		}
@@ -1223,7 +1231,7 @@ bool FilterTree::saveXML(std::ofstream &f,std::map<string,string> &fileMapping,
 			while(depthLast-- > depth)
 			{
 				f << tabs(minTabDepth+depthLast+2);
-				f  << "</children>" << endl; 
+				f  << "</children>" << std::endl; 
 				child--;
 			}
 		}
@@ -1292,9 +1300,9 @@ bool FilterTree::saveXML(std::ofstream &f,std::map<string,string> &fileMapping,
 	//Close out filter tree.
 	while(child--)
 	{
-		f << tabs(minTabDepth+child+2) << "</children>" << endl;
+		f << tabs(minTabDepth+child+2) << "</children>" << std::endl;
 	}
-	f << tabs(minTabDepth+1) << "</filtertree>" << endl;
+	f << tabs(minTabDepth+1) << "</filtertree>" << std::endl;
 
 	return true;
 }
@@ -1365,11 +1373,14 @@ size_t FilterTree::countChildFilters(const tree<Filter *> &treeInst,
 	{
 		for(tree<Filter*>::pre_order_iterator it=nodes[ui];
 				it!=treeInst.end();++it)
-			childIts.insert(*it);
+		{
+			if(isChild(filters,nodes[ui],it))
+				childIts.insert(*it);
+		}
 
 	}
 
-	return childIts.size()-nodes.size();
+	return childIts.size();
 }
 
 
@@ -1451,10 +1462,10 @@ void FilterTree::checkRefreshValidity(const vector< const FilterStreamData *> &c
 	{
 		if(!curData[ui]->parent)
 		{
-			cerr << "Warning: orphan filter stream (FilterStreamData::parent == 0)." <<
-				"This must be set when creating new filter streams in the ::refresh function for the filter." << endl;
-			cerr << "Filter :"  << refreshFilter->getUserString() << "Stream Type: " << 
-				STREAM_NAMES[getBitNum(curData[ui]->getStreamType())] << endl;
+			std::cerr << "Warning: orphan filter stream (FilterStreamData::parent == 0)." <<
+				"This must be set when creating new filter streams in the ::refresh function for the filter." << std::endl;
+			std::cerr << "Filter :"  << refreshFilter->getUserString() << "Stream Type: " << 
+				STREAM_NAMES[getBitNum(curData[ui]->getStreamType())] << std::endl;
 		}
 		else if(curData[ui]->parent == refreshFilter)
 		{
