@@ -78,7 +78,7 @@ class FilterTree
 				tree<Filter *>::iterator testChild);
 
 
-		static size_t countChildFilters(const tree<Filter *> &treeInst,
+		size_t countChildFilters(const tree<Filter *> &treeInst,
 					const std::vector<tree<Filter *>::iterator> &nodes);
 	public:
 		FilterTree();
@@ -129,7 +129,7 @@ class FilterTree
 		unsigned int refreshFilterTree(	
 			std::list<FILTER_OUTPUT_DATA> &outData,
 			std::vector<SelectionDevice *> &devices,std::vector<ConsoleMessage > &consoleMessages,
-						ProgressData &curProg, ATOMIC_BOOL &abortRefresh);
+						ProgressData &curProg, std::atomic<bool> &abortRefresh);
 
 		static std::string getRefreshErrString(unsigned int errCode);
 		
