@@ -27,6 +27,12 @@
 
 #include <numeric>
 
+using std::vector;
+using std::pair;
+using std::make_pair;
+using std::list;
+using std::set;
+
 bool filterIsSampling(const Filter *f)
 {
 	bool affectsSampling=false;
