@@ -23,12 +23,6 @@
 
 #include <mgl2/canvas_wnd.h>
 
-//!Plot error bar estimation strings
-const char *errModeStrings[] = { 
-				NTRANS("None"),
-				NTRANS("Moving avg.")
-				};
-
 const char *traceStyleStrings[]= {
 	NTRANS("Lines"),
 	NTRANS("Bars"),
@@ -154,20 +148,7 @@ unsigned int plotID(const std::string &plotString)
 }
 //-----------
 
-unsigned int plotErrmodeID(const std::string &s)
-{
-	for(unsigned int ui=0;ui<PLOT_ERROR_ENDOFENUM; ui++)
-	{
-		if(s ==  errModeStrings[ui])
-			return ui;
-	}
-	ASSERT(false);
-}
 
-string plotErrmodeString(unsigned int plotID)
-{
-	return errModeStrings[plotID];
-}
 
 //===
 
@@ -1276,7 +1257,7 @@ PlotBase *Plot1D::clone() const
 	p->logarithmic=logarithmic;
 	p->xValues=xValues;
 	p->yValues=yValues;
-	p->errBars=errBars;
+	p->yErrorBars=yErrorBars;
 
 	copyBase(p);
 
@@ -1284,68 +1265,24 @@ PlotBase *Plot1D::clone() const
 }
 
 
-void Plot1D::setErrMode(PLOT_ERROR mode) 
+void Plot1D::setErrMode(unsigned int mode) 
 {
+	ASSERT(mode < PLOT_ERR_MODE_ENUM_END);
 	errMode=mode;
-	genErrBars();
-}
-
-
-void Plot1D::genErrBars() 
-{
-	switch(errMode.mode)
-	{
-		case PLOT_ERROR_NONE:
-			return;	
-		case PLOT_ERROR_MOVING_AVERAGE:
-		{
-			//FIXME: Has contiguous assumption implicit
-			ASSERT(errMode.movingAverageNum);
-			errBars.resize(yValues.size());
-			for(int ui=0;ui<(int)yValues.size();ui++)
-			{
-				float mean;
-				mean=0.0f;
-
-				//Compute the local mean
-				for(int uj=0;uj<(int)errMode.movingAverageNum;uj++)
-				{
-					//TODO: Why are we using (int) here?
-					int idx;
-					idx= std::max(ui+uj-(int)errMode.movingAverageNum/2,0);
-					idx=std::min(idx,(int)(yValues.size()-1));
-					ASSERT(idx<(int)yValues.size());
-					mean+=yValues[idx];
-				}
-
-				mean/=(float)errMode.movingAverageNum;
-
-				//Compute the local stddev
-				float stddev;
-				stddev=0;
-				for(int uj=0;uj<(int)errMode.movingAverageNum;uj++)
-				{
-					int idx;
-					idx= std::max(ui+uj-(int)errMode.movingAverageNum/2,0);
-					idx=std::min(idx,(int)(yValues.size()-1));
-					stddev+=(yValues[idx]-mean)*(yValues[idx]-mean);
-				}
-
-				stddev=sqrtf(stddev/(float)errMode.movingAverageNum);
-				errBars[ui]=stddev;
-			}
-			break;
-		}
-	}
 
 }
 
 void Plot1D::setData(const vector<float> &vX, const vector<float> &vY, 
-		const vector<float> &vErr)
+		const vector<pair<float,float> > &vErr)
 {
 
 	ASSERT(vX.size() == vY.size());
 	ASSERT(vErr.size() == vY.size() || !vErr.size());
+	for(const auto &p  : vErr)
+	{
+		ASSERT(isnan(p.first) || p.first >=0 );
+		ASSERT(isnan(p.second) || p.second >=0 );
+	}
 
 
 	//Fill up vectors with data
@@ -1354,8 +1291,10 @@ void Plot1D::setData(const vector<float> &vX, const vector<float> &vY,
 	yValues.resize(vY.size());
 	std::copy(vY.begin(),vY.end(),yValues.begin());
 	
-	errBars.resize(vErr.size());
-	std::copy(vErr.begin(),vErr.end(),errBars.begin());
+	yErrorBars.resize(vErr.size());
+	std::copy(vErr.begin(),vErr.end(),yErrorBars.begin());
+
+	//FIXME: Error data not taken into account
 
 	//Compute minima and maxima of plot data, and keep a copy of it
 	float maxThis=-std::numeric_limits<float>::max();
@@ -1402,7 +1341,19 @@ void Plot1D::setData(const vector<std::pair<float,float> > &v)
 
 }
 
-void Plot1D::setData(const vector<std::pair<float,float> > &v,const vector<float> &vErr) 
+void Plot1D::setData(const vector<std::pair<float,float> > &v,
+		const vector<float> & symErr)
+{
+	vector<pair<float,float> > errV;
+	errV.resize(symErr.size());
+	for(auto ui=0;ui<errV.size();ui++)
+		errV[ui] = std::make_pair(symErr[ui],symErr[ui]);
+
+	setData(v,errV);
+}
+
+void Plot1D::setData(const vector<std::pair<float,float> > &v,
+		const vector<pair<float,float> >&vErr) 
 {
 	//Fill up vectors with data
 	xValues.resize(v.size());
@@ -1421,12 +1372,12 @@ void Plot1D::setData(const vector<std::pair<float,float> > &v,const vector<float
 	}
 	else
 	{
-		errBars.resize(vErr.size());
-		std::copy(vErr.begin(),vErr.end(),errBars.begin());
-		computeDataBounds(yValues,vErr,minX,maxX);
+		yErrorBars.resize(vErr.size());
+		std::copy(vErr.begin(),vErr.end(),yErrorBars.begin());
+		computeDataBounds(yValues,vErr,minY,maxY);
 	}
 }
-void PlotBase::computeDataBounds(const vector<float> &d, const vector<float> &vErr,
+void PlotBase::computeDataBounds(const vector<float> &d, const vector<pair<float,float> > &vErr,
 						float &minV,float &maxV) 
 {
 	//Compute minima and maxima of plot data, and keep a copy of it
@@ -1435,8 +1386,8 @@ void PlotBase::computeDataBounds(const vector<float> &d, const vector<float> &vE
 	
 	for(unsigned int ui=0;ui<d.size();ui++)
 	{
-		minThis=std::min(minThis,d[ui]-vErr[ui]);
-		maxThis=std::max(maxThis,d[ui]+vErr[ui]);
+		minThis=std::min(minThis,d[ui]-vErr[ui].second);
+		maxThis=std::max(maxThis,d[ui]+vErr[ui].first);
 	}
 
 	minV=minThis;
@@ -1524,13 +1475,14 @@ void Plot1D::drawPlot(mglGraph *gr) const
 	
 
 	//Make a copy of the data we need to use
+	//FIXME:  Non-equal error bars
 	float *bufferX,*bufferY,*bufferErr;
 	bufferX = new float[xValues.size()];
 	bufferY = new float[yValues.size()];
 
-	showErrs=errBars.size();
+	showErrs=yErrorBars.size();
 	if(showErrs)
-		bufferErr = new float[errBars.size()];
+		bufferErr = new float[yErrorBars.size()];
 
 	//Pre-process the data, before handing to mathgl
 	//--
@@ -1542,13 +1494,13 @@ void Plot1D::drawPlot(mglGraph *gr) const
 	}
 	if(showErrs)
 	{
-		for(unsigned int uj=0;uj<errBars.size(); uj++)
-			bufferErr[uj] = errBars[uj];
+		for(unsigned int uj=0;uj<yErrorBars.size(); uj++)
+			bufferErr[uj] = yErrorBars[uj].second;
 	}
 	//--
 	
 	//Mathgl needs to know where to put the error bars.	
-	ASSERT(!showErrs  || errBars.size() ==xValues.size());
+	ASSERT(!showErrs  || yErrorBars.size() ==xValues.size());
 	
 	//Initialise the mathgl data
 	//--
@@ -1556,7 +1508,7 @@ void Plot1D::drawPlot(mglGraph *gr) const
 	yDat.Set(bufferY,yValues.size());
 
 	if(showErrs)
-		eDat.Set(bufferErr,errBars.size());
+		eDat.Set(bufferErr,yErrorBars.size());
 	//--
 	
 	
@@ -1652,14 +1604,27 @@ void Plot1D::getRawData(std::vector<std::vector< float> > &rawData,
 		labels.push_back(yLabel);
 	
 	
-	if(errBars.size())
+	if(yErrorBars.size())
 	{
-		tmp.resize(errBars.size());
-		std::copy(errBars.begin(),errBars.end(),tmp.begin());
+		vector<pair<float,float> > tmpError;
+
+		tmpError.resize(yErrorBars.size());
+		std::copy(yErrorBars.begin(),yErrorBars.end(),tmpError.begin());
 		
-		rawData.push_back(dummy);
-		rawData.back().swap(tmp);
-		labels.emplace_back(TRANS("error"));
+		//Unpack
+		vector<float> errUpper,errLower;
+		errUpper.resize(tmpError.size());
+		errLower.resize(tmpError.size());
+		for(auto ui=0u; ui<tmpError.size();ui++)
+		{
+			errLower[ui]=tmpError[ui].first;
+			errUpper[ui]=tmpError[ui].second;
+		}
+
+		rawData.emplace_back(std::move(errLower));
+		labels.emplace_back(TRANS("error (-)"));
+		rawData.emplace_back(std::move(errUpper));
+		labels.emplace_back(TRANS("error (+)"));
 	}
 }
 
