@@ -37,6 +37,12 @@
 
 //Use config header to determine if we need to enable mgl2 support
 #include "../config.h"
+
+//Work-around for bug in mathgl 2.4.4
+// where debug causes a wrong macro to be called
+#ifdef DEBUG
+#define mgl_abs(x) abs(x)
+#endif
 #include <mgl2/mgl.h>
 
 //mathgl shadows std::isnan
@@ -68,6 +74,14 @@ enum
 	PLOT_MODE_ENUM_END //not a plot, just end of enum
 };
 
+//Plot error mode
+enum
+{
+	PLOT_ERR_MODE_NONE, //No error bars
+	PLOT_ERR_MODE_YBOTH, //Y error bars in both directions
+	PLOT_ERR_MODE_ENUM_END,
+};
+
 //!Return a human readable string for a given plot type
 std::string plotString(unsigned int plotMode);
 
@@ -244,7 +258,7 @@ class PlotBase
 		static void computeDataBounds(const std::vector<float> &d, float &minV,float &maxV) ;
 		
 		//Find the upper and lower limit of a given dataset
-		static void computeDataBounds(const std::vector<float> &d, const std::vector<float> &errorBar,
+		static void computeDataBounds(const std::vector<float> &d, const std::vector<std::pair<float,float> > &errorBar,
 								float &minV,float &maxV);
 
 		//Find the upper and lower limit of a given dataset
@@ -337,10 +351,13 @@ class Plot1D : public PlotBase
 		//!Should plot logarithm (+1) of data? Be careful of -ve values.
 		bool logarithmic;
 		//!Data
-		std::vector<float> xValues,yValues,errBars;
+		std::vector<float> xValues,yValues;
+		//!Error data, positive in magnitude. 
+		// First is error in -ve direction, second in +ve. NaN if not known
+		std::vector<std::pair<float,float> > yErrorBars;
 
 		//Do we want to draw error bars?
-		PLOT_ERROR errMode;	
+		unsigned int errMode;	
 
 		//Set the error bars for this plot
 		void genErrBars();	
@@ -356,6 +373,11 @@ class Plot1D : public PlotBase
 		void setData(const std::vector<float> &vX, const std::vector<float> &vY);
 		void setData(const std::vector<float> &vX, const std::vector<float> &vY,
 							const std::vector<float> &symYErr);
+		//!Set plot data using non-symmetric error
+		void setData(const std::vector<float> &vX, const std::vector<float> &vY,
+					const std::vector<std::pair<float,float> > &symYErr);
+		void setData(const std::vector<std::pair<float,float> > &v,
+				const std::vector<std::pair<float,float> > &symYErr);
 
 		
 		//!Move a region to a new location. 
@@ -399,7 +421,7 @@ class Plot1D : public PlotBase
 		float getSmallestNonzero() const;
 
 		//Set the current error mode
-		void setErrMode(PLOT_ERROR newErrMode) ;  
+		void setErrMode(unsigned int newErrMode) ;  
 
 };
 
@@ -473,7 +495,7 @@ class Plot2DScatter : public PlotBase
 		void setData(const std::vector<std::pair<float,float> > &pts);
 		void setData(const std::vector<std::pair<float,float> > &pts ,const std::vector<float> &intens);
 
-		void setIntensityLabel(const string &s) { intensityLabel=s;}
+		void setIntensityLabel(const std::string &s) { intensityLabel=s;}
 };
 
 //Wrapper class for containing multiple plots 
