@@ -78,7 +78,7 @@ class TreeState
 
 		//Do we want to abort the refresh? This is passed to the tree
 		// to signal if the primary thread would like to abort
-		ATOMIC_BOOL wantAbort;
+		std::atomic<bool> wantAbort;
 
 		//How much has the tree been modified since last save?
 		unsigned int stateModifyLevel;
