@@ -28,6 +28,8 @@
 using std::list;
 using std::vector;
 using std::pair;
+using std::string;
+using std::map;
 
 bool VisController::isInstantiated = false;
 
@@ -41,6 +43,7 @@ bool dummyRefreshCallback(bool dummy)
 RefreshController::RefreshController(TreeState &tC)
 {
 	treeState=&tC;
+	curProg.reset();
 }
 
 RefreshController::~RefreshController()
@@ -261,7 +264,33 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 					//Create a 1D plot
 					auto plotNew= new Plot1D;
 
-					plotNew->setData(plotData->xyData);
+					plotNew->setLogarithmic(plotData->logarithmic);
+					plotNew->titleAsRawDataLabel=plotData->useDataLabelAsYDescriptor;
+
+					vector<pair<float,float> > yErrors;
+					//Set up the error behaviour from the plotstream
+					switch(plotData->errorMode)
+					{
+						case PlotStreamData::ERROR_MODE_NONE:
+							plotNew->setErrMode(PLOT_ERR_MODE_NONE);
+							break;
+						case PlotStreamData::ERROR_MODE_GAUSS:
+						case PlotStreamData::ERROR_MODE_POISSON:
+						case PlotStreamData::ERROR_MODE_GAUSS_RATIO:
+						case PlotStreamData::ERROR_MODE_POISSON_RATIO:
+						case PlotStreamData::ERROR_MODE_MOVING_AVERAGE:
+							plotNew->setErrMode(PLOT_ERR_MODE_YBOTH);
+							plotData->computeErrors(plotData->confidenceVal,yErrors);
+							break;
+						default:
+							ASSERT(false);
+							plotNew->setErrMode(PLOT_ERR_MODE_NONE);
+					}
+					if(yErrors.size())
+						plotNew->setData(plotData->xyData,yErrors);
+					else
+						plotNew->setData(plotData->xyData);
+					
 					for(unsigned int ui=0;ui<2;ui++)
 					{
 						for(unsigned int uj=0;uj<2;uj++)
@@ -275,9 +304,6 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 						}
 					}
 
-					plotNew->setLogarithmic(plotData->logarithmic);
-					plotNew->titleAsRawDataLabel=plotData->useDataLabelAsYDescriptor;
-					plotNew->setErrMode(plotData->errDat);
 					//Construct any regions that the plot may have
 					for(unsigned int ui=0;ui<plotData->regions.size();ui++)
 					{
