@@ -23,7 +23,7 @@
 	#include <iostream>
 	#include <cstdlib>
 	
-	#include <sys/time.h>
+	#include <chrono>
 
 	//Do we want to trap floating point exceptions 
 	void trapfpe (bool doTrap=true);
@@ -59,9 +59,9 @@
 	}
 
 	//Debug timing routines
-	#define DEBUG_TIME_START() timeval TIME_DEBUG_t; gettimeofday(&TIME_DEBUG_t,NULL);
-	#define DEBUG_TIME_END()  { timeval TIME_DEBUG_tend; gettimeofday(&TIME_DEBUG_tend,NULL); \
-	std::cerr << (TIME_DEBUG_tend.tv_sec - TIME_DEBUG_t.tv_sec) + ((float)TIME_DEBUG_tend.tv_usec-(float)TIME_DEBUG_t.tv_usec)/1.0e6 << std::endl; }
+	#define DEBUG_TIME_START() auto TIME_DEBUG_tstart = std::chrono::steady_clock::now();
+	#define DEBUG_TIME_END()  { auto TIME_DEBUG_tdiff = std::chrono::steady_clock::now() - TIME_DEBUG_tstart; \
+	std::cerr << (float)std::chrono::duration_cast<std::chrono::microsends>(tdiff).count() /1e6 << " sec" << std::endl; }
 
 	#ifndef TEST
 	#define EQ_TOL(f,g) (fabs( (f) - (g)) < 0.001)
