@@ -24,6 +24,8 @@
 
 #include "common/translation.h"
 
+#include "../backend/APT/ionhit.h"
+
 #ifdef __APPLE__
 	#include <sys/types.h>
 	#include <sys/sysctl.h>
@@ -44,6 +46,8 @@
 #include <cstring>
 #include <clocale>
 
+
+
 using std::string;
 using std::vector;
 using std::list;
@@ -708,6 +712,20 @@ float BoundCube::getBound(unsigned int bound, unsigned int minMax) const
         return bounds[bound][minMax];
 }
 
+Point3D BoundCube::min() const
+{
+	Point3D tmp;
+	getBound(tmp,0);
+	return tmp;
+}
+
+Point3D BoundCube::max() const
+{
+	Point3D tmp;
+	getBound(tmp,1);
+	return tmp;
+}
+
 void BoundCube::setBound(unsigned int bound, unsigned int minMax, float value)
 {
         ASSERT(bound <3 && minMax < 2);
@@ -749,6 +767,42 @@ void BoundCube::setBounds(const std::vector<Point3D> &points)
 #endif
 }
 
+void BoundCube::setBounds(const std::vector<IonHit> &ions)
+{
+	
+	setInverseLimits();	
+	for(const auto & ion: ions)
+	{
+		const auto point=ion.getPos();
+		for(unsigned int uj=0; uj<3; uj++)
+		{
+			if(point.getValue(uj) < bounds[uj][0])
+			{
+				{
+				bounds[uj][0] = point.getValue(uj);
+				valid[uj][0]=true;
+				}
+			}
+			
+			if(point.getValue(uj) > bounds[uj][1])
+			{
+				{
+				bounds[uj][1] = point.getValue(uj);
+				valid[uj][1]=true;
+				}
+			}
+		}
+	}
+
+#ifdef DEBUG
+	for(const auto & ion: ions)
+	{
+		const auto point=ion.getPos();
+		ASSERT(containsPt(point));
+	}
+#endif
+}
+
 void BoundCube::setBounds(const Point3D &p, float r)
 {
 	for(unsigned int dim=0;dim<3;dim++)
@@ -992,6 +1046,38 @@ void BoundCube::expand(const Point3D &p)
 	}
 }
 
+void BoundCube::expand(const vector<Point3D> &vec) 
+{
+	//If self not valid, ensure that it will be after this run
+	for(auto &p : vec)
+	{
+		for(unsigned int ui=0; ui<3; ui++)
+		{
+			//Check lower bound is lower to new pt
+			bounds[ui][0] =std::min(bounds[ui][0],p[ui]);
+
+			//Check upper bound is upper to new pt
+			bounds[ui][1] = std::max(bounds[ui][1],p[ui]);
+		}
+	}
+}
+
+void BoundCube::expand(const vector<IonHit> &vec) 
+{
+	//If self not valid, ensure that it will be after this run
+	for(auto &p : vec)
+	{
+		for(unsigned int ui=0; ui<3; ui++)
+		{
+			//Check lower bound is lower to new pt
+			bounds[ui][0] =std::min(bounds[ui][0],p[ui]);
+
+			//Check upper bound is upper to new pt
+			bounds[ui][1] = std::max(bounds[ui][1],p[ui]);
+		}
+	}
+}
+
 void BoundCube::expand(float f) 
 {
 	//If self not valid, ensure that it will be after this run
@@ -1431,6 +1517,8 @@ size_t getAvailRAM()
 	kern_return_t           error;
 	
 	error = host_statistics(sls_port , HOST_VM_INFO , (host_info_t) &vm, &vmCount);
+	if (error != KERN_SUCCESS) 
+		return 0;
 	pagesize = (unsigned long)sysconf(_SC_PAGESIZE);
 	memsize = (vm.free_count + vm.inactive_count) * pagesize;//(vm.wire_count + vm.active_count + vm.inactive_count + vm.free_count + vm.zero_fill_count ) * pagesize;
 	ret = (size_t)(memsize/(1024*1024));
@@ -1687,6 +1775,47 @@ bool rmFile(const std::string &filename)
 #endif
 
 #ifdef DEBUG
+
+#include <fstream>
+
+void gsl_print_matrix(gsl_matrix *m)
+{
+	std::cerr << "[" << std::endl;
+	for (size_t i = 0; i < m->size1; i++)
+	{
+		for (size_t j = 0; j < m->size2; j++)
+		{
+			std::cerr << gsl_matrix_get(m,i,j) << " ";
+		}
+		std::cerr << std::endl;
+
+	}
+	std::cerr << "]" << std::endl;
+
+}
+
+bool gsl_dump_matrix(gsl_matrix *m, const char *filename)
+{
+	std::ofstream f(filename);
+
+	if(!f)
+		return false;
+
+	f << "[" << std::endl;
+	for (size_t i = 0; i < m->size1; i++)
+	{
+		for (size_t j = 0; j < m->size2; j++)
+		{
+			f << gsl_matrix_get(m,i,j) << " ";
+		}
+		f << std::endl;
+
+	}
+	f << "]" << std::endl;
+
+	return true;
+}
+
 bool isValidXML(const char *filename)
 {
 	//Debug check to ensure we have written a valid xml file
