@@ -23,6 +23,7 @@
 
 #include <gsl/gsl_rng.h>
 #include <gsl/gsl_randist.h>
+#include <gsl/gsl_matrix.h>
 
 #if (_MSC_VER >= 1600) ||  (__cplusplus > 199711L) 
 	#define HAVE_CPP_1X
@@ -35,26 +36,6 @@
 	#define THREEDEP_ARRAYSIZE(f) (sizeof (f) / sizeof(*f))
 #endif
 
-//macro to switch between normal bool and atomic, as available.
-// do *NOT* declare const ATOMIC_BOOLs. This has wierd CPU caching
-// assumptions, which cause the type to not work properly if not using
-// true atomics	
-#ifndef ATOMIC_BOOL
-
-
-	#ifdef HAVE_CPP_1X
-		// Killed? By an ATOMIC bool? No sir, I guess I don't take 
-		// much solace that the implosion trigger
-		// functioned perfectly. 
-
-		//This bool is reliable for attempting to perform inter-thread flagging.
-		#include <atomic>
-		#define ATOMIC_BOOL std::atomic<bool>
-	#else
-		//C++ <1X does not provide a truly safe bool type. Most implementations it seems to work though (provided you don't use const).
-		#define ATOMIC_BOOL bool
-	#endif
-#endif
 
 #include "mathfuncs.h"
 #include "common/assertion.h"
@@ -65,9 +46,11 @@
 #include <list>
 #include <fstream>
 #include <algorithm>
+#include <atomic>
 
 class K3DTree;
 
+struct IonHit;
 
 //Set new locale code. Must be followed by a popLocale call before completion
 // Only one locale type can be pushed at a time this way
@@ -383,6 +366,11 @@ public:
     float getBound(unsigned int bound, unsigned int minMax) const ;
     
     void getBound(Point3D &bound, unsigned int minMax) const ;
+
+    Point3D min() const; 
+
+    Point3D max() const; 
+
     //!Return the centroid 
     Point3D getCentroid() const;
 
@@ -411,6 +399,8 @@ public:
     void setBounds( const Point3D &p, const Point3D &q);
     //!Obtain bounds from an array of Point3Ds
     void setBounds(const std::vector<Point3D> &ptArray);
+    //!Obtain bounds from an array of IonHits
+    void setBounds(const std::vector<IonHit> &ptArray);
 
     //!Set bounds via cube that contains given sphere
     void setBounds(const Point3D &p, float radius);
@@ -448,6 +438,10 @@ public:
     void expand(const BoundCube &b);
     //!Expand such that point is contained in this volume. Existing volume must be valid
     void expand(const Point3D &p);
+    //!Expand such that point is contained in this volume. Existing volume must be valid
+    void expand(const std::vector<Point3D> &p);
+    //!Expand such that point is contained in this volume. Existing volume must be valid
+    void expand(const std::vector<IonHit> &p);
     //!Expand by a specified thickness 
     void expand(float v);
     //!Obtain a corner point of the cube
@@ -577,7 +571,7 @@ class ColourRGBAf
 //Randomly select subset. Subset will be (somewhat) sorted on output.
 // Returns -1 on abort, otherwise returns number of randomly selected items
 template<class T> size_t randomSelect(std::vector<T> &result, const std::vector<T> &source, 
-							RandNumGen &rng, size_t num,unsigned int &progress, ATOMIC_BOOL &wantAbort, bool strongRandom=false)
+							RandNumGen &rng, size_t num,unsigned int &progress, std::atomic<bool> &wantAbort, bool strongRandom=false)
 {
 	progress=0;
 	//If there are not enough points, just copy it across in whole
@@ -853,4 +847,50 @@ void vectorTranspose(const std::vector<std::vector<T> > &v,
 	}
 }
 
+//Sum matrix down an axis, 0 = sum all rows, 1=cols. Vector will be resized automatically
+template<class T>
+void gsl_sum_axis(const gsl_matrix *m, unsigned int axis,
+		std::vector<T> &v)
+{
+	ASSERT(axis <2);
+	
+	if(axis ==0) // Row summation. 
+	{
+		v.resize(m->size2,0);
+
+		for(auto uj=0; uj<m->size2;uj++)
+		{
+			for(auto ui=0;ui<m->size1; ui++)
+				v[uj]+=gsl_matrix_get(m,ui,uj);
+		}
+
+	}
+	else
+	{
+		v.resize(m->size1,0);
+
+		for(auto ui=0; ui<m->size1;ui++)
+		{
+			for(auto uj=0;uj<m->size2; uj++)
+				v[ui]+=gsl_matrix_get(m,ui,uj);
+		}
+
+	}
+}
+
+#ifdef DEBUG
+void gsl_print_matrix(gsl_matrix *m);
+bool gsl_dump_matrix(gsl_matrix *m, const char *filename);
+template<class T>
+T gsl_matrix_sum(const gsl_matrix *m)
+{
+	unsigned int nElements = m->size1*m->size2;
+	T accum(0);
+	for(auto ui=0u;ui<nElements;ui++)
+		accum+=m->data[ui];
+
+	return accum;
+}
+#endif
+
 #endif
