@@ -29,7 +29,8 @@ const unsigned int OPENMP_MIN_DATASIZE=1000;
 enum
 {
 	PLOT_ERROR_NONE,
-	PLOT_ERROR_MOVING_AVERAGE,
+	PLOT_ERROR_MOVING_AVERAGE, //Derived from plot itself, using moving average
+	PLOT_ERROR_SUPPLIED_Y_BOTH,//Supplied as fixed values
 	PLOT_ERROR_ENDOFENUM
 };
 
@@ -65,18 +66,6 @@ enum
 };
 
 
-//FIXME: Is ther ewomewhere else to put this?
-//!Structure to handle error bar drawing in plot
-class PLOT_ERROR
-{
-	public:
-		PLOT_ERROR() { mode=PLOT_ERROR_NONE; movingAverageNum=1;};
-		//!Plot data estimator mode
-		unsigned int mode;
-		//!Number of data points for moving average
-		unsigned int movingAverageNum;
-};
-
 extern const char *RANGEFILE_WX_CONSTANT;
 
 extern const char *DTD_NAME;
