@@ -16,13 +16,20 @@
  *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "gsl_helper.h"
-
+#include "common/assertion.h"
 #include <iostream>
 
 
 using std::cerr;
 using std::endl;
 
+#ifdef DEBUG
+void gsl_catch_errors(const char *reason, const char *file, int line, int gsl_errno)
+{
+	cerr << "Trapped GSL error (" << file << ":" << line << " ->" << reason <<endl;
+	ASSERT(false);
+}
+#endif
 void gslPrint(const gsl_matrix *m)
 {
 	for(unsigned int ui=0;ui<m->size1; ui++)
