@@ -24,5 +24,7 @@
 
 void gslPrint(const gsl_matrix *m);
 
-
+#ifdef DEBUG
+void gsl_catch_errors(const char *reason, const char *file, int line, int gsl_errno);
+#endif
 #endif
