@@ -21,9 +21,10 @@
 #include "common/basics.h"
 #include "common/stringFuncs.h"
 
-#include <sys/time.h>
+#include <chrono>
 
 #include <gsl/gsl_blas.h>
+#include <gsl/gsl_eigen.h>
 
 using std::string;
 using std::vector;
@@ -240,6 +241,67 @@ float Point3D::mag() const
 	return sqrtf(sqrMag());
 }
 
+float Point3D::distanceToSegment(const Point3D &fA, const Point3D &fB) const
+{
+
+	//If the vectors a pointing "together" then use  point-line formula
+	if(vectorPointDir(fA,fB,*this,*this) == POINTDIR_TOGETHER)
+	{
+		Point3D closestPt;
+		Point3D vAB= fB-fA;
+
+		//Use formula d^2 = |(B-A)(cross)(A-P)|^2/|B-A|^2
+		return sqrtf( (vAB.crossProd(fA-*this)).sqrMag()/(vAB.sqrMag()));
+	}
+
+	return sqrtf( std::min(fB.sqrDist(*this), fA.sqrDist(*this)) );
+}
+
+float Point3D::distanceToFacet(const Point3D &fA, const Point3D &fB, 
+			const Point3D &fC, const Point3D &normal) const
+{
+
+	//This will check the magnitude of the incoming normal
+	ASSERT( fabs(sqrtf(normal.sqrMag()) - 1.0f) < 2.0* std::numeric_limits<float>::epsilon());
+	unsigned int pointDir[3];
+	pointDir[0] = vectorPointDir(fA,fB,*this,*this);
+	pointDir[1] = vectorPointDir(fA,fC,*this,*this);
+	pointDir[2] = vectorPointDir(fB,fC,*this,*this);
+
+	//They can never be "APART" if the
+	//vectors point to the same pt
+	ASSERT(pointDir[0] != POINTDIR_APART);
+	ASSERT(pointDir[1] != POINTDIR_APART);
+	ASSERT(pointDir[2] != POINTDIR_APART);
+
+	//Check to see if any of them are "in common"
+	if(pointDir[0]  > 0 ||  pointDir[1] >0 || pointDir[2] > 0)
+	{
+		//if so, we have to check each edge for its closest point
+		//then pick the best
+		float bestDist[3];
+		bestDist[0] = distanceToSegment(fA,fB);
+		bestDist[1] = distanceToSegment(fA,fC);
+		bestDist[2] = distanceToSegment(fB,fC);
+	
+
+		return std::min(bestDist[0],std::min(bestDist[1],bestDist[2]));
+	}
+
+	float temp;
+
+	temp = fabs((*this-fA).dotProd(normal));
+
+	//check that the other points were not better than this!
+	ASSERT(dist(fA) >= temp - std::numeric_limits<float>::epsilon());
+	ASSERT(dist(fB) >= temp - std::numeric_limits<float>::epsilon());
+	ASSERT(dist(fC) >= temp - std::numeric_limits<float>::epsilon());
+	 
+
+	//Point lies above/below facet, use plane formula
+	return temp; 
+}
+
 Point3D Point3D::normalise()
 {
 	float mag = sqrtf(sqrMag());
@@ -608,9 +670,11 @@ int RandNumGen::initTimer()
 {
 	timeval tp;
 
-	gettimeofday(&tp,NULL);
+	auto t = std::chrono::system_clock::now();
 
-	initialise(tp.tv_sec+ tp.tv_usec);
+	time_t tt = std::chrono::system_clock::to_time_t(t);
+
+	initialise(tt);
 	
 	return tp.tv_sec + tp.tv_usec;
 }
@@ -1240,6 +1304,23 @@ unsigned int vectorPointDir(const Point3D &pA, const Point3D &pB,
 	
 	return POINTDIR_TOGETHER;
 }
+
+
+void transposeGSLMatrix(gsl_matrix* &m)
+{
+	gsl_matrix *T=gsl_matrix_alloc(m->size2,m->size1);
+
+	for(auto ui=0;ui<m->size1;ui++)
+		for(auto uj=0;uj<m->size2;uj++)
+			gsl_matrix_set(T,uj,ui,gsl_matrix_get(m,ui,uj));
+
+	std::swap(m,T);
+
+	gsl_matrix_free(T);
+}
+
+
+
 #ifdef DEBUG
 
 bool testMathfuncs()
