@@ -124,6 +124,7 @@ class Point3D
 		Point3D normalise();
                 //!returns the square of distance another pt
                 float sqrDist(const Point3D &pt) const;
+		float dist(const Point3D &pt) const {return sqrtf(sqrDist(pt));};
 
                 //!overload for array indexing returns |pt|^2
                 float sqrMag() const;
@@ -148,6 +149,38 @@ class Point3D
 		//Extend the current vector by the specified distance
 		void extend(float distance);
 
+		
+		//! Returns the shortest distance between a line segment and a given point
+		/* The inputs are the ends of the line segment and the point. Uses the formula that 
+		 * \f$ 
+		 * D = \abs{\vec{PE}}\f$
+		 * \f[ 
+		 * \mathrm{~if~} \vec{PA} \cdot \vec{AB} > 0 
+		 * \rightarrow \vec{PE} = \vec{A} 
+		 * \f]
+		 * \f[
+		 * \mathrm{~if~} \vec{AB} \cdot \vec{PB} > 0 ~\&~ \vec{PA} \cdot \vec{AB} < 0
+		 * \rightarrow \vec{PB} \cdot \frac{\vec{AB}}{\abs{\vec{AB}}} 
+		 * \f]
+		 * \f[
+		 * \mathrm{~if~} \vec{PB} \cdot \vec{AB} < 0 
+		 * \rightarrow \vec{B} 
+		 * \f]
+		 */
+		float distanceToSegment(const Point3D &fA, const Point3D &fB) const;
+
+		//!Find the distance between a point, and a triangular facet -- may be positive or negative
+		/* The inputs are the facet points (ABC) and the point P (this pt).
+		 * distance is shortest using standard plane version 
+		 * \f$ D = \vec{AB} \cdot \vec{n} \f$ 
+		 * iff dot products to each combination of \f$ \left( AP,BP,CP \right) \leq 0 \f$
+		 * otherwise closest point is on the boundary of the simplex.
+		 * tested by shortest distance to each line segment (E is shortest pt. AB is line segement)
+		 * \f$ \vec{E} = \frac{\vec{AB}}{|\vec{AB}|} 
+		 *  ( \vec{PB} \cdot \vec{AB})\f$
+		 */
+		float distanceToFacet(const Point3D &fA, const Point3D &fB, 
+				const Point3D &fC, const Point3D &normal) const;
 
 		//!Retrieve by value
                 float operator[](unsigned int ui) const; 
@@ -395,7 +428,9 @@ T vectorWeightedMean(const std::vector<T> &v, const std::vector<T> &weight)
 	return value/weightSum;
 }
 
-
+//!Perform an in-place tranposition of a gsl matrix, even if non-square
+// note that additional memory consumption will be size(mem(M)), as temporary copy made
+void transposeGSLMatrix(gsl_matrix* &m);
 
 #ifdef DEBUG
 bool testMathfuncs();
