@@ -29,6 +29,102 @@ using std::numeric_limits;
 
 
 
+void incrementDataDistanceWeight(const Point3D &p,Voxels<float>  &v)
+{
+	//Obtain the position in the dataset
+	size_t x,y,z;
+	v.getIndex(x,y,z,p);
+
+	size_t nx,ny,nz;
+	v.getSize(nx,ny,nz);
+
+	//OK, so now do +- for each axis
+	// i.e. 26NN. Obtain weighting
+	float w[3][3][3];
+	for(auto ui=-1;ui<2;ui++)
+	{
+		for(auto uj=-1;uj<2;uj++)
+		{
+			for(auto uk=-1;uk<2;uk++)
+			{
+
+				if( ((long int)x + ui > 0 &&
+					x+ui < nx) &&
+				    ((long int)y + uj > 0 &&
+				     y+uj < ny) &&
+				   ((long int)z + uk > 0 &&
+					z+uk < nz))
+
+				{
+					w[ui][uj][uk]=sqrt(
+						v.getPoint(x+ui,y+uj,z+uk).sqrDist(p));
+				}
+				else
+					w[ui][uj][uk]=0;
+			}
+		}
+	}
+
+	//So we have the weights now, invert them and assign
+	// for inverse distance
+	for(auto ui=0;ui<3;ui++)
+		for(auto uj=0;uj<3;uj++)
+			for(auto uk=0;uk<3;uk++)
+			{
+				if(w[ui][uj][uk] >  sqrt(std::numeric_limits<float>::epsilon()))
+					w[ui][uj][uk]=1.0f/w[ui][uj][uk];
+				else
+					w[ui][uj][uk]=0;
+
+			}
+
+	float wSum=0;
+	for(auto ui=0;ui<3;ui++)
+		for(auto uj=0;uj<3;uj++)
+			for(auto uk=0;uk<3;uk++)
+				wSum+=w[ui][uj][uk];
+
+	for(auto ui=-1;ui<2;ui++)
+	{
+		for(auto uj=-1;uj<2;uj++)
+		{
+			for(auto uk=-1;uk<2;uk++)
+			{
+				if( w[ui][uj][uk] == 0)
+					continue;
+
+				if( ((long int)x + ui > 0 &&
+					x+ui < nx) &&
+				    ((long int)y + uj > 0 &&
+				     y+uj < ny) &&
+				   ((long int)z + uk > 0 &&
+					z+uk < nz) )
+
+				{
+#pragma omp critical
+					{
+					float t=v.getData(x+ui,y+uj,z+uk);
+					t+=w[ui][uj][uk]/wSum;
+
+					v.setData(x+ui,y+uj,z+uk,t);
+					}
+				}
+			}
+		}
+	}
+	
+	
+}
+
+void countDataDistanceWeight(const vector<Point3D> &pts, Voxels<float>&v)
+{
+#pragma omp parallel for shared(v)
+	for(auto ui=0;ui<pts.size();ui++)
+	{
+		incrementDataDistanceWeight(pts[ui],v);
+	}
+}
+
 
 
 #ifdef DEBUG
