@@ -41,8 +41,6 @@ const unsigned int MAX_CALLBACK=500;
 
 #include <vigra/accumulator.hxx>
 
-using namespace std;
-
 
 #ifndef M_PI
 #define M_PI 3.14159265358979323846
@@ -181,10 +179,10 @@ template<class T> class Voxels
 		void getInterpolatedData(const Point3D &pt, T &v) const;
 
 		//Perform in-place gaussian smoothing
-		void isotropicGaussianSmooth(float stdev,float windowRatio);
+		bool isotropicGaussianSmooth(float stdev,float windowRatio);
 
 		//Perform in-place laplacian smoothing
-		void laplaceOfGaussian(float stdev, float windowRatio);
+		bool laplaceOfGaussian(float stdev, float windowRatio);
 
 		//get an interpolated slice from a section of the data
 		void getInterpSlice(size_t normal, float offset, T *p, 
@@ -273,6 +271,7 @@ template<class T> class Voxels
 		Point3D getPitch() const;
 		//!Set the bounding size
 		void setBounds(const Point3D &pMin, const Point3D &pMax);
+		void setBounds(const BoundCube &b);
 		//!Get the bounding size
 		void getBounds(Point3D &pMin, Point3D &pMax) const { pMin=minBound;pMax=maxBound;}
 		void getBounds(BoundCube &bc) const { bc.setBounds(minBound,maxBound);}
@@ -1080,6 +1079,12 @@ void Voxels<T>::setBounds(const Point3D &pMin, const Point3D &pMax)
 	maxBound=pMax;
 }
 
+	template<class T>
+void Voxels<T>::setBounds(const BoundCube &bc)
+{
+	setBounds(bc.min(),bc.max());
+}
+
 template<class T>
 size_t Voxels<T>::init(size_t nX, size_t nY,
 	       				size_t nZ, const BoundCube &bound)
@@ -1137,10 +1142,10 @@ size_t Voxels<T>::loadFile(const char *cpFilename, size_t nX, size_t nY, size_t
 	//Draw a progress bar
 	if(!silent)
 	{
-		cerr << std::endl << "|";
+		std::cerr << std::endl << "|";
 		for(unsigned int ui=0; ui<100; ui++)
-			cerr << ".";
-		cerr << "| 100%" << std::endl << "|";
+			std::cerr << ".";
+		std::cerr << "| 100%" << std::endl << "|";
 	}
 		
 	unsigned int lastFrac=0;
@@ -1155,7 +1160,7 @@ size_t Voxels<T>::loadFile(const char *cpFilename, size_t nX, size_t nY, size_t
 			//Update progress bar
 			if(!silent && ((unsigned int)(((float)CFile.tellg()*100.0f)/(float)fileSize) > lastFrac))
 			{
-				cerr << ".";
+				std::cerr << ".";
 				pts++;
 				lastFrac=(unsigned int)(((float)CFile.tellg()*100.0f)/(float)fileSize) ;	
 			}
@@ -1182,9 +1187,9 @@ size_t Voxels<T>::loadFile(const char *cpFilename, size_t nX, size_t nY, size_t
 	if(!silent)
 	{
 		while(pts++ <100)
-			cerr << ".";
+			std::cerr << ".";
 	
-		cerr << "| done" << std::endl;
+		std::cerr << "| done" << std::endl;
 	}
 
 	return 0;
@@ -1194,7 +1199,7 @@ template<class T>
 size_t Voxels<T>::writeFile(const char *filename) const
 {
 
-	ASSERT(voxels.size())
+	ASSERT(voxels.size());
 
 	std::ofstream file(filename, std::ios::binary);
 
@@ -1793,23 +1798,38 @@ void Voxels<T>::getInterpolatedData(const Point3D &p, T &v) const
 }	
 
 template<class T>
-void Voxels<T>::isotropicGaussianSmooth(float stdev,float windowRatio)
+bool Voxels<T>::isotropicGaussianSmooth(float stdev,float windowRatio)
 {
 	//perform in-place smoothing
 	vigra::ConvolutionOptions<3> opt  = vigra::ConvolutionOptions<3>().filterWindowSize(windowRatio);
+	try
+	{
 	vigra::gaussianSmoothMultiArray(vigra::srcMultiArrayRange(voxels),
 			vigra::destMultiArray(voxels),stdev,opt);
+	}
+	catch(...)
+	{
+		return false;
+	}
 
+	return true;
 }
 
 template<class T>
-void Voxels<T>::laplaceOfGaussian(float stdev, float windowRatio)
+bool Voxels<T>::laplaceOfGaussian(float stdev, float windowRatio)
 {
 	//perform in-place smoothing
 	vigra::ConvolutionOptions<3> opt  = vigra::ConvolutionOptions<3>().filterWindowSize(windowRatio);
+	try
+	{
 	vigra::laplacianOfGaussianMultiArray(vigra::srcMultiArrayRange(voxels),
 			vigra::destMultiArray(voxels),stdev,opt);
-
+	}
+	catch(...)
+	{
+		return false;
+	}
+	return true;
 }
 
 template<class T>
