@@ -55,7 +55,7 @@ std::string unescapeXML(const std::string &s);
 
 //!Jump to the next element of the given name and retrieve the value for the specified attrip
 //returns false on failure
-//NOTE: Do not use if your value may validly contain whitespace. stream_cast skips these cases
+//NOTE: Do not use if your value may validly contain whitespace. stream_cast skips these cases. There is a specialisation for std::string, which preserves whitespace
 template<class T> 
 bool XMLGetNextElemAttrib(xmlNodePtr &nodePtr, T &v, const char *nodeName, const char *attrib)
 {
@@ -81,6 +81,10 @@ bool XMLGetNextElemAttrib(xmlNodePtr &nodePtr, T &v, const char *nodeName, const
 	return true;
 }
 
+//template specialisation, which does not strip whitespace from the attribute
+template<>
+bool XMLGetNextElemAttrib(xmlNodePtr &nodePtr, std::string &v, const char *nodeName, const char *attrib);
+
 
 //Returns 0 if successful, non zero if there is a property failure, or if the property is empty
 template<class T> unsigned int XMLHelpGetProp(T &prop,xmlNodePtr node, std::string propName)
