@@ -28,6 +28,10 @@
 
 #include "glDebug.h"
 
+using std::vector;
+using std::pair;
+using std::string;
+using std::make_pair;
 
 //Static class variables
 //====
@@ -2235,7 +2239,10 @@ void DrawProgressCircleOverlay::setFilterStepEstimates(const vector<unsigned int
 
 void DrawProgressCircleOverlay::draw( )const
 {
-	if(!totalFilters)
+	if(!totalFilters) 
+		return;
+
+	if(estimatedSteps.empty())
 		return;
 
 	ASSERT(estimatedSteps.size() == totalFilters);
@@ -2270,7 +2277,6 @@ void DrawProgressCircleOverlay::draw( )const
 	radiusIn= radiusOut*IN_RADIUS_FRACTION; 
 
 		
-	float visGrey=getHighContrastValue();
 
 	//Working in degrees
 	// - first in pair is start of segment (degrees)
@@ -2377,7 +2383,7 @@ void DrawProgressCircleOverlay::draw( )const
 				
 		}
 	}
-	//Draw the sections for this fulter
+	//Draw the sections for this filter
 	
 	glPopMatrix(); //Pop modelview matrix
 
@@ -2453,7 +2459,7 @@ DrawAnimatedOverlay::~DrawAnimatedOverlay()
 
 void DrawAnimatedOverlay::resetTime()
 {
-	gettimeofday(&animStartTime,NULL);
+	animStartTime= std::chrono::system_clock::now();
 }
 
 bool DrawAnimatedOverlay::setTexture(const vector<string> &texFiles,
@@ -2467,11 +2473,9 @@ bool DrawAnimatedOverlay::setTexture(const vector<string> &texFiles,
 
 void DrawAnimatedOverlay::getAnimationStat(float &alpha , float &animDeltaTime) const
 {
-		
-	timeval t;
-	gettimeofday(&t,NULL);
-	animDeltaTime=(float)(t.tv_sec - animStartTime.tv_sec) +
-		(t.tv_usec-animStartTime.tv_usec)/1.0e6;
+	
+	auto tNow = std::chrono::system_clock::now();
+	animDeltaTime= std::chrono::duration_cast<std::chrono::microseconds>(tNow-animStartTime).count()/1e6;
 
 
 	//Skip if we wish to show later
@@ -3035,6 +3039,10 @@ void DrawField3D::draw() const
 					}
 					else if(colourMapMode == COLOURMAP_MODE_CUSTOM)
 						applyCustomColourMap(colourMap,rgb,alphaThis,(float)ui,0,STEPS);
+					else
+					{
+						ASSERT(false);
+					}
 
 					//Set the colour section
 					float *p;
