@@ -19,7 +19,6 @@
 #ifndef DRAWABLES_H
 #define DRAWABLES_H
 
-//MacOS is "special" and puts it elsewhere
 
 #ifdef ENABLE_LIBVD 
 #include <GL/glew.h>
@@ -27,12 +26,14 @@
 #endif
 
 
+//MacOS is "special" and puts glu elsewhere
 #ifdef __APPLE__ 
 	#include <OpenGL/glu.h>
 #else
 	#include <GL/glu.h>
 #endif
 #include <sys/time.h>
+#include <chrono>
 
 
 
@@ -587,7 +588,7 @@ class DrawPolygon : public DrawableObj
 {
 	protected:
 		//!Vertices of the quad
-		vector<Point3D> vertices;
+		std::vector<Point3D> vertices;
 
 		//!Colour data for the quad
 		//!The lighting normal of the triangle 
@@ -611,7 +612,7 @@ class DrawPolygon : public DrawableObj
 		//!Get bounding cube
 		virtual void getBoundingBox(BoundCube &b) const ;
 
-		void setVertices(const vector<Point3D> &p);
+		void setVertices(const std::vector<Point3D> &p);
 		//!Set the colour of all vertices
 		void setColour(float r, float g, float b, float a);
 
@@ -1138,7 +1139,7 @@ class DrawAnimatedOverlay : public DrawableOverlay
 		// to opengl
 		unsigned int textureId;
 
-		timeval animStartTime;
+		std::chrono::system_clock::time_point animStartTime;
 
 		bool textureOK;
 
@@ -1204,7 +1205,7 @@ class DrawProgressCircleOverlay : public DrawAnimatedOverlay
 		//Filter that we are analysing (0->n-1)
 		unsigned int curFilter;
 	
-		vector<unsigned int> estimatedSteps;	
+		std::vector<unsigned int> estimatedSteps;	
 
 		//Draw a 2D wheel shaped section. Complete variable toggles the style of the drawing from a completed, to a n incompleted segment
 		void drawSection(unsigned int degreeStep, 
@@ -1214,7 +1215,7 @@ class DrawProgressCircleOverlay : public DrawAnimatedOverlay
 		~DrawProgressCircleOverlay();
 		void setCurFilter(unsigned int v) { curFilter= v;}
 
-		void setFilterStepEstimates(const vector<unsigned int> &v);
+		void setFilterStepEstimates(const std::vector<unsigned int> &v);
 		void setMaxStep(unsigned int v) { maxStep= v;}
 		void setNumFilters(unsigned int v) { totalFilters= v;}
 		void setProgress(unsigned int newProg) { ASSERT(newProg <=100); stepProgress = newProg;}
