@@ -1,6 +1,6 @@
 /*
  *	effect.h - opengl 3D effects header
- *	Copyright (C) 2015, D Haley 
+ *	Copyright (C) 2018, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -95,16 +95,13 @@ class BoxCropEffect : public Effect
 {
 	private:
 		//controlling ID values for gl plane. No more than MAX_OPENGL_CLIPPLANES allowed
-		unsigned int openGLIdStart,openGLIdEnd;
+		unsigned int openGLIdStart;
 		//Cropping margins (Fraction from edge towards opposite edge (complete)). 0->1. 
 		//Opposing edges must sum to 0->1. (xLo,xHi,yLo...)
 		float cropFractions[6];
 		//!True if we should transform to camera coordinates before applying crop
 		bool useCamCoordinates;
 
-		//!Aspect ratio of output image
-		float outputAspect;
-
 		void doClip(const Point3D &origin, const Point3D & normal,unsigned int glOffset) const;
 	public:
 		BoxCropEffect();
