@@ -517,9 +517,6 @@ void marchingCubes(const Voxels<float> &v,float isoValue, vector<TriangleWithVer
 		for(size_t iZ = 0; iZ < nz-1; iZ++)
 		{
 			iFlagIndex=0;
-			Point3D position;
-			//Lower left corner of cell for dual grid
-			position=v.getPoint(iX,iY,iZ) + gridSpacing*0.5;
 
 			//Find which vertices are inside of the surface and which are outside
 			for(int iVertexTest = 0; iVertexTest < 8; iVertexTest++)
@@ -656,6 +653,9 @@ void marchingCubes(const Voxels<float> &v,float isoValue, vector<TriangleWithVer
 			voxelFrameIntersection=low + (high-low)*alpha;
 		}
 
+		voxelFrameIntersection+=gridSpacing*0.5;
+
+
 			
 		pointMap.insert(make_pair(it->first,voxelFrameIntersection));
 
