@@ -62,7 +62,8 @@ Scene::Scene() : tempCam(nullptr), cameraSet(true), outWinAspect(1.0f), noticeTe
 	lightPosition[2]= 1.0;
 	lightPosition[3]=0.0;
 
-	lastMessageTime.tv_sec=lastMessageTime.tv_usec=0;
+	lastMessageTimeSet=false;
+
 	noticeText.setPosition(0.02,0.95);
 	noticeText.setSize(0.015);
 
@@ -87,8 +88,8 @@ unsigned int Scene::initDraw()
 		errCode=glewInit();
 		if(errCode!= GLEW_OK)
 		{
-			cerr << "Opengl context could not be created, aborting." << endl;
-			cerr << "Glew reports:" << glewGetErrorString(errCode) << endl;
+			std::cerr << "Opengl context could not be created, aborting." << std::endl;
+			std::cerr << "Glew reports:" << glewGetErrorString(errCode) << std::endl;
 			//Blow up without opengl
 			exit(1);
 		}
@@ -684,16 +685,15 @@ void Scene::updateNotifications()
 	ASSERT(MESSAGE_FADE_TIME > MESSAGE_FADE_START);
 
 
-	timeval tNow;
-	gettimeofday(&tNow,NULL);
-	float deltaMessageTime;
+	auto tNow = std::chrono::system_clock::now();
 
-	if(lastMessageTime.tv_sec ==0 && lastMessageTime.tv_usec == 0)
+	if (!lastMessageTimeSet)
 	{
+		lastMessageTimeSet=true;
 		lastMessageTime=tNow;
 	}
 
-	deltaMessageTime = (tNow.tv_sec- lastMessageTime.tv_sec) + (tNow.tv_usec - lastMessageTime.tv_usec)/1e6;
+	float deltaMessageTime = std::chrono::duration_cast<std::chrono::microseconds>(tNow-lastMessageTime).count()/1e6;
 
 
 	//Check the last message time
@@ -707,7 +707,7 @@ void Scene::updateNotifications()
 	if(noticeMessages.empty())
 	{
 		noticeText.setText("");
-		lastMessageTime.tv_usec=lastMessageTime.tv_sec=0;
+		lastMessageTimeSet=false;
 		return;
 	}
 	else
