@@ -42,24 +42,24 @@ bool SelectionDevice::getBinding(const DrawableObj *d,unsigned int mouseFlags,
 
 	bool found=false;
 
-	for(unsigned int ui=0;ui<bindingVec.size();ui++)
+	for(auto & binding : bindingVec)
 	{
-		if(bindingVec[ui].matchesDrawable(d,mouseFlags,keyFlags))
+		if(binding.matchesDrawable(d,mouseFlags,keyFlags))
 		{
 			if(!found)
 			{
 				//we found one.
 				found=true;
-				b=&(bindingVec[ui]);
+				b=&binding;
 				keyMask=b->getKeyFlags();
 				continue;
 			}
 
 			//OK, we already have one, but we can be "trumped"
 			//by a more complex keymask.
-			if( (keyMask & bindingVec[ui].getKeyFlags() )== keyMask)
+			if( (keyMask & binding.getKeyFlags() )== keyMask)
 			{
-				b=&(bindingVec[ui]);
+				b=&binding;
 				keyMask=b->getKeyFlags();
 			}
 		}
@@ -77,7 +77,7 @@ void SelectionDevice::getModifiedBindings(vector<std::pair<const Filter *,Select
 	for(unsigned int ui=0;ui<bindingVec.size();ui++)
 	{
 		if(bindingVec[ui].modified())
-			bindings.push_back(std::make_pair(target,bindingVec[ui]));
+			bindings.emplace_back(target,bindingVec[ui]);
 	}
 }
 
@@ -106,7 +106,7 @@ bool SelectionDevice::getAvailBindings(const DrawableObj *d,vector<const Selecti
 
 SelectionBinding::SelectionBinding()
 {
-	obj=0;
+	obj=nullptr;
 	valModified=false;
 	bindingId=drawActionId=0;
 }
