@@ -305,18 +305,27 @@ int pngTexture3D(texture *dest, const vector<string> &fileNames)
 	}
 
 	delete[] dataArray;
-	
+
+	//Clear existing error
+	glGetError();
+
+
 	glGenTextures(1, &(dest->glID));
 	glBindTexture(GL_TEXTURE_3D, dest->glID);
-	
-	//Send texture to video card
-	glTexImage3D(GL_TEXTURE_3D, 0, GL_RGBA, dest->width, dest->height, dest->depth, 0,
-				GL_RGBA, GL_UNSIGNED_BYTE, dest->data);
 
-	//Sett scale-down 
-	// and scale-up interpolation to LINEAR
-	glTexParameteri(GL_TEXTURE_3D, GL_TEXTURE_MIN_FILTER, GL_LINEAR); 
-	glTexParameteri(GL_TEXTURE_3D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+	if(glGetError() == GL_NO_ERROR)
+	{
+		//Send texture to video card
+		glTexImage3D(GL_TEXTURE_3D, 0, GL_RGBA, dest->width, dest->height, dest->depth, 0,
+					GL_RGBA, GL_UNSIGNED_BYTE, dest->data);
+
+		//Sett scale-down 
+		// and scale-up interpolation to LINEAR
+		glTexParameteri(GL_TEXTURE_3D, GL_TEXTURE_MIN_FILTER, GL_LINEAR); 
+		glTexParameteri(GL_TEXTURE_3D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+	}
+	else
+		return 4;
 
 	return 0;
 }
