@@ -58,7 +58,7 @@ CropPanel::CropPanel(wxWindow * parent, wxWindowID id,
 	crop[0]=crop[1]=crop[2]=crop[3]=0.2;
 	selMode=SELECT_MODE_NONE;
 	dragging=false;
-	linkedPanel=0;
+	linkedPanel=nullptr;
 	linkMode=CROP_LINK_NONE;
 	hasUpdates=false;
 }
@@ -473,9 +473,9 @@ void CropPanel::draw()
 {
 	ASSERT(validCoords());
 
-	wxAutoBufferedPaintDC   *dc=new wxAutoBufferedPaintDC(this);
+	auto dc=new wxAutoBufferedPaintDC(this);
 	
-	wxBrush *b = new wxBrush;
+	auto b = new wxBrush;
 	b->SetColour(wxSystemSettings::GetColour(wxSYS_COLOUR_BACKGROUND));
 	dc->Clear();
 
@@ -676,7 +676,7 @@ void CropPanel::link(CropPanel *panel,unsigned int mode)
 {
 	linkMode=mode;
 	if(linkMode== CROP_LINK_NONE)
-		linkedPanel=0;
+		linkedPanel=nullptr;
 	else
 	{
 		linkedPanel=panel;
