@@ -40,7 +40,7 @@
 using std::vector;
 using std::pair;
 using std::make_pair;
-using namespace std;
+using std::string;
 
 
 
@@ -1540,8 +1540,9 @@ void TransferEditorDialog::OnButtonSave(wxCommandEvent &event)
 
 	vector<pair<float,ColourRGBAf> > tFunc;
 	tFunc =  getTransferFunction();
-	
-	ofstream f(wxF.GetFilename());
+
+	std::string s=(wxF.GetFilename().ToStdString());
+	std::ofstream f(s.c_str());
 
 	if(!f)
 	{
@@ -1564,9 +1565,9 @@ void TransferEditorDialog::OnButtonLoad(wxCommandEvent &event)
 		return;
 
 
-	string s;
-
-	ifstream f(wxF.GetFilename());
+	string fName=(wxF.GetFilename().ToStdString());
+	
+	std::ifstream f(fName);
 
 	if(!f)
 	{
@@ -1576,6 +1577,7 @@ void TransferEditorDialog::OnButtonLoad(wxCommandEvent &event)
 	}
 
 
+	string s;
 	getline(f,s);
 	
 
