@@ -47,6 +47,7 @@
 
 using std::string;
 
+
 enum
 {
 	ID_KEYPRESS_TIMER=wxID_ANY+1,
@@ -93,6 +94,7 @@ BasicGLPane::BasicGLPane(wxWindow* parent) : wxGLCanvas(parent, wxID_ANY,  attri
 	haveCameraUpdates=false;
 	applyingDevice=false;
 	paneInitialised=false;
+	viewInitialiseFail=false;
 
 	keyDoubleTapTimer=new wxTimer(this,ID_KEYPRESS_TIMER);
 	lastKeyDoubleTap=(unsigned int)-1;
@@ -713,7 +715,9 @@ void BasicGLPane::keyReleased(wxKeyEvent& event)
  
 void BasicGLPane::resized(wxSizeEvent& evt)
 {
-	prepare3DViewport(0,0,getWidth(),getHeight()); 
+	if(!prepare3DViewport(0,0,getWidth(),getHeight()))
+		return;
+
 	auto dc=new wxClientDC(this);
 	Refresh();
 
@@ -778,7 +782,7 @@ int BasicGLPane::getHeight()
 void BasicGLPane::render( wxPaintEvent& evt )
 {
 	//Prevent calls to openGL if pane not visible
-	if (!IsShown()) 
+	if (!IsShown() || viewInitialiseFail)  
 		return;
 	
 	if(!context)
@@ -792,8 +796,15 @@ void BasicGLPane::render( wxPaintEvent& evt )
 
 	if(!paneInitialised)
 	{
+		//Must be set or prepare3D will abort
 		paneInitialised=true;
-		prepare3DViewport(0,0,getWidth(),getHeight()); 
+		if(!prepare3DViewport(0,0,getWidth(),getHeight()))
+		{
+			paneInitialised=false;
+			viewInitialiseFail=true;
+			return;
+		}
+
 	}
 
 //Apple requires a context update on each resize, for some reason
