@@ -156,8 +156,10 @@ void MathGLPane::setPanCoords() const
 	thePlot->getBounds(xMin,xMax,yMin,yMax);
 
 	float pEndX, pStartX,dummy;
-	toPlotCoords(draggingCurrent.x,draggingCurrent.y,pEndX,dummy);
-	toPlotCoords(draggingStart.x,draggingStart.y,pStartX,dummy);
+	if(!toPlotCoords(draggingCurrent.x,draggingCurrent.y,pEndX,dummy))
+		return;
+	if(!toPlotCoords(draggingStart.x,draggingStart.y,pStartX,dummy))
+		return;
 	
 	float offX = pEndX-pStartX;
 
@@ -519,7 +521,9 @@ bool MathGLPane::getRegionUnderCursor(const wxPoint  &mousePos, unsigned int &pl
 
 	//Convert the mouse coordinates to data coordinates.
 	float xM,yM;
-	toPlotCoords(mousePos.x,mousePos.y,xM,yM);
+	if(!toPlotCoords(mousePos.x,mousePos.y,xM,yM))
+		return false;
+
 	mglPoint pMouse(xM,yM); 
 
 
@@ -656,7 +660,8 @@ void MathGLPane::oneDMouseDownAction(bool leftDown,bool middleDown,
 			ASSERT(thePlot->getPlotMode(plotId) == PLOT_MODE_1D);
 
 			float mglStartX,mglStartY;
-			toPlotCoords(draggingStart.x, draggingStart.y,mglStartX,mglStartY);
+			if(!toPlotCoords(draggingStart.x, draggingStart.y,mglStartX,mglStartY))
+				return;
 
 			//Get the type of move, and the region
 			//that is being moved, as well as the plot that this
@@ -823,7 +828,8 @@ void MathGLPane::mouseWheelMoved(wxMouseEvent& event)
 	//retrieve the mouse position
 	mglPoint mousePos;
 	float mglX,mglY;
-	toPlotCoords(curMouse.x,curMouse.y,mglX,mglY);
+	if(!toPlotCoords(curMouse.x,curMouse.y,mglX,mglY))
+		return;
 	mousePos=mglPoint(mglX,mglY);
 
 	float xPlotMin,xPlotMax,yPlotMin,yPlotMax;
@@ -922,7 +928,8 @@ void MathGLPane::leftMouseReleased(wxMouseEvent& event)
 				//update
 				float mglX,mglY;
 
-				toPlotCoords(curMouse.x,curMouse.y,mglX,mglY);
+				if(!toPlotCoords(curMouse.x,curMouse.y,mglX,mglY))
+					return;
 				lastEditedRegion=startMouseRegion;
 				lastEditedPlot=startMousePlot;
 			
