@@ -43,6 +43,7 @@
 #include "backend/APT/ionhit.h"
 #include "backend/APT/APTFileIO.h"
 #include "backend/APT/abundanceParser.h"
+#include "backend/stats/confidence.h"
 
 #include "common/mathfuncs.h"
 #include "common/stringFuncs.h"
@@ -142,9 +143,9 @@ bool runUnitTests()
 
 	//Set the abort pointer for the filter
 #ifdef HAVE_CPP_1X
-	ATOMIC_BOOL abortFlag(false);
+	std::atomic<bool> abortFlag(false);
 #else
-	ATOMIC_BOOL abortFlag=false;
+	std::atomic<bool> abortFlag=false;
 #endif
 	Filter::wantAbort=&abortFlag;
 	K3DTree::setAbortFlag(&abortFlag);
@@ -223,6 +224,9 @@ bool runUnitTests()
 	if(!meshTests())
 		return false;
 
+	if(!runConfidenceTests())
+		return false;
+
 	cerr << " OK" << endl << endl;
 
 	return true;
