@@ -48,6 +48,7 @@ void updateFilterPropertyGrid(wxPropertyGrid *g, const Filter *f, const string &
 	//If debugging, test self consistency
 	p.checkConsistent();
 #endif	
+	g->Freeze();
 	g->Clear();
 	//Create the keys to add to the grid
 	for(size_t ui=0;ui<p.numGroups();ui++)
@@ -171,6 +172,12 @@ void updateFilterPropertyGrid(wxPropertyGrid *g, const Filter *f, const string &
 
 			//add the property to the grid
 			g->Append(pgp);
+			
+			if(fp.displayShaded)
+			{
+				wxColour c(240,240,255);
+				pgp->SetBackgroundColour(c);
+			}
 
 			switch(fp.type)
 			{
@@ -189,6 +196,7 @@ void updateFilterPropertyGrid(wxPropertyGrid *g, const Filter *f, const string &
 	//Restore the selected property, if possible
 	if(stateString.size())
 		g->RestoreEditableState(stateString);
+	g->Thaw();
 }
 
 void updateCameraPropertyGrid(wxPropertyGrid *g, const Camera *c)
@@ -202,12 +210,12 @@ void updateCameraPropertyGrid(wxPropertyGrid *g, const Camera *c)
 	CameraProperties p;
 	c->getProperties(p);
 	
-	for(unsigned int ui=0;ui<p.props.size();ui++)
+	for(auto & prop : p.props)
 	{
-		for(unsigned int uj=0;uj<p.props[ui].size();uj++)
+		for(unsigned int uj=0;uj<prop.size();uj++)
 		{
 			CameraProperty camProp;
-			camProp=p.props[ui][uj];
+			camProp=prop[uj];
 
 			string keyStr;
 			stream_cast(keyStr,camProp.key);
