@@ -1,6 +1,6 @@
 /*
  * propertyGridUpdater.h  - Update a  propertgy grid, using 3depict backend data
- * Copyright (C) 2015  D Haley
+ * Copyright (C) 2018, D Haley
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,9 @@
 #define PROPERTYGRIDUPDATER_H
 
 #include <wx/propgrid/propgrid.h>
+#include <wx/msgdlg.h>
 #include "backend/filter.h"
+#include "gui/dialogs/transferFuncDialog.h"
 
 #include <map>
 
@@ -40,4 +42,36 @@ void updateCameraPropertyGrid(wxPropertyGrid *g, const Camera *c);
 //Convert the property grid value into a 3depict-usable string
 std::string getPropValueFromEvent(wxPropertyGridEvent &event);
 
+class wxPGTransferFunctionDialog : public wxPGEditorDialogAdapter
+{
+	TransferEditorDialog *dlg;
+
+	public:
+		wxPGTransferFunctionDialog(wxWindow *win) : wxPGEditorDialogAdapter() { dlg = new TransferEditorDialog(win,wxID_ANY,"Transfer Function Editor"); }
+		~wxPGTransferFunctionDialog() {delete dlg;}
+		bool DoShowDialog(wxPropertyGrid *pg, wxPGProperty *prop); 
+};
+
+class wxPGTransferFunctionProperty : public wxStringProperty
+{
+	private:
+		wxWindow *parentWin;
+	public:
+		wxPGTransferFunctionProperty(const wxString &label,
+				const wxString &name , const wxString &value) : wxStringProperty(label,name,value)
+		{
+			parentWin=NULL;
+		}
+
+		void setParent(wxWindow *p) { parentWin=p;}
+
+		const wxPGEditor* DoGetEditorClass() const { return wxPGEditor_TextCtrlAndButton;}
+
+		virtual wxPGEditorDialogAdapter *GetEditorDialog() const
+		{
+			return new wxPGTransferFunctionDialog(parentWin);
+		}
+
+};
+
 #endif
