@@ -471,11 +471,19 @@ bool processMatchesName(size_t processID, const std::string &procName)
 			if (status == STATUS_SUCCESS)
 				break;
 			else if (status != STATUS_INFO_LENGTH_MISMATCH) { // 0xC0000004L
+				free(pspid);
 				return false;   // error
 			}
 
 			bufferSize *= 2;
-			pspid = (PSYSTEM_PROCESS_INFORMATION_DETAILD) realloc ((PVOID)pspid, bufferSize);
+			auto tmpAlloc= realloc ((PVOID)pspid, bufferSize);
+
+			if(!tmpAlloc)
+			{
+				free(pspid);
+				return false;	
+			}
+			pspid = (PSYSTEM_PROCESS_INFORMATION_DETAILD)tmpAlloc;
 		}
 
 		PSYSTEM_PROCESS_INFORMATION_DETAILD pspidBase;
