@@ -170,6 +170,12 @@ class VersionCheckThread : public wxThread
 		std::string getVerStr() {  return versionStr; }
 };
 
+//Create a temporary filename, optionally providing an extension to use/
+// - note that any subdirs will be automatically created if needed.
+std::string createTmpFilename(const char *dir=NULL,const char *extension=NULL);
+
+//Check if file can be written to, whether or not it exists
+bool canWriteToFile(const char *fName);
 
 //!storage node of tree persistence 
 // - tree persistence means the state for 
